from typing import Any

from novatel_edie import Header, Field, Message, SatelliteId
from novatel_edie.enums import *

class UNKNOWN(Message):
    def __repr__(self) -> str: ...

    @property
    def bytes(self) -> bytes: ...

class PASSAUX(Message):
    @property
    def buffer(self) -> list[int]: ...


class FILETRANSFER(Message):
    @property
    def file_transfer_operation_enum(self) -> FileTransferOperation: ...

    @property
    def file_name(self) -> str: ...


class TRANSFERPORTSTATUS(Message):
    @property
    def usb_detection_type(self) -> USBDetectionType: ...

    @property
    def usb_mode(self) -> USBMode: ...


class LOG(Message):
    @property
    def log_port_address(self) -> PortAddress: ...

    @property
    def message_id(self) -> int: ...

    @property
    def trigger(self) -> LogTrigger: ...

    @property
    def on_time(self) -> float: ...

    @property
    def offset(self) -> float: ...

    @property
    def hold(self) -> Hold: ...


class INTERFACEMODE(Message):
    @property
    def port(self) -> CommPort: ...

    @property
    def receive_interface_mode(self) -> InterfaceMode: ...

    @property
    def transmit_interface_mode(self) -> InterfaceMode: ...

    @property
    def responses(self) -> OnOff: ...


class COM(Message):
    @property
    def port(self) -> CommPort: ...

    @property
    def baud_rate(self) -> int: ...

    @property
    def parity(self) -> OEM4_Parity: ...

    @property
    def data_bits(self) -> int: ...

    @property
    def stop_bits(self) -> int: ...

    @property
    def hand_shaking(self) -> HandShake: ...

    @property
    def echo(self) -> OnOff: ...

    @property
    def breaks(self) -> OnOff: ...


class LOGLIST_log_list_Field(Field):
    @property
    def log_port_address(self) -> PortAddress: ...

    @property
    def message_id(self) -> int: ...

    @property
    def trigger(self) -> LogTrigger: ...

    @property
    def on_time(self) -> float: ...

    @property
    def offset(self) -> float: ...

    @property
    def hold(self) -> Hold: ...


class LOGLIST(Message):
    @property
    def log_list(self) -> list[LOGLIST_log_list_Field]: ...


class RESET(Message):
    @property
    def delay(self) -> int: ...


class SAVECONFIG(Message):
    pass


class FRESET(Message):
    @property
    def type(self) -> NVM_DataType: ...


class MODEL(Message):
    @property
    def model_name(self) -> str: ...


class UNLOG(Message):
    @property
    def log_port_address(self) -> PortAddress: ...

    @property
    def message_id(self) -> int: ...


class VERSION_versions_Field(Field):
    @property
    def component_type(self) -> Component: ...

    @property
    def model_name(self) -> str: ...

    @property
    def psn(self) -> str: ...

    @property
    def hardware_version(self) -> str: ...

    @property
    def software_version(self) -> str: ...

    @property
    def boot_version(self) -> str: ...

    @property
    def compile_date(self) -> str: ...

    @property
    def compile_time(self) -> str: ...


class VERSION(Message):
    @property
    def versions(self) -> list[VERSION_versions_Field]: ...


class UNLOGALL(Message):
    @property
    def port(self) -> PortAddress: ...

    @property
    def remove_held(self) -> bool: ...


class AUTH(Message):
    @property
    def auth_state(self) -> Security: ...

    @property
    def auth_data1(self) -> str: ...

    @property
    def auth_data2(self) -> str: ...

    @property
    def auth_data3(self) -> str: ...

    @property
    def auth_data4(self) -> str: ...

    @property
    def auth_data5(self) -> str: ...

    @property
    def model_name(self) -> str: ...

    @property
    def expiry_date(self) -> str: ...


class PORTSTATS_port_statistics_Field(Field):
    @property
    def port(self) -> CommPort: ...

    @property
    def rx_chars(self) -> int: ...

    @property
    def tx_chars(self) -> int: ...

    @property
    def good_rx_chars(self) -> int: ...

    @property
    def dropped_chars(self) -> int: ...

    @property
    def interrupts(self) -> int: ...

    @property
    def breaks(self) -> int: ...

    @property
    def parity_errors(self) -> int: ...

    @property
    def framing_errors(self) -> int: ...

    @property
    def over_runs(self) -> int: ...


class PORTSTATS(Message):
    @property
    def port_statistics(self) -> list[PORTSTATS_port_statistics_Field]: ...


class RXSTATUS_status_words_Field(Field):
    @property
    def status_word(self) -> int: ...

    @property
    def priority_mask(self) -> int: ...

    @property
    def event_set_mask(self) -> int: ...

    @property
    def event_clear_mask(self) -> int: ...


class RXSTATUS(Message):
    @property
    def rx_error(self) -> int: ...

    @property
    def status_words(self) -> list[RXSTATUS_status_words_Field]: ...


class RXSTATUSEVENT(Message):
    @property
    def word(self) -> RxEventWord: ...

    @property
    def bit_position(self) -> int: ...

    @property
    def event(self) -> RxStatusFlag: ...

    @property
    def description(self) -> str: ...


class STATUSCONFIG(Message):
    @property
    def type(self) -> RxStatusConfigType: ...

    @property
    def word(self) -> RxEventWord: ...

    @property
    def mask(self) -> int: ...


class ANTENNAPOWER(Message):
    @property
    def antenna_power(self) -> AntennaPower: ...


class RXCONFIG(Message):
    @property
    def message_id(self) -> int: ...

    @property
    def message_length(self) -> int: ...

    @property
    def message_buffer(self) -> str: ...


class SEND(Message):
    @property
    def port_address(self) -> CommPort: ...

    @property
    def text(self) -> str: ...


class SENDHEX(Message):
    @property
    def port_address(self) -> CommPort: ...

    @property
    def text(self) -> list[int]: ...


class NVMRESTORE(Message):
    pass


class VALIDMODELS_models_Field(Field):
    @property
    def model(self) -> str: ...

    @property
    def expiry_year(self) -> int: ...

    @property
    def expiry_month(self) -> int: ...

    @property
    def expiry_day(self) -> int: ...


class VALIDMODELS(Message):
    @property
    def models(self) -> list[VALIDMODELS_models_Field]: ...


class PASSCOM1(Message):
    @property
    def buffer(self) -> list[int]: ...


class PASSCOM2(Message):
    @property
    def buffer(self) -> list[int]: ...


class PASSCOM3(Message):
    @property
    def buffer(self) -> list[int]: ...


class COMCONFIG_com_config_Field(Field):
    @property
    def port(self) -> CommPort: ...

    @property
    def baud(self) -> int: ...

    @property
    def parity(self) -> OEM4_Parity: ...

    @property
    def data_bits(self) -> int: ...

    @property
    def stop_bits(self) -> int: ...

    @property
    def handshake(self) -> HandShake: ...

    @property
    def echo(self) -> OnOff: ...

    @property
    def breaks(self) -> OnOff: ...

    @property
    def rx_type(self) -> InterfaceMode: ...

    @property
    def tx_type(self) -> InterfaceMode: ...

    @property
    def responses(self) -> OnOff: ...


class COMCONFIG(Message):
    @property
    def com_config(self) -> list[COMCONFIG_com_config_Field]: ...


class PASSXCOM1(Message):
    @property
    def buffer(self) -> list[int]: ...


class PASSXCOM2(Message):
    @property
    def buffer(self) -> list[int]: ...


class COMCONTROL(Message):
    @property
    def port(self) -> CommPort: ...

    @property
    def signal(self) -> ComSignal: ...

    @property
    def control(self) -> ComSignalCtrl: ...


class SOFTLOADCOMMIT(Message):
    @property
    def src(self) -> SoftLoadSource: ...


class SOFTLOADRESET(Message):
    @property
    def src(self) -> SoftLoadSource: ...


class SOFTLOADSREC(Message):
    @property
    def srec(self) -> str: ...

    @property
    def src(self) -> SoftLoadSource: ...


class PASSUSB1(Message):
    @property
    def buffer(self) -> list[int]: ...


class PASSUSB2(Message):
    @property
    def buffer(self) -> list[int]: ...


class PASSUSB3(Message):
    @property
    def buffer(self) -> list[int]: ...


class PASSXCOM3(Message):
    @property
    def buffer(self) -> list[int]: ...


class NMEATALKER(Message):
    @property
    def talker_id(self) -> NMEATalkerID: ...


class CANCONFIG(Message):
    @property
    def can_port(self) -> CanPort: ...

    @property
    def on_off(self) -> OnOff: ...

    @property
    def bitrate(self) -> CanBitRate: ...


class TUNNELESCAPE(Message):
    @property
    def enable(self) -> Enable: ...

    @property
    def tunnel_escape(self) -> list[int]: ...


class HWMONITOR_measurements_Field(Field):
    @property
    def value(self) -> float: ...

    @property
    def status(self) -> int: ...


class HWMONITOR(Message):
    @property
    def measurements(self) -> list[HWMONITOR_measurements_Field]: ...


class CONFIGCODE(Message):
    @property
    def config_state(self) -> Security: ...

    @property
    def data1(self) -> str: ...

    @property
    def data2(self) -> str: ...

    @property
    def data3(self) -> str: ...

    @property
    def data4(self) -> str: ...

    @property
    def data5(self) -> str: ...

    @property
    def description(self) -> str: ...


class CHANCONFIGLIST_chan_cfg_list_array_Field_chan_cfg_list_sys_array_Field(Field):
    @property
    def num_chans(self) -> int: ...

    @property
    def signal_type(self) -> ChanConfigSignal: ...


class CHANCONFIGLIST_chan_cfg_list_array_Field(Field):
    @property
    def chan_cfg_list_sys_array(self) -> list[CHANCONFIGLIST_chan_cfg_list_array_Field_chan_cfg_list_sys_array_Field]: ...


class CHANCONFIGLIST(Message):
    @property
    def set_in_use(self) -> int: ...

    @property
    def chan_cfg_list_array(self) -> list[CHANCONFIGLIST_chan_cfg_list_array_Field]: ...


class SELECTCHANCONFIG(Message):
    @property
    def chan_config_setting(self) -> int: ...


class SOFTLOADDATA(Message):
    @property
    def offset(self) -> int: ...

    @property
    def data(self) -> list[int]: ...


class SOFTLOADSETUP(Message):
    @property
    def setup_type(self) -> SoftLoadSetup: ...

    @property
    def setup_string(self) -> str: ...


class SOFTLOADSTATUS(Message):
    @property
    def status(self) -> SoftLoadStatus: ...


class IPCONFIG(Message):
    @property
    def interface(self) -> PhysicalInterface: ...

    @property
    def mode(self) -> IPConfigMode: ...

    @property
    def ip_address(self) -> str: ...

    @property
    def netmask(self) -> str: ...

    @property
    def gateway(self) -> str: ...


class DNSCONFIG_dns_server_Field(Field):
    @property
    def ip_address(self) -> str: ...


class DNSCONFIG(Message):
    @property
    def dns_server(self) -> list[DNSCONFIG_dns_server_Field]: ...


class ETHCONFIG(Message):
    @property
    def interface(self) -> PhysicalInterface: ...

    @property
    def speed(self) -> EthernetSpeed: ...

    @property
    def duplex(self) -> EthernetDuplex: ...

    @property
    def crossover(self) -> EthernetCrossover: ...

    @property
    def power_mode(self) -> EthernetPowerMode: ...


class SERIALCONFIG(Message):
    @property
    def port(self) -> CommPort: ...

    @property
    def baud_rate(self) -> int: ...

    @property
    def parity(self) -> OEM4_Parity: ...

    @property
    def data_bits(self) -> int: ...

    @property
    def stop_bits(self) -> int: ...

    @property
    def hand_shaking(self) -> HandShake: ...

    @property
    def breaks(self) -> OnOff: ...


class ECHO(Message):
    @property
    def port(self) -> CommPort: ...

    @property
    def echo(self) -> OnOff: ...


class ICOMCONFIG(Message):
    @property
    def port(self) -> CommPort: ...

    @property
    def protocol(self) -> EthernetProtocol: ...

    @property
    def endpoint(self) -> str: ...

    @property
    def bind_interface(self) -> PhysicalInterface: ...


class NTRIPCONFIG(Message):
    @property
    def port(self) -> CommPort: ...

    @property
    def type(self) -> NTripType: ...

    @property
    def protocol(self) -> NTripProtocol: ...

    @property
    def endpoint(self) -> str: ...

    @property
    def mountpoint(self) -> str: ...

    @property
    def name(self) -> str: ...

    @property
    def password(self) -> str: ...

    @property
    def bind_interface(self) -> PhysicalInterface: ...


class PASSICOM1(Message):
    @property
    def buffer(self) -> list[int]: ...


class PASSICOM2(Message):
    @property
    def buffer(self) -> list[int]: ...


class PASSICOM3(Message):
    @property
    def buffer(self) -> list[int]: ...


class PASSNCOM1(Message):
    @property
    def buffer(self) -> list[int]: ...


class PASSNCOM2(Message):
    @property
    def buffer(self) -> list[int]: ...


class PASSNCOM3(Message):
    @property
    def buffer(self) -> list[int]: ...


class ETHSTATUS_eth_status_Field(Field):
    @property
    def interface(self) -> PhysicalInterface: ...

    @property
    def mac_address(self) -> str: ...

    @property
    def interface_config(self) -> EthernetInterfaceConfig: ...


class ETHSTATUS(Message):
    @property
    def eth_status(self) -> list[ETHSTATUS_eth_status_Field]: ...


class IPSTATUS_ip_status_Field(Field):
    @property
    def interface(self) -> PhysicalInterface: ...

    @property
    def ip_address(self) -> str: ...

    @property
    def netmask(self) -> str: ...

    @property
    def gateway(self) -> str: ...


class IPSTATUS_dns_server_Field(Field):
    @property
    def ip_address_6(self) -> str: ...


class IPSTATUS(Message):
    @property
    def ip_status(self) -> list[IPSTATUS_ip_status_Field]: ...

    @property
    def dns_server(self) -> list[IPSTATUS_dns_server_Field]: ...


class SOFTLOADFILE(Message):
    @property
    def file_system(self) -> MassStorageDevice: ...

    @property
    def file_name(self) -> str: ...

    @property
    def destination_device(self) -> EgressRoutingDest: ...


class MODELFEATURES_features_Field(Field):
    @property
    def feature_status(self) -> FeatureStatus: ...

    @property
    def feature(self) -> Feature: ...


class MODELFEATURES(Message):
    @property
    def features(self) -> list[MODELFEATURES_features_Field]: ...


class PASSTHROUGH(Message):
    @property
    def port(self) -> CommPort: ...

    @property
    def buffer(self) -> list[int]: ...


class NTRIPSOURCETABLE(Message):
    @property
    def endpoint(self) -> str: ...

    @property
    def NTRIPSOURCETABLE_reserved1(self) -> int: ...

    @property
    def NTRIPSOURCETABLE_reserved2(self) -> int: ...


class SOURCETABLE(Message):
    @property
    def endpoint(self) -> str: ...

    @property
    def SOURCETABLE_reserved1(self) -> int: ...

    @property
    def SOURCETABLE_reserved2(self) -> int: ...

    @property
    def entry_data(self) -> str: ...


class PASSCOM4(Message):
    @property
    def buffer(self) -> list[int]: ...


class PASSICOM4(Message):
    @property
    def buffer(self) -> list[int]: ...


class PROFILE(Message):
    @property
    def profile_option(self) -> ProfileOption: ...

    @property
    def profile_name(self) -> str: ...

    @property
    def command(self) -> str: ...


class PROFILEINFO_profile_info_command_Field(Field):
    @property
    def command(self) -> str: ...


class PROFILEINFO(Message):
    @property
    def profile_name(self) -> str: ...

    @property
    def status(self) -> int: ...

    @property
    def profile_info_command(self) -> list[PROFILEINFO_profile_info_command_Field]: ...


class SERIALPROTOCOL(Message):
    @property
    def port(self) -> CommPort: ...

    @property
    def protocol(self) -> PortProtocol: ...


class NMEAVERSION(Message):
    @property
    def nmea_version(self) -> NMEAVersion: ...


class IPSERVICE(Message):
    @property
    def i_net_port(self) -> IPService: ...

    @property
    def enable(self) -> Enable: ...


class PASSCOM5(Message):
    @property
    def buffer(self) -> list[int]: ...


class PASSCOM6(Message):
    @property
    def buffer(self) -> list[int]: ...


class SETADMINPASSWORD(Message):
    @property
    def old_password(self) -> str: ...

    @property
    def new_password(self) -> str: ...


class IPSTATS_ip_interface_statistics_Field(Field):
    @property
    def physical_interface(self) -> PhysicalInterface: ...

    @property
    def connection_duration(self) -> int: ...

    @property
    def rx_count(self) -> int: ...

    @property
    def tx_count(self) -> int: ...


class IPSTATS(Message):
    @property
    def ip_interface_statistics(self) -> list[IPSTATS_ip_interface_statistics_Field]: ...


class LOGIN(Message):
    @property
    def port(self) -> CommPort: ...

    @property
    def name(self) -> str: ...

    @property
    def password(self) -> str: ...


class LOGOUT(Message):
    @property
    def port(self) -> CommPort: ...


class SAVEETHERNETDATA(Message):
    @property
    def interface(self) -> PhysicalInterface: ...


class PASSCOM7(Message):
    @property
    def buffer(self) -> list[int]: ...


class PASSCOM8(Message):
    @property
    def buffer(self) -> list[int]: ...


class PASSCOM9(Message):
    @property
    def buffer(self) -> list[int]: ...


class PASSCOM10(Message):
    @property
    def buffer(self) -> list[int]: ...


class UPTIME(Message):
    @property
    def uptime(self) -> int: ...


class NMEAFORMAT(Message):
    @property
    def field(self) -> NMEAField: ...

    @property
    def format(self) -> str: ...


class RADARSTATUS(Message):
    @property
    def status(self) -> int: ...

    @property
    def solution_status(self) -> SolStatus: ...

    @property
    def solution_type(self) -> SolType: ...

    @property
    def horizontal_speed_mps(self) -> float: ...

    @property
    def smoothed_horizontal_speed_mps(self) -> float: ...

    @property
    def frequency(self) -> float: ...


class RADARCONFIG(Message):
    @property
    def switch(self) -> Enable: ...

    @property
    def frequency_step_hz_per_kph(self) -> float: ...

    @property
    def update_rate(self) -> EmulatedRadarUpdateRate: ...

    @property
    def response_mode(self) -> EmulatedRadarResponseMode: ...

    @property
    def response_threshold_kph(self) -> float: ...


class PGNCONFIG(Message):
    @property
    def message_id(self) -> int: ...

    @property
    def pgn(self) -> int: ...

    @property
    def priority(self) -> int: ...


class CCOMCONFIG(Message):
    @property
    def port(self) -> CommPort: ...

    @property
    def node(self) -> J1939Node: ...

    @property
    def protocol(self) -> CanProtocol: ...

    @property
    def pgn(self) -> int: ...

    @property
    def priority(self) -> int: ...

    @property
    def address(self) -> int: ...


class J1939CONFIG(Message):
    @property
    def j1939_node(self) -> J1939Node: ...

    @property
    def can_port(self) -> CanPort: ...

    @property
    def preferred_address(self) -> int: ...

    @property
    def alternate_address_range_start(self) -> int: ...

    @property
    def alternate_address_range_end(self) -> int: ...

    @property
    def manufacturer_code(self) -> int: ...

    @property
    def industry_group(self) -> int: ...

    @property
    def device_class(self) -> int: ...

    @property
    def device_class_instance(self) -> int: ...

    @property
    def function(self) -> int: ...

    @property
    def function_instance(self) -> int: ...

    @property
    def ecu_instance(self) -> int: ...


class J1939STATUS(Message):
    @property
    def j1939_node(self) -> J1939Node: ...

    @property
    def j1939_node_status(self) -> J1939NodeStatus: ...

    @property
    def address_claim_count(self) -> int: ...

    @property
    def claimed_address(self) -> int: ...


class NVMUSERDATA(Message):
    @property
    def data(self) -> list[int]: ...


class SAFEMODESTATUS(Message):
    @property
    def safe_mode_status(self) -> SafeModeStatus: ...

    @property
    def reset_count(self) -> int: ...

    @property
    def description(self) -> str: ...


class FILELIST(Message):
    @property
    def mass_storage_device(self) -> MassStorageDevice: ...

    @property
    def entry_type(self) -> FileSystemEntryType: ...

    @property
    def file_size(self) -> int: ...

    @property
    def last_change_date(self) -> int: ...

    @property
    def last_change_time(self) -> int: ...

    @property
    def file_name(self) -> str: ...


class FILETRANSFERSTATUS(Message):
    @property
    def file_transfer_status(self) -> FileTransferStatus: ...

    @property
    def total_transferred(self) -> int: ...

    @property
    def total_transfer_size(self) -> int: ...

    @property
    def file_name(self) -> str: ...

    @property
    def error_msg(self) -> str: ...


class FILESYSTEMSTATUS(Message):
    @property
    def mass_storage_device(self) -> MassStorageDevice: ...

    @property
    def file_system_status(self) -> FileSystemStatus: ...

    @property
    def media_capacity(self) -> int: ...

    @property
    def error_message(self) -> str: ...


class USBSTICKEJECT(Message):
    pass


class FILECONFIG(Message):
    @property
    def file_operation(self) -> FileOperation: ...


class FILEMEDIACONFIG(Message):
    @property
    def mass_storage_device(self) -> MassStorageDevice: ...


class PASSICOM5(Message):
    @property
    def buffer(self) -> list[int]: ...


class PASSICOM6(Message):
    @property
    def buffer(self) -> list[int]: ...


class PASSICOM7(Message):
    @property
    def buffer(self) -> list[int]: ...


class FILESTATUS(Message):
    @property
    def media_type(self) -> MassStorageDevice: ...

    @property
    def file_status(self) -> FileStatus: ...

    @property
    def file_name(self) -> str: ...

    @property
    def file_size(self) -> int: ...

    @property
    def media_remaining_capacity(self) -> int: ...

    @property
    def media_total_capacity(self) -> int: ...

    @property
    def error_msg_string(self) -> str: ...


class FILEROTATECONFIG(Message):
    @property
    def maximum_file_time(self) -> int: ...

    @property
    def maximum_file_size(self) -> int: ...

    @property
    def disk_full_action(self) -> DiskFullAction: ...


class FILEAUTOTRANSFER(Message):
    @property
    def file_auto_transfer_mode(self) -> FileAutoTransferMode: ...


class LUAFILESYSTEMSTATUS(Message):
    @property
    def file_system_status(self) -> FileSystemStatus: ...

    @property
    def error(self) -> str: ...


class LUAFILELIST(Message):
    @property
    def file_size(self) -> int: ...

    @property
    def last_changed_date(self) -> int: ...

    @property
    def last_changed_time(self) -> int: ...

    @property
    def file_path(self) -> str: ...


class LUASTATUS(Message):
    @property
    def executor_number(self) -> int: ...

    @property
    def script_command_line(self) -> str: ...

    @property
    def lua_status(self) -> LuaStatus: ...


class LUA(Message):
    @property
    def action(self) -> LuaAction: ...

    @property
    def script_command_line(self) -> str: ...


class FILEDELETE(Message):
    @property
    def filename(self) -> str: ...


class USERI2CREAD(Message):
    @property
    def slave_device_address(self) -> int: ...

    @property
    def slave_register_address(self) -> list[int]: ...

    @property
    def request_length(self) -> int: ...

    @property
    def transaction_id(self) -> int: ...


class USERI2CWRITE(Message):
    @property
    def slave_device_address(self) -> int: ...

    @property
    def slave_register_address(self) -> list[int]: ...

    @property
    def write_data(self) -> list[int]: ...

    @property
    def transaction_id(self) -> int: ...


class USERI2CRESPONSE(Message):
    @property
    def slave_device_address(self) -> int: ...

    @property
    def slave_register_address(self) -> int: ...

    @property
    def status_code(self) -> I2CStatus: ...

    @property
    def operation_mode(self) -> I2COperationMode: ...

    @property
    def transaction_id(self) -> int: ...

    @property
    def read_data(self) -> list[int]: ...


class LUAOUTPUT(Message):
    @property
    def sequence_number(self) -> int: ...

    @property
    def lua_executor(self) -> int: ...

    @property
    def source(self) -> LuaOutSource: ...

    @property
    def data(self) -> str: ...


class PPPSEEDSTORESTATUS(Message):
    @property
    def status(self) -> PPPSeedStoreStatus: ...

    @property
    def horizontal_std_dev(self) -> float: ...


class NMEABEIDOUTALKER(Message):
    @property
    def talker_id(self) -> NMEABeidouTalkerID: ...


class ANTENNATYPE_pc_cs_Field(Field):
    @property
    def frequency(self) -> Frequency: ...

    @property
    def pco(self) -> list[float]: ...

    @property
    def pcv(self) -> list[float]: ...


class ANTENNATYPE(Message):
    @property
    def manage_user_defined_antenna(self) -> ManageUserDefinedAntenna: ...

    @property
    def antenna(self) -> AntennaModel: ...

    @property
    def antenna_name(self) -> str: ...

    @property
    def pc_cs(self) -> list[ANTENNATYPE_pc_cs_Field]: ...


class USERANTENNA_pc_cs_Field(Field):
    @property
    def frequency(self) -> Frequency: ...

    @property
    def pco(self) -> list[float]: ...

    @property
    def pcv(self) -> list[float]: ...


class USERANTENNA(Message):
    @property
    def antenna(self) -> AntennaModel: ...

    @property
    def antenna_name(self) -> str: ...

    @property
    def pc_cs(self) -> list[USERANTENNA_pc_cs_Field]: ...


class TERRASTARAUTOCHANCONFIG(Message):
    @property
    def switch(self) -> Enable: ...


class GEODETICDATUM(Message):
    @property
    def option(self) -> DatumDataStore: ...

    @property
    def name(self) -> str: ...

    @property
    def epsg_code(self) -> int: ...

    @property
    def anchor(self) -> DatumAnchor: ...

    @property
    def semi_major_axis(self) -> float: ...

    @property
    def inverse_flattening(self) -> float: ...


class GEODETICDATUMS_datums_Field(Field):
    @property
    def name(self) -> str: ...

    @property
    def epsg_code(self) -> int: ...

    @property
    def anchor(self) -> DatumAnchor: ...

    @property
    def semi_major_axis(self) -> float: ...

    @property
    def inverse_flattening(self) -> float: ...


class GEODETICDATUMS(Message):
    @property
    def datums(self) -> list[GEODETICDATUMS_datums_Field]: ...


class DATUMTRANSFORMATION(Message):
    @property
    def option(self) -> DatumDataStore: ...

    @property
    def name(self) -> str: ...

    @property
    def name_2(self) -> str: ...

    @property
    def epoch(self) -> float: ...

    @property
    def x_translation(self) -> float: ...

    @property
    def y_translation(self) -> float: ...

    @property
    def z_translation(self) -> float: ...

    @property
    def x_rotation(self) -> float: ...

    @property
    def y_rotation(self) -> float: ...

    @property
    def z_rotation(self) -> float: ...

    @property
    def scale_difference(self) -> float: ...

    @property
    def x_translation_rate(self) -> float: ...

    @property
    def y_translation_rate(self) -> float: ...

    @property
    def z_translation_rate(self) -> float: ...

    @property
    def x_rotation_rate(self) -> float: ...

    @property
    def y_rotation_rate(self) -> float: ...

    @property
    def z_rotation_rate(self) -> float: ...

    @property
    def scale_difference_rate(self) -> float: ...


class DATUMTRANSFORMATIONS_transformations_Field(Field):
    @property
    def name(self) -> str: ...

    @property
    def name_2(self) -> str: ...

    @property
    def epoch(self) -> float: ...

    @property
    def x_translation(self) -> float: ...

    @property
    def y_translation(self) -> float: ...

    @property
    def z_translation(self) -> float: ...

    @property
    def x_rotation(self) -> float: ...

    @property
    def y_rotation(self) -> float: ...

    @property
    def z_rotation(self) -> float: ...

    @property
    def scale_difference(self) -> float: ...

    @property
    def x_translation_rate(self) -> float: ...

    @property
    def y_translation_rate(self) -> float: ...

    @property
    def z_translation_rate(self) -> float: ...

    @property
    def x_rotation_rate(self) -> float: ...

    @property
    def y_rotation_rate(self) -> float: ...

    @property
    def z_rotation_rate(self) -> float: ...

    @property
    def scale_difference_rate(self) -> float: ...


class DATUMTRANSFORMATIONS(Message):
    @property
    def transformations(self) -> list[DATUMTRANSFORMATIONS_transformations_Field]: ...


class USERI2CBITRATE(Message):
    @property
    def bit_rate(self) -> I2CBitRate: ...


class GPSEPHEM(Message):
    @property
    def satellite_id(self) -> int: ...

    @property
    def tow(self) -> float: ...

    @property
    def health7(self) -> int: ...

    @property
    def iode1(self) -> int: ...

    @property
    def iode2(self) -> int: ...

    @property
    def wn(self) -> int: ...

    @property
    def zwn(self) -> int: ...

    @property
    def toe(self) -> float: ...

    @property
    def a(self) -> float: ...

    @property
    def delta_n(self) -> float: ...

    @property
    def m0(self) -> float: ...

    @property
    def ecc(self) -> float: ...

    @property
    def omega(self) -> float: ...

    @property
    def cuc(self) -> float: ...

    @property
    def cus(self) -> float: ...

    @property
    def crc(self) -> float: ...

    @property
    def crs(self) -> float: ...

    @property
    def cic(self) -> float: ...

    @property
    def cis(self) -> float: ...

    @property
    def i0(self) -> float: ...

    @property
    def i_dot(self) -> float: ...

    @property
    def omega0(self) -> float: ...

    @property
    def omega_dot(self) -> float: ...

    @property
    def iodc(self) -> int: ...

    @property
    def toc(self) -> float: ...

    @property
    def tgd(self) -> float: ...

    @property
    def af0(self) -> float: ...

    @property
    def af1(self) -> float: ...

    @property
    def af2(self) -> float: ...

    @property
    def anti_spoofing(self) -> bool: ...

    @property
    def n(self) -> float: ...

    @property
    def eph_var(self) -> float: ...


class IONUTC(Message):
    @property
    def a0(self) -> float: ...

    @property
    def a1(self) -> float: ...

    @property
    def a2(self) -> float: ...

    @property
    def a3(self) -> float: ...

    @property
    def b0(self) -> float: ...

    @property
    def b1(self) -> float: ...

    @property
    def b2(self) -> float: ...

    @property
    def b3(self) -> float: ...

    @property
    def w_nt(self) -> int: ...

    @property
    def tot(self) -> int: ...

    @property
    def a0_10(self) -> float: ...

    @property
    def a1_11(self) -> float: ...

    @property
    def w_nlsf(self) -> int: ...

    @property
    def dn(self) -> int: ...

    @property
    def delta_tls(self) -> int: ...

    @property
    def delta_tlsf(self) -> int: ...

    @property
    def delta_tutc(self) -> int: ...


class CLOCKADJUST(Message):
    @property
    def command(self) -> ClockAdjustCommand: ...


class RAWGPSSUBFRAME(Message):
    @property
    def frame_decoder_number(self) -> int: ...

    @property
    def satellite_id(self) -> int: ...

    @property
    def sub_frame_id(self) -> int: ...

    @property
    def raw_sub_frame_data(self) -> list[int]: ...

    @property
    def signal_channel_number(self) -> int: ...


class CLOCKSTEERING(Message):
    @property
    def steering_source(self) -> ClockSource: ...

    @property
    def steering_state(self) -> ClockSteeringState: ...

    @property
    def modulus(self) -> int: ...

    @property
    def effective_pulse_width(self) -> float: ...

    @property
    def bandwidth(self) -> float: ...

    @property
    def slope(self) -> float: ...

    @property
    def last_offset(self) -> float: ...

    @property
    def last_rate(self) -> float: ...


class ASSIGN(Message):
    @property
    def chan(self) -> int: ...

    @property
    def assign_state(self) -> AssignState: ...

    @property
    def prn(self) -> int: ...

    @property
    def doppler(self) -> int: ...

    @property
    def doppler_window(self) -> int: ...


class ASSIGNALL(Message):
    @property
    def system(self) -> AssignSystem: ...

    @property
    def assign_state(self) -> AssignState: ...

    @property
    def prn(self) -> int: ...

    @property
    def doppler(self) -> int: ...

    @property
    def doppler_window(self) -> int: ...


class UNASSIGN(Message):
    @property
    def chan(self) -> int: ...

    @property
    def assign_state(self) -> AssignState: ...


class UNASSIGNALL(Message):
    @property
    def system(self) -> AssignSystem: ...


class RAWEPHEM(Message):
    @property
    def satellite_id(self) -> int: ...

    @property
    def week(self) -> int: ...

    @property
    def toe(self) -> int: ...

    @property
    def subframe1(self) -> list[int]: ...

    @property
    def subframe2(self) -> list[int]: ...

    @property
    def subframe3(self) -> list[int]: ...


class RANGE_obs_Field(Field):
    @property
    def sv_prn(self) -> int: ...

    @property
    def sv_freq(self) -> int: ...

    @property
    def psr(self) -> float: ...

    @property
    def sd_psr(self) -> float: ...

    @property
    def adr(self) -> float: ...

    @property
    def sd_adr(self) -> float: ...

    @property
    def dop(self) -> float: ...

    @property
    def C_No(self) -> float: ...

    @property
    def lock_time(self) -> float: ...

    @property
    def c_status(self) -> int: ...


class RANGE(Message):
    @property
    def obs(self) -> list[RANGE_obs_Field]: ...


class SATVIS_sat_vis_list_Field(Field):
    @property
    def prn(self) -> int: ...

    @property
    def freq(self) -> int: ...

    @property
    def sat_health(self) -> int: ...

    @property
    def elevation(self) -> float: ...

    @property
    def azimuth(self) -> float: ...

    @property
    def true_doppler(self) -> float: ...

    @property
    def apparent_doppler(self) -> float: ...


class SATVIS(Message):
    @property
    def is_sat_vis_valid(self) -> bool: ...

    @property
    def was_gps_almanac_used(self) -> bool: ...

    @property
    def sat_vis_list(self) -> list[SATVIS_sat_vis_list_Field]: ...


class ECUTOFF(Message):
    @property
    def elevation_cutoff_angle(self) -> float: ...


class ALMANAC_sv_alm_data_Field(Field):
    @property
    def prn(self) -> int: ...

    @property
    def wn(self) -> int: ...

    @property
    def toa(self) -> float: ...

    @property
    def ecc(self) -> float: ...

    @property
    def omega_dot(self) -> float: ...

    @property
    def omega0(self) -> float: ...

    @property
    def omega(self) -> float: ...

    @property
    def mo(self) -> float: ...

    @property
    def af0(self) -> float: ...

    @property
    def af1(self) -> float: ...

    @property
    def n(self) -> float: ...

    @property
    def a(self) -> float: ...

    @property
    def di(self) -> float: ...

    @property
    def sv_configuration(self) -> int: ...

    @property
    def health6(self) -> int: ...

    @property
    def health8(self) -> int: ...

    @property
    def anti_spoofing_set(self) -> bool: ...


class ALMANAC(Message):
    @property
    def sv_alm_data(self) -> list[ALMANAC_sv_alm_data_Field]: ...


class RAWALM_sub_frame_pages_Field(Field):
    @property
    def svid(self) -> int: ...

    @property
    def page_raw_data(self) -> list[int]: ...


class RAWALM(Message):
    @property
    def weeks(self) -> int: ...

    @property
    def milliseconds(self) -> int: ...

    @property
    def sub_frame_pages(self) -> list[RAWALM_sub_frame_pages_Field]: ...


class TRACKSTAT_chan_status_Field(Field):
    @property
    def prn(self) -> int: ...

    @property
    def freq(self) -> int: ...

    @property
    def channel_status(self) -> int: ...

    @property
    def psr(self) -> float: ...

    @property
    def doppler(self) -> float: ...

    @property
    def C_No(self) -> float: ...

    @property
    def lock_time(self) -> float: ...

    @property
    def psr_residual(self) -> float: ...

    @property
    def psr_range_reject(self) -> ObservationStatus: ...

    @property
    def psr_filter_weighting(self) -> float: ...


class TRACKSTAT(Message):
    @property
    def position_status(self) -> SolStatus: ...

    @property
    def position_type(self) -> SolType: ...

    @property
    def tracking_elevation_cutoff(self) -> float: ...

    @property
    def chan_status(self) -> list[TRACKSTAT_chan_status_Field]: ...


class TIME(Message):
    @property
    def clock_model_status(self) -> ClockModelStatus: ...

    @property
    def offset(self) -> float: ...

    @property
    def offset_std(self) -> float: ...

    @property
    def utc_offset(self) -> float: ...

    @property
    def utc_year(self) -> int: ...

    @property
    def utc_month(self) -> int: ...

    @property
    def utc_day(self) -> int: ...

    @property
    def utc_hour(self) -> int: ...

    @property
    def utc_minute(self) -> int: ...

    @property
    def utc_millisecond(self) -> int: ...

    @property
    def utc_time_status(self) -> UTCTimeStatus: ...


class SETAPPROXTIME(Message):
    @property
    def weeks(self) -> int: ...

    @property
    def seconds(self) -> float: ...


class LOCKOUT(Message):
    @property
    def prn(self) -> int: ...


class UNLOCKOUT(Message):
    @property
    def prn(self) -> int: ...


class UNLOCKOUTALL(Message):
    pass


class RANGECMP_range_c_entry_Field(Field):
    @property
    def range_c_data(self) -> list[int]: ...


class RANGECMP(Message):
    @property
    def range_c_entry(self) -> list[RANGECMP_range_c_entry_Field]: ...


class EXTERNALCLOCK(Message):
    @property
    def clock_type(self) -> ClockType: ...

    @property
    def frequency(self) -> ExtClockFreq: ...

    @property
    def h0(self) -> float: ...

    @property
    def hm1(self) -> float: ...

    @property
    def hm2(self) -> float: ...


class MARKTIME(Message):
    @property
    def week(self) -> int: ...

    @property
    def seconds(self) -> float: ...

    @property
    def offset(self) -> float: ...

    @property
    def offset_std(self) -> float: ...

    @property
    def utc_offset(self) -> float: ...

    @property
    def status(self) -> ClockModelStatus: ...


class FREQUENCYOUT(Message):
    @property
    def enable(self) -> FreqOutEnable: ...

    @property
    def pulse_width(self) -> int: ...

    @property
    def period(self) -> int: ...


class DYNAMICS(Message):
    @property
    def value(self) -> Dynamics: ...


class RAWGPSWORD(Message):
    @property
    def prn(self) -> int: ...

    @property
    def raw_word(self) -> int: ...


class ADJUST1PPS(Message):
    @property
    def mode(self) -> Adjust1PPSMode: ...

    @property
    def period(self) -> Adjust1PPSPeriod: ...

    @property
    def time(self) -> int: ...


class CLOCKCALIBRATE(Message):
    @property
    def setting(self) -> ClockCalibrate: ...

    @property
    def modulus(self) -> int: ...

    @property
    def center(self) -> int: ...

    @property
    def slope(self) -> float: ...

    @property
    def bandwidth(self) -> float: ...


class TIMESYNC(Message):
    @property
    def gps_week(self) -> int: ...

    @property
    def milliseconds(self) -> int: ...

    @property
    def time_status(self) -> GPSTimeStatus: ...


class CLOCKOFFSET(Message):
    @property
    def clock_offset(self) -> int: ...


class PPSCONTROL(Message):
    @property
    def enable_disable(self) -> PPSEnable: ...

    @property
    def polarity(self) -> Polarity: ...

    @property
    def rate(self) -> float: ...

    @property
    def pulse_width(self) -> int: ...


class MARKCONTROL(Message):
    @property
    def mark(self) -> Mark: ...

    @property
    def enable_disable(self) -> Enable: ...

    @property
    def polarity(self) -> Polarity: ...

    @property
    def time_bias(self) -> int: ...

    @property
    def time_guard(self) -> int: ...


class MARK2TIME(Message):
    @property
    def week(self) -> int: ...

    @property
    def seconds(self) -> float: ...

    @property
    def offset(self) -> float: ...

    @property
    def offset_std(self) -> float: ...

    @property
    def utc_offset(self) -> float: ...

    @property
    def status(self) -> ClockModelStatus: ...


class RANGEGPSL1_obs_Field(Field):
    @property
    def sv_prn(self) -> int: ...

    @property
    def sv_freq(self) -> int: ...

    @property
    def psr(self) -> float: ...

    @property
    def sd_psr(self) -> float: ...

    @property
    def adr(self) -> float: ...

    @property
    def sd_adr(self) -> float: ...

    @property
    def dop(self) -> float: ...

    @property
    def C_No(self) -> float: ...

    @property
    def lock_time(self) -> float: ...

    @property
    def c_status(self) -> int: ...


class RANGEGPSL1(Message):
    @property
    def obs(self) -> list[RANGEGPSL1_obs_Field]: ...


class GLOALMANAC_sat_alm_data_Field(Field):
    @property
    def weeks(self) -> int: ...

    @property
    def milliseconds(self) -> int: ...

    @property
    def slot(self) -> int: ...

    @property
    def frequency(self) -> int: ...

    @property
    def sat_type(self) -> int: ...

    @property
    def health(self) -> int: ...

    @property
    def t_lambda_n(self) -> float: ...

    @property
    def lambda_n(self) -> float: ...

    @property
    def delta_i(self) -> float: ...

    @property
    def ecc(self) -> float: ...

    @property
    def arg_perig(self) -> float: ...

    @property
    def delta_t(self) -> float: ...

    @property
    def delta_td(self) -> float: ...

    @property
    def tau(self) -> float: ...


class GLOALMANAC(Message):
    @property
    def sat_alm_data(self) -> list[GLOALMANAC_sat_alm_data_Field]: ...


class GLOCLOCK(Message):
    @property
    def nominal_offset(self) -> int: ...

    @property
    def residual_offset(self) -> float: ...

    @property
    def residual_offset_var(self) -> float: ...

    @property
    def sat_type(self) -> int: ...

    @property
    def n4(self) -> int: ...

    @property
    def tau_gps(self) -> float: ...

    @property
    def na(self) -> int: ...

    @property
    def tau_c(self) -> float: ...

    @property
    def b1(self) -> float: ...

    @property
    def b2(self) -> float: ...

    @property
    def kp(self) -> int: ...


class GLORAWALM_strings_Field(Field):
    @property
    def string(self) -> list[int]: ...

    @property
    def GLORAWALM_reserved(self) -> int: ...


class GLORAWALM(Message):
    @property
    def weeks(self) -> int: ...

    @property
    def milliseconds(self) -> int: ...

    @property
    def strings(self) -> list[GLORAWALM_strings_Field]: ...


class GLORAWFRAME_raw_string_Field(Field):
    @property
    def string(self) -> list[int]: ...

    @property
    def GLORAWFRAME_reserved(self) -> int: ...


class GLORAWFRAME(Message):
    @property
    def frame_number(self) -> int: ...

    @property
    def sloto(self) -> int: ...

    @property
    def freqo(self) -> int: ...

    @property
    def weeks(self) -> int: ...

    @property
    def milliseconds(self) -> int: ...

    @property
    def frame_decoder_number(self) -> int: ...

    @property
    def signal_channel_number(self) -> int: ...

    @property
    def raw_string(self) -> list[GLORAWFRAME_raw_string_Field]: ...


class GLORAWSTRING(Message):
    @property
    def slot(self) -> int: ...

    @property
    def freq(self) -> int: ...

    @property
    def string(self) -> list[int]: ...

    @property
    def GLORAWSTRING_reserved(self) -> int: ...


class GLOEPHEMERIS(Message):
    @property
    def sloto(self) -> int: ...

    @property
    def freqo(self) -> int: ...

    @property
    def sat_type(self) -> int: ...

    @property
    def false_iod(self) -> int: ...

    @property
    def ephem_week(self) -> int: ...

    @property
    def ephem_time(self) -> int: ...

    @property
    def time_offset(self) -> int: ...

    @property
    def nt(self) -> int: ...

    @property
    def GLOEPHEMERIS_reserved(self) -> int: ...

    @property
    def GLOEPHEMERIS_reserved_9(self) -> int: ...

    @property
    def issue(self) -> int: ...

    @property
    def broadcast_health(self) -> int: ...

    @property
    def pos_x(self) -> float: ...

    @property
    def pos_y(self) -> float: ...

    @property
    def pos_z(self) -> float: ...

    @property
    def vel_x(self) -> float: ...

    @property
    def vel_y(self) -> float: ...

    @property
    def vel_z(self) -> float: ...

    @property
    def ls_acc_x(self) -> float: ...

    @property
    def ls_acc_y(self) -> float: ...

    @property
    def ls_acc_z(self) -> float: ...

    @property
    def tau(self) -> float: ...

    @property
    def delta_tau(self) -> float: ...

    @property
    def gamma(self) -> float: ...

    @property
    def tk(self) -> int: ...

    @property
    def p(self) -> int: ...

    @property
    def ft(self) -> int: ...

    @property
    def age(self) -> int: ...

    @property
    def flags(self) -> int: ...


class GLOECUTOFF(Message):
    @property
    def elevation_cutoff_angle(self) -> float: ...


class GLORAWEPHEM_glo_raw_ephem_Field(Field):
    @property
    def string(self) -> list[int]: ...

    @property
    def GLORAWEPHEM_reserved(self) -> int: ...


class GLORAWEPHEM(Message):
    @property
    def sloto(self) -> int: ...

    @property
    def freqo(self) -> int: ...

    @property
    def signal_channel_number(self) -> int: ...

    @property
    def weeks(self) -> int: ...

    @property
    def milliseconds(self) -> int: ...

    @property
    def glo_raw_ephem(self) -> list[GLORAWEPHEM_glo_raw_ephem_Field]: ...


class FORCEGPSL2CODE(Message):
    @property
    def code_type(self) -> L2CodeType: ...


class CNOUPDATE(Message):
    @property
    def c_no_update_rate(self) -> CNoUpdateRate: ...


class RAWSBASFRAME(Message):
    @property
    def frame_decoder_num(self) -> int: ...

    @property
    def prn(self) -> int: ...

    @property
    def waas_msg_id(self) -> int: ...

    @property
    def raw_frame_data(self) -> list[int]: ...

    @property
    def signal_channel_num(self) -> int: ...


class SBAS0(Message):
    @property
    def prn(self) -> int: ...


class SBAS1(Message):
    @property
    def prn(self) -> int: ...

    @property
    def prn_mask(self) -> list[int]: ...

    @property
    def iodp(self) -> int: ...


class SBAS10(Message):
    @property
    def prn(self) -> int: ...

    @property
    def brrc(self) -> int: ...

    @property
    def cltc_lsb(self) -> int: ...

    @property
    def cltc_v1(self) -> int: ...

    @property
    def iltc_v1(self) -> int: ...

    @property
    def cltc_v0(self) -> int: ...

    @property
    def iltc_v0(self) -> int: ...

    @property
    def cgeo_lsb(self) -> int: ...

    @property
    def cgeo_v(self) -> int: ...

    @property
    def igeo(self) -> int: ...

    @property
    def cer(self) -> int: ...

    @property
    def ciono_step(self) -> int: ...

    @property
    def iiono(self) -> int: ...

    @property
    def ciono_ramp(self) -> int: ...

    @property
    def rssudre(self) -> int: ...

    @property
    def rss_iono(self) -> int: ...

    @property
    def spare_bits(self) -> list[int]: ...


class SBAS17_items_Field(Field):
    @property
    def data_id(self) -> int: ...

    @property
    def prn_3(self) -> int: ...

    @property
    def health(self) -> int: ...

    @property
    def x(self) -> int: ...

    @property
    def y(self) -> int: ...

    @property
    def z(self) -> int: ...

    @property
    def x_vel(self) -> int: ...

    @property
    def y_vel(self) -> int: ...

    @property
    def z_vel(self) -> int: ...


class SBAS17(Message):
    @property
    def prn(self) -> int: ...

    @property
    def items(self) -> list[SBAS17_items_Field]: ...

    @property
    def t0(self) -> int: ...


class SBAS18(Message):
    @property
    def prn(self) -> int: ...

    @property
    def num_bands(self) -> int: ...

    @property
    def band_num(self) -> int: ...

    @property
    def iodi(self) -> int: ...

    @property
    def igp_mask(self) -> list[int]: ...

    @property
    def spare_bit(self) -> int: ...


class SBAS2(Message):
    @property
    def prn(self) -> int: ...

    @property
    def iodf(self) -> int: ...

    @property
    def iodp(self) -> int: ...

    @property
    def prc(self) -> list[int]: ...

    @property
    def udrei(self) -> list[int]: ...


class SBAS24(Message):
    @property
    def prn(self) -> int: ...

    @property
    def prc(self) -> list[int]: ...

    @property
    def udrei(self) -> list[int]: ...

    @property
    def iodp(self) -> int: ...

    @property
    def block_id(self) -> int: ...

    @property
    def iodf(self) -> int: ...

    @property
    def spare(self) -> int: ...

    @property
    def velocity_code(self) -> int: ...

    @property
    def prn_mask_number1(self) -> int: ...

    @property
    def iode1(self) -> int: ...

    @property
    def dx1(self) -> int: ...

    @property
    def dy1(self) -> int: ...

    @property
    def dz1(self) -> int: ...

    @property
    def a_f01(self) -> int: ...

    @property
    def prn_mask_number2(self) -> int: ...

    @property
    def iode2(self) -> int: ...

    @property
    def dx2or_ddx(self) -> int: ...

    @property
    def dy2or_ddy(self) -> int: ...

    @property
    def dz2or_ddz(self) -> int: ...

    @property
    def a_f02ora_f1(self) -> int: ...

    @property
    def tod(self) -> int: ...

    @property
    def iodp_21(self) -> int: ...

    @property
    def spare_22(self) -> int: ...


class SBAS25(Message):
    @property
    def prn(self) -> int: ...

    @property
    def velocity_code(self) -> int: ...

    @property
    def prn_mask_number1(self) -> int: ...

    @property
    def iode1(self) -> int: ...

    @property
    def dx1(self) -> int: ...

    @property
    def dy1(self) -> int: ...

    @property
    def dz1(self) -> int: ...

    @property
    def a_f01(self) -> int: ...

    @property
    def prn_mask_number2(self) -> int: ...

    @property
    def iode2(self) -> int: ...

    @property
    def dx2or_ddx(self) -> int: ...

    @property
    def dy2or_ddy(self) -> int: ...

    @property
    def dz2or_ddz(self) -> int: ...

    @property
    def a_f02ora_f1(self) -> int: ...

    @property
    def tod(self) -> int: ...

    @property
    def iodp(self) -> int: ...

    @property
    def spare(self) -> int: ...

    @property
    def velocity_code_17(self) -> int: ...

    @property
    def prn_mask_number1_18(self) -> int: ...

    @property
    def iode1_19(self) -> int: ...

    @property
    def dx1_20(self) -> int: ...

    @property
    def dy1_21(self) -> int: ...

    @property
    def dz1_22(self) -> int: ...

    @property
    def a_f01_23(self) -> int: ...

    @property
    def prn_mask_number2_24(self) -> int: ...

    @property
    def iode2_25(self) -> int: ...

    @property
    def dx2or_ddx_26(self) -> int: ...

    @property
    def dy2or_ddy_27(self) -> int: ...

    @property
    def dz2or_ddz_28(self) -> int: ...

    @property
    def a_f02ora_f1_29(self) -> int: ...

    @property
    def tod_30(self) -> int: ...

    @property
    def iodp_31(self) -> int: ...

    @property
    def spare_32(self) -> int: ...


class SBAS26_grid_point_data_Field(Field):
    @property
    def igpvde(self) -> int: ...

    @property
    def givei(self) -> int: ...


class SBAS26(Message):
    @property
    def prn(self) -> int: ...

    @property
    def band_num(self) -> int: ...

    @property
    def block_id(self) -> int: ...

    @property
    def grid_point_data(self) -> list[SBAS26_grid_point_data_Field]: ...

    @property
    def iodi(self) -> int: ...

    @property
    def spare_bits(self) -> int: ...


class SBAS3(Message):
    @property
    def prn(self) -> int: ...

    @property
    def iodf(self) -> int: ...

    @property
    def iodp(self) -> int: ...

    @property
    def prc(self) -> list[int]: ...

    @property
    def udrei(self) -> list[int]: ...


class SBAS4(Message):
    @property
    def prn(self) -> int: ...

    @property
    def iodf(self) -> int: ...

    @property
    def iodp(self) -> int: ...

    @property
    def prc(self) -> list[int]: ...

    @property
    def udrei(self) -> list[int]: ...


class SBAS5(Message):
    @property
    def prn(self) -> int: ...

    @property
    def iodf(self) -> int: ...

    @property
    def iodp(self) -> int: ...

    @property
    def prc(self) -> list[int]: ...

    @property
    def udrei(self) -> list[int]: ...


class SBAS7(Message):
    @property
    def prn(self) -> int: ...

    @property
    def system_latency(self) -> int: ...

    @property
    def iodp(self) -> int: ...

    @property
    def spare_bits(self) -> int: ...

    @property
    def degradation_factor(self) -> list[int]: ...


class SBAS9(Message):
    @property
    def prn(self) -> int: ...

    @property
    def iodn(self) -> int: ...

    @property
    def t0(self) -> int: ...

    @property
    def ura(self) -> int: ...

    @property
    def x(self) -> float: ...

    @property
    def y(self) -> float: ...

    @property
    def z(self) -> float: ...

    @property
    def x_vel(self) -> float: ...

    @property
    def y_vel(self) -> float: ...

    @property
    def z_vel(self) -> float: ...

    @property
    def x_accel(self) -> float: ...

    @property
    def y_accel(self) -> float: ...

    @property
    def z_accel(self) -> float: ...

    @property
    def af0(self) -> float: ...

    @property
    def af1(self) -> float: ...


class SBASECUTOFF(Message):
    @property
    def elevation_cutoff_angle(self) -> float: ...


class DLLTIMECONST(Message):
    @property
    def signal_type(self) -> SignalType: ...

    @property
    def time_const_sec(self) -> int: ...


class SATVIS2_sat_vis_list_Field(Field):
    @property
    def id(self) -> SatelliteId: ...

    @property
    def sat_health(self) -> int: ...

    @property
    def elevation(self) -> float: ...

    @property
    def azimuth(self) -> float: ...

    @property
    def true_doppler(self) -> float: ...

    @property
    def apparent_doppler(self) -> float: ...


class SATVIS2(Message):
    @property
    def system_type(self) -> SystemType: ...

    @property
    def is_sat_vis_valid(self) -> bool: ...

    @property
    def was_gnss_almanac_used(self) -> bool: ...

    @property
    def sat_vis_list(self) -> list[SATVIS2_sat_vis_list_Field]: ...


class RAWCNAVFRAME(Message):
    @property
    def sig_chan_num(self) -> int: ...

    @property
    def prn(self) -> int: ...

    @property
    def frame_id(self) -> int: ...

    @property
    def raw_frame_data(self) -> list[int]: ...


class MARK3TIME(Message):
    @property
    def week(self) -> int: ...

    @property
    def seconds(self) -> float: ...

    @property
    def offset(self) -> float: ...

    @property
    def offset_std(self) -> float: ...

    @property
    def utc_offset(self) -> float: ...

    @property
    def status(self) -> ClockModelStatus: ...


class MARK4TIME(Message):
    @property
    def week(self) -> int: ...

    @property
    def seconds(self) -> float: ...

    @property
    def offset(self) -> float: ...

    @property
    def offset_std(self) -> float: ...

    @property
    def utc_offset(self) -> float: ...

    @property
    def status(self) -> ClockModelStatus: ...


class GALECUTOFF(Message):
    @property
    def elevation_cutoff_angle(self) -> float: ...


class GALALMANAC(Message):
    @property
    def sat_id(self) -> int: ...

    @property
    def fnav_received(self) -> bool: ...

    @property
    def inav_received(self) -> bool: ...

    @property
    def e1_b_health(self) -> int: ...

    @property
    def e5a_health(self) -> int: ...

    @property
    def e5b_health(self) -> int: ...

    @property
    def GALALMANAC_reserved1(self) -> int: ...

    @property
    def io_da(self) -> int: ...

    @property
    def weeks(self) -> int: ...

    @property
    def milliseconds(self) -> int: ...

    @property
    def ecc(self) -> float: ...

    @property
    def omega_dot(self) -> float: ...

    @property
    def omega0(self) -> float: ...

    @property
    def omega(self) -> float: ...

    @property
    def m0(self) -> float: ...

    @property
    def af0(self) -> float: ...

    @property
    def af1(self) -> float: ...

    @property
    def delta_root_a(self) -> float: ...

    @property
    def delta_i(self) -> float: ...


class GALCLOCK(Message):
    @property
    def a0(self) -> float: ...

    @property
    def a1(self) -> float: ...

    @property
    def delta_tls(self) -> int: ...

    @property
    def tot(self) -> int: ...

    @property
    def w_nt(self) -> int: ...

    @property
    def w_nlsf(self) -> int: ...

    @property
    def dn(self) -> int: ...

    @property
    def delta_tlsf(self) -> int: ...

    @property
    def a0g(self) -> float: ...

    @property
    def a1g(self) -> float: ...

    @property
    def t0g(self) -> int: ...

    @property
    def wn0g(self) -> int: ...


class GALEPHEMERIS(Message):
    @property
    def sat_id(self) -> int: ...

    @property
    def fnav_received(self) -> bool: ...

    @property
    def inav_received(self) -> bool: ...

    @property
    def e1_b_health(self) -> int: ...

    @property
    def e5a_health(self) -> int: ...

    @property
    def e5b_health(self) -> int: ...

    @property
    def e1_bdvs(self) -> int: ...

    @property
    def e5a_dvs(self) -> int: ...

    @property
    def e5b_dvs(self) -> int: ...

    @property
    def inavsisa(self) -> int: ...

    @property
    def GALEPHEMERIS_reserved1(self) -> int: ...

    @property
    def iod_nav(self) -> int: ...

    @property
    def t0e(self) -> int: ...

    @property
    def root_a(self) -> float: ...

    @property
    def delta_n(self) -> float: ...

    @property
    def m0(self) -> float: ...

    @property
    def ecc(self) -> float: ...

    @property
    def omega(self) -> float: ...

    @property
    def cuc(self) -> float: ...

    @property
    def cus(self) -> float: ...

    @property
    def crc(self) -> float: ...

    @property
    def crs(self) -> float: ...

    @property
    def cic(self) -> float: ...

    @property
    def cis(self) -> float: ...

    @property
    def i0(self) -> float: ...

    @property
    def i_dot(self) -> float: ...

    @property
    def omega0(self) -> float: ...

    @property
    def omega_dot(self) -> float: ...

    @property
    def fnavt0c(self) -> int: ...

    @property
    def fnav_af0(self) -> float: ...

    @property
    def fnav_af1(self) -> float: ...

    @property
    def fnav_af2(self) -> float: ...

    @property
    def inavt0c(self) -> int: ...

    @property
    def inav_af0(self) -> float: ...

    @property
    def inav_af1(self) -> float: ...

    @property
    def inav_af2(self) -> float: ...

    @property
    def e1_e5a_bgd(self) -> float: ...

    @property
    def e1_e5b_bgd(self) -> float: ...


class GALFNAVRAWALMANAC(Message):
    @property
    def io_da(self) -> int: ...

    @property
    def w_na(self) -> int: ...

    @property
    def t0a(self) -> int: ...

    @property
    def raw_data(self) -> list[int]: ...


class GALFNAVRAWEPHEMERIS_raw_pages_Field(Field):
    @property
    def page(self) -> list[int]: ...

    @property
    def GALFNAVRAWEPHEMERIS_reserved(self) -> int: ...


class GALFNAVRAWEPHEMERIS(Message):
    @property
    def sat_id(self) -> int: ...

    @property
    def weeks(self) -> int: ...

    @property
    def milliseconds(self) -> int: ...

    @property
    def raw_pages(self) -> list[GALFNAVRAWEPHEMERIS_raw_pages_Field]: ...


class GALINAVRAWALMANAC(Message):
    @property
    def io_da(self) -> int: ...

    @property
    def w_na(self) -> int: ...

    @property
    def t0a(self) -> int: ...

    @property
    def raw_data(self) -> list[int]: ...


class GALINAVRAWEPHEMERIS_raw_words_Field(Field):
    @property
    def word(self) -> list[int]: ...


class GALINAVRAWEPHEMERIS(Message):
    @property
    def sat_id(self) -> int: ...

    @property
    def weeks(self) -> int: ...

    @property
    def milliseconds(self) -> int: ...

    @property
    def raw_words(self) -> list[GALINAVRAWEPHEMERIS_raw_words_Field]: ...


class GALIONO(Message):
    @property
    def ai0(self) -> float: ...

    @property
    def ai1(self) -> float: ...

    @property
    def ai2(self) -> float: ...

    @property
    def sf1(self) -> int: ...

    @property
    def sf2(self) -> int: ...

    @property
    def sf3(self) -> int: ...

    @property
    def sf4(self) -> int: ...

    @property
    def sf5(self) -> int: ...


class MARK1TIME(Message):
    @property
    def week(self) -> int: ...

    @property
    def seconds(self) -> float: ...

    @property
    def offset(self) -> float: ...

    @property
    def offset_std(self) -> float: ...

    @property
    def utc_offset(self) -> float: ...

    @property
    def status(self) -> ClockModelStatus: ...


class SETUTCLEAPSECONDS(Message):
    @property
    def seconds(self) -> int: ...

    @property
    def future_week_number(self) -> int: ...

    @property
    def future_day_number(self) -> int: ...

    @property
    def future_seconds(self) -> int: ...


class LBANDTRACKSTAT_l_band_chan_states_Field(Field):
    @property
    def beam_name(self) -> str: ...

    @property
    def assigned_frequency(self) -> int: ...

    @property
    def baud_rate(self) -> int: ...

    @property
    def service_id(self) -> int: ...

    @property
    def tracking_status(self) -> int: ...

    @property
    def LBANDTRACKSTAT_reserved(self) -> int: ...

    @property
    def doppler(self) -> float: ...

    @property
    def cn0(self) -> float: ...

    @property
    def phase_std_dev(self) -> float: ...

    @property
    def lock_time(self) -> float: ...

    @property
    def total_unique_word_bits(self) -> int: ...

    @property
    def bad_unique_word_bits(self) -> int: ...

    @property
    def bad_unique_words(self) -> int: ...

    @property
    def total_viterbi_symbols(self) -> int: ...

    @property
    def corrected_viterbi_syms(self) -> int: ...

    @property
    def ber(self) -> float: ...


class LBANDTRACKSTAT(Message):
    @property
    def l_band_chan_states(self) -> list[LBANDTRACKSTAT_l_band_chan_states_Field]: ...


class FORCEGLOL2CODE(Message):
    @property
    def l2_code_type(self) -> L2CodeType: ...


class SETTIMEBASE_backup_system_Field(Field):
    @property
    def system(self) -> TimingSystem: ...

    @property
    def time_out(self) -> int: ...


class SETTIMEBASE(Message):
    @property
    def primary_system(self) -> TimingSystem: ...

    @property
    def backup_system(self) -> list[SETTIMEBASE_backup_system_Field]: ...


class RANGECMP2(Message):
    @property
    def range_data(self) -> list[int]: ...


class GALINAVEPHEMERIS(Message):
    @property
    def sat_id(self) -> int: ...

    @property
    def e5b_health(self) -> int: ...

    @property
    def e5b_dvs(self) -> int: ...

    @property
    def GALINAVEPHEMERIS_reserved1(self) -> int: ...

    @property
    def GALINAVEPHEMERIS_reserved2(self) -> int: ...

    @property
    def e1b_health(self) -> int: ...

    @property
    def e1b_dvs(self) -> int: ...

    @property
    def GALINAVEPHEMERIS_reserved3(self) -> int: ...

    @property
    def GALINAVEPHEMERIS_reserved4(self) -> int: ...

    @property
    def io_dnav(self) -> int: ...

    @property
    def sisa(self) -> int: ...

    @property
    def inav_signal_type(self) -> int: ...

    @property
    def toe(self) -> Any: ...

    @property
    def toc(self) -> int: ...

    @property
    def m0(self) -> float: ...

    @property
    def delta_n(self) -> float: ...

    @property
    def ecc(self) -> float: ...

    @property
    def root_a(self) -> float: ...

    @property
    def i0(self) -> float: ...

    @property
    def i_dot(self) -> float: ...

    @property
    def omega0(self) -> float: ...

    @property
    def omega(self) -> float: ...

    @property
    def omega_dot(self) -> float: ...

    @property
    def cuc(self) -> float: ...

    @property
    def cus(self) -> float: ...

    @property
    def crc(self) -> float: ...

    @property
    def crs(self) -> float: ...

    @property
    def cic(self) -> float: ...

    @property
    def cis(self) -> float: ...

    @property
    def af0(self) -> float: ...

    @property
    def af1(self) -> float: ...

    @property
    def af2(self) -> float: ...

    @property
    def e1_e5a_bgd(self) -> float: ...

    @property
    def e1_e5b_bgd(self) -> float: ...


class GALFNAVEPHEMERIS(Message):
    @property
    def sat_id(self) -> int: ...

    @property
    def e5a_health(self) -> int: ...

    @property
    def e5a_dvs(self) -> int: ...

    @property
    def GALFNAVEPHEMERIS_reserved1(self) -> int: ...

    @property
    def GALFNAVEPHEMERIS_reserved2(self) -> int: ...

    @property
    def io_dnav(self) -> int: ...

    @property
    def sisa(self) -> int: ...

    @property
    def GALFNAVEPHEMERIS_reserved3(self) -> int: ...

    @property
    def toe(self) -> Any: ...

    @property
    def toc(self) -> int: ...

    @property
    def m0(self) -> float: ...

    @property
    def delta_n(self) -> float: ...

    @property
    def ecc(self) -> float: ...

    @property
    def root_a(self) -> float: ...

    @property
    def i0(self) -> float: ...

    @property
    def i_dot(self) -> float: ...

    @property
    def omega0(self) -> float: ...

    @property
    def omega(self) -> float: ...

    @property
    def omega_dot(self) -> float: ...

    @property
    def cuc(self) -> float: ...

    @property
    def cus(self) -> float: ...

    @property
    def crc(self) -> float: ...

    @property
    def crs(self) -> float: ...

    @property
    def cic(self) -> float: ...

    @property
    def cis(self) -> float: ...

    @property
    def af0(self) -> float: ...

    @property
    def af1(self) -> float: ...

    @property
    def af2(self) -> float: ...

    @property
    def e1_e5a_bgd(self) -> float: ...


class TRACKSV(Message):
    @property
    def system(self) -> SystemType: ...

    @property
    def sat_id(self) -> int: ...

    @property
    def condition(self) -> TrackSV: ...


class QZSSRAWSUBFRAME(Message):
    @property
    def satellite_id(self) -> int: ...

    @property
    def sub_frame_id(self) -> int: ...

    @property
    def raw_sub_frame_data(self) -> list[int]: ...

    @property
    def signal_channel_number(self) -> int: ...


class QZSSRAWEPHEM(Message):
    @property
    def satellite_id(self) -> int: ...

    @property
    def week(self) -> int: ...

    @property
    def toe(self) -> int: ...

    @property
    def subframe1(self) -> list[int]: ...

    @property
    def subframe2(self) -> list[int]: ...

    @property
    def subframe3(self) -> list[int]: ...


class QZSSEPHEMERIS(Message):
    @property
    def satellite_id(self) -> int: ...

    @property
    def tow(self) -> float: ...

    @property
    def health7(self) -> int: ...

    @property
    def iode1(self) -> int: ...

    @property
    def iode2(self) -> int: ...

    @property
    def wn(self) -> int: ...

    @property
    def zwn(self) -> int: ...

    @property
    def toe(self) -> float: ...

    @property
    def a(self) -> float: ...

    @property
    def delta_n(self) -> float: ...

    @property
    def m0(self) -> float: ...

    @property
    def ecc(self) -> float: ...

    @property
    def omega(self) -> float: ...

    @property
    def cuc(self) -> float: ...

    @property
    def cus(self) -> float: ...

    @property
    def crc(self) -> float: ...

    @property
    def crs(self) -> float: ...

    @property
    def cic(self) -> float: ...

    @property
    def cis(self) -> float: ...

    @property
    def i0(self) -> float: ...

    @property
    def i_dot(self) -> float: ...

    @property
    def omega0(self) -> float: ...

    @property
    def omega_dot(self) -> float: ...

    @property
    def iodc(self) -> int: ...

    @property
    def toc(self) -> float: ...

    @property
    def tgd(self) -> float: ...

    @property
    def af0(self) -> float: ...

    @property
    def af1(self) -> float: ...

    @property
    def af2(self) -> float: ...

    @property
    def anti_spoofing(self) -> bool: ...

    @property
    def n(self) -> float: ...

    @property
    def eph_var(self) -> float: ...

    @property
    def fit_interval(self) -> int: ...

    @property
    def char_as_int(self) -> int: ...

    @property
    def char_as_int_34(self) -> int: ...

    @property
    def char_as_int_35(self) -> int: ...


class QZSSRAWALMANAC_sub_frame_pages_Field(Field):
    @property
    def svid(self) -> int: ...

    @property
    def page_raw_data(self) -> list[int]: ...


class QZSSRAWALMANAC(Message):
    @property
    def weeks(self) -> int: ...

    @property
    def milliseconds(self) -> int: ...

    @property
    def sub_frame_pages(self) -> list[QZSSRAWALMANAC_sub_frame_pages_Field]: ...


class QZSSALMANAC_sv_alm_data_Field(Field):
    @property
    def prn(self) -> int: ...

    @property
    def wn(self) -> int: ...

    @property
    def toa(self) -> float: ...

    @property
    def ecc(self) -> float: ...

    @property
    def omega_dot(self) -> float: ...

    @property
    def omega0(self) -> float: ...

    @property
    def omega(self) -> float: ...

    @property
    def mo(self) -> float: ...

    @property
    def af0(self) -> float: ...

    @property
    def af1(self) -> float: ...

    @property
    def n(self) -> float: ...

    @property
    def a(self) -> float: ...

    @property
    def di(self) -> float: ...

    @property
    def health6(self) -> int: ...

    @property
    def health8(self) -> int: ...


class QZSSALMANAC(Message):
    @property
    def sv_alm_data(self) -> list[QZSSALMANAC_sv_alm_data_Field]: ...


class QZSSIONUTC(Message):
    @property
    def a0(self) -> float: ...

    @property
    def a1(self) -> float: ...

    @property
    def a2(self) -> float: ...

    @property
    def a3(self) -> float: ...

    @property
    def b0(self) -> float: ...

    @property
    def b1(self) -> float: ...

    @property
    def b2(self) -> float: ...

    @property
    def b3(self) -> float: ...

    @property
    def w_nt(self) -> int: ...

    @property
    def tot(self) -> int: ...

    @property
    def a0_10(self) -> float: ...

    @property
    def a1_11(self) -> float: ...

    @property
    def w_nlsf(self) -> int: ...

    @property
    def dn(self) -> int: ...

    @property
    def delta_tls(self) -> int: ...

    @property
    def delta_tlsf(self) -> int: ...

    @property
    def delta_tutc(self) -> int: ...


class AUTHCODES_auth_codes_Field(Field):
    @property
    def type(self) -> PlatformAuthCodeType: ...

    @property
    def valid(self) -> bool: ...

    @property
    def auth_code(self) -> str: ...


class AUTHCODES(Message):
    @property
    def signature_status(self) -> SignatureStatus: ...

    @property
    def auth_codes(self) -> list[AUTHCODES_auth_codes_Field]: ...


class QZSSECUTOFF(Message):
    @property
    def elevation_cutoff_angle(self) -> float: ...


class RTKTRACKINGCONTROL(Message):
    @property
    def mode(self) -> RTKTrackingControl: ...


class GALFNAVRAWPAGE(Message):
    @property
    def sig_chan_num(self) -> int: ...

    @property
    def sat_id(self) -> int: ...

    @property
    def raw_frame_data(self) -> list[int]: ...


class GALINAVRAWWORD(Message):
    @property
    def sig_chan_num(self) -> int: ...

    @property
    def sat_id(self) -> int: ...

    @property
    def signal_type(self) -> SignalType: ...

    @property
    def raw_frame_data(self) -> list[int]: ...


class SATXYZ2_sats_Field(Field):
    @property
    def system_type(self) -> SystemType: ...

    @property
    def id(self) -> SatelliteId: ...

    @property
    def x(self) -> float: ...

    @property
    def y(self) -> float: ...

    @property
    def z(self) -> float: ...

    @property
    def rb(self) -> float: ...

    @property
    def iono_corr(self) -> float: ...

    @property
    def tropo_corr(self) -> float: ...

    @property
    def dummy(self) -> float: ...

    @property
    def dummy_10(self) -> float: ...


class SATXYZ2(Message):
    @property
    def sats(self) -> list[SATXYZ2_sats_Field]: ...


class DOPPLERWINDOW(Message):
    @property
    def system(self) -> AssignSystem: ...

    @property
    def setting(self) -> DopplerWindowMode: ...

    @property
    def doppler_window(self) -> int: ...

    @property
    def center_frequency(self) -> int: ...


class APPROXPOSTIMEOUT(Message):
    @property
    def timeout_sec(self) -> int: ...


class QZSSRAWCNAVMESSAGE(Message):
    @property
    def sig_chan_num(self) -> int: ...

    @property
    def prn(self) -> int: ...

    @property
    def message_id(self) -> int: ...

    @property
    def raw_frame_data(self) -> list[int]: ...


class DATADECODESIGNAL(Message):
    @property
    def signal_type(self) -> SignalType: ...

    @property
    def data_decode_mode(self) -> Enable: ...


class BDSECUTOFF(Message):
    @property
    def elevation_cutoff_angle(self) -> float: ...


class BDSALMANAC(Message):
    @property
    def satellite_id(self) -> int: ...

    @property
    def wn(self) -> int: ...

    @property
    def toa(self) -> int: ...

    @property
    def root_a(self) -> float: ...

    @property
    def eccentricity(self) -> float: ...

    @property
    def omega(self) -> float: ...

    @property
    def m0(self) -> float: ...

    @property
    def omega0(self) -> float: ...

    @property
    def omega_dot(self) -> float: ...

    @property
    def delta_i(self) -> float: ...

    @property
    def a0(self) -> float: ...

    @property
    def a1(self) -> float: ...

    @property
    def health(self) -> int: ...


class BDSIONO(Message):
    @property
    def transmitting_satellite_id(self) -> int: ...

    @property
    def alpha0(self) -> float: ...

    @property
    def alpha1(self) -> float: ...

    @property
    def alpha2(self) -> float: ...

    @property
    def alpha3(self) -> float: ...

    @property
    def beta0(self) -> float: ...

    @property
    def beta1(self) -> float: ...

    @property
    def beta2(self) -> float: ...

    @property
    def beta3(self) -> float: ...


class BDSCLOCK(Message):
    @property
    def a0_utc(self) -> float: ...

    @property
    def a1_utc(self) -> float: ...

    @property
    def delta_tls(self) -> int: ...

    @property
    def w_nlsf(self) -> int: ...

    @property
    def dn(self) -> int: ...

    @property
    def delta_tlsf(self) -> int: ...

    @property
    def a0_gps(self) -> float: ...

    @property
    def a1_gps(self) -> float: ...

    @property
    def a0_gal(self) -> float: ...

    @property
    def a1_gal(self) -> float: ...

    @property
    def a0_glo(self) -> float: ...

    @property
    def a1_glo(self) -> float: ...


class EVENTOUTCONTROL(Message):
    @property
    def mark(self) -> Mark: ...

    @property
    def enable_disable(self) -> Enable: ...

    @property
    def polarity(self) -> Polarity: ...

    @property
    def active_period(self) -> int: ...

    @property
    def not_active_period(self) -> int: ...


class EVENTINCONTROL(Message):
    @property
    def mark(self) -> Mark: ...

    @property
    def event_in_enable(self) -> EventInEnable: ...

    @property
    def polarity(self) -> Polarity: ...

    @property
    def time_bias(self) -> int: ...

    @property
    def time_guard(self) -> int: ...


class RFINPUTGAIN(Message):
    @property
    def frequency(self) -> RFInputFrequency: ...

    @property
    def mode(self) -> RFInputGainMode: ...

    @property
    def gain(self) -> float: ...


class BDSRAWNAVSUBFRAME(Message):
    @property
    def signal_channel_number(self) -> int: ...

    @property
    def satellite_id(self) -> int: ...

    @property
    def bds_data_source(self) -> BDSDataSource: ...

    @property
    def subframe_id(self) -> int: ...

    @property
    def raw_subframe_data(self) -> list[int]: ...


class BDSEPHEMERIS(Message):
    @property
    def satellite_id(self) -> int: ...

    @property
    def wn(self) -> int: ...

    @property
    def ura(self) -> float: ...

    @property
    def sat_h1(self) -> int: ...

    @property
    def tgd1(self) -> float: ...

    @property
    def tgd2(self) -> float: ...

    @property
    def iodc(self) -> int: ...

    @property
    def toc(self) -> int: ...

    @property
    def a0(self) -> float: ...

    @property
    def a1(self) -> float: ...

    @property
    def a2(self) -> float: ...

    @property
    def iode(self) -> int: ...

    @property
    def toe(self) -> int: ...

    @property
    def root_a(self) -> float: ...

    @property
    def eccentricity(self) -> float: ...

    @property
    def omega(self) -> float: ...

    @property
    def delta_n(self) -> float: ...

    @property
    def m0(self) -> float: ...

    @property
    def omega0(self) -> float: ...

    @property
    def omega_dot(self) -> float: ...

    @property
    def i0(self) -> float: ...

    @property
    def i_dot(self) -> float: ...

    @property
    def cuc(self) -> float: ...

    @property
    def cus(self) -> float: ...

    @property
    def crc(self) -> float: ...

    @property
    def crs(self) -> float: ...

    @property
    def cic(self) -> float: ...

    @property
    def cis(self) -> float: ...


class ASSIGNLBANDBEAM(Message):
    @property
    def assign_mode(self) -> LBandAssign: ...

    @property
    def beam_name(self) -> str: ...

    @property
    def frequency(self) -> int: ...

    @property
    def baud_rate(self) -> int: ...

    @property
    def doppler_window(self) -> int: ...


class RANGECMP3(Message):
    @property
    def range_data(self) -> list[int]: ...


class ELEVATIONCUTOFF(Message):
    @property
    def system_type(self) -> SystemType: ...

    @property
    def elevation_cutoff_angle(self) -> float: ...

    @property
    def ELEVATIONCUTOFF_reserved(self) -> int: ...


class PPSCONTROL2(Message):
    @property
    def enable_disable(self) -> PPSEnable: ...

    @property
    def polarity(self) -> Polarity: ...

    @property
    def rate(self) -> float: ...

    @property
    def pulse_width(self) -> int: ...

    @property
    def estimated_error_limit(self) -> int: ...


class ITSPECTRALANALYSIS(Message):
    @property
    def data_source(self) -> SpectralAnalysisSource: ...

    @property
    def frequency(self) -> Frequency: ...

    @property
    def psd_update_period_ms(self) -> int: ...

    @property
    def fft_size(self) -> FFTSize: ...

    @property
    def psd_time_ave_window_sec(self) -> int: ...

    @property
    def psd_subcarrier_ave_window(self) -> int: ...


class ITPSDFINAL(Message):
    @property
    def status_word(self) -> int: ...

    @property
    def frequency_start_m_hz(self) -> float: ...

    @property
    def step_size_hz(self) -> float: ...

    @property
    def samples(self) -> list[int]: ...


class ITFILTTABLE_filter_coef_status_Field_nf_status_Field(Field):
    @property
    def enabled_9(self) -> Enable: ...

    @property
    def pfid(self) -> ProgFilterID: ...

    @property
    def mode(self) -> ProgFilterMode: ...

    @property
    def lower_cut_off_frequency(self) -> float: ...

    @property
    def higher_cut_off_frequency(self) -> float: ...

    @property
    def frequency_width(self) -> float: ...


class ITFILTTABLE_filter_coef_status_Field(Field):
    @property
    def frequency(self) -> Frequency: ...

    @property
    def encoder_id(self) -> int: ...

    @property
    def ddc_filter_type(self) -> DDCFilterType: ...

    @property
    def status(self) -> int: ...

    @property
    def enabled(self) -> Enable: ...

    @property
    def lower_cut_off_freqency(self) -> float: ...

    @property
    def higher_cut_off_freqency(self) -> float: ...

    @property
    def nf_status(self) -> list[ITFILTTABLE_filter_coef_status_Field_nf_status_Field]: ...


class ITFILTTABLE(Message):
    @property
    def filter_coef_status(self) -> list[ITFILTTABLE_filter_coef_status_Field]: ...


class ITBANDPASSCONFIG(Message):
    @property
    def frequency(self) -> Frequency: ...

    @property
    def enable(self) -> Enable: ...

    @property
    def cut_off_frequency(self) -> float: ...


class ITPROGFILTCONFIG(Message):
    @property
    def frequency(self) -> Frequency: ...

    @property
    def pfid(self) -> ProgFilterID: ...

    @property
    def enable(self) -> Enable: ...

    @property
    def mode(self) -> ProgFilterMode: ...

    @property
    def cut_off_frequency(self) -> float: ...

    @property
    def notch_width(self) -> float: ...


class ITBANDPASSBANK_bpf_bank_entries_Field(Field):
    @property
    def frequency(self) -> Frequency: ...

    @property
    def min_lower_cut_off_frequency(self) -> float: ...

    @property
    def max_lower_cut_off_frequency(self) -> float: ...

    @property
    def min_higher_cut_off_frequency(self) -> float: ...

    @property
    def max_higher_cut_off_frequency(self) -> float: ...

    @property
    def frequency_step(self) -> float: ...


class ITBANDPASSBANK(Message):
    @property
    def bpf_bank_entries(self) -> list[ITBANDPASSBANK_bpf_bank_entries_Field]: ...


class ITPROGFILTBANK_nf_bank_entries_Field_nf_parameters_Field(Field):
    @property
    def nf_mode(self) -> ProgFilterMode: ...

    @property
    def min_lower_cut_off_frequency(self) -> float: ...

    @property
    def max_lower_cut_off_frequency(self) -> float: ...

    @property
    def min_higher_cut_off_frequency(self) -> float: ...

    @property
    def max_higher_cut_off_frequency(self) -> float: ...

    @property
    def frequency_step(self) -> float: ...

    @property
    def notch_width(self) -> float: ...


class ITPROGFILTBANK_nf_bank_entries_Field(Field):
    @property
    def frequency(self) -> Frequency: ...

    @property
    def nf_parameters(self) -> list[ITPROGFILTBANK_nf_bank_entries_Field_nf_parameters_Field]: ...


class ITPROGFILTBANK(Message):
    @property
    def nf_bank_entries(self) -> list[ITPROGFILTBANK_nf_bank_entries_Field]: ...


class ITFRONTENDMODE(Message):
    @property
    def freq(self) -> RFInputFrequency: ...

    @property
    def mode(self) -> ITBFrontEndMode: ...


class RANGECMP4(Message):
    @property
    def range_data(self) -> list[int]: ...


class RANGECMP5(Message):
    @property
    def range_data(self) -> list[int]: ...


class ITPSDDETECT(Message):
    @property
    def status_word(self) -> int: ...

    @property
    def frequency_start_m_hz(self) -> float: ...

    @property
    def step_size_hz(self) -> float: ...

    @property
    def samples(self) -> list[int]: ...


class ITDETECTSTATUS_interference_statuses_Field(Field):
    @property
    def frequency(self) -> RFInputFrequency: ...

    @property
    def int_detect_method(self) -> ITIntDetectMethod: ...

    @property
    def parameter1(self) -> float: ...

    @property
    def parameter2(self) -> float: ...

    @property
    def parameter3(self) -> float: ...

    @property
    def parameter4(self) -> float: ...

    @property
    def severity1(self) -> int: ...

    @property
    def severity2(self) -> int: ...

    @property
    def ITDETECTSTATUS_reserved3(self) -> int: ...


class ITDETECTSTATUS(Message):
    @property
    def interference_statuses(self) -> list[ITDETECTSTATUS_interference_statuses_Field]: ...


class NAVICRAWSUBFRAME(Message):
    @property
    def sig_chan_num(self) -> int: ...

    @property
    def sat_id(self) -> int: ...

    @property
    def frame_id(self) -> int: ...

    @property
    def raw_subframe_data(self) -> list[int]: ...


class NAVICALMANAC(Message):
    @property
    def w_na(self) -> int: ...

    @property
    def ecc(self) -> float: ...

    @property
    def toa(self) -> int: ...

    @property
    def di(self) -> float: ...

    @property
    def omega_dot(self) -> float: ...

    @property
    def root_a(self) -> float: ...

    @property
    def omega0(self) -> float: ...

    @property
    def omega(self) -> float: ...

    @property
    def m0(self) -> float: ...

    @property
    def af0(self) -> float: ...

    @property
    def af1(self) -> float: ...

    @property
    def alm_svid(self) -> int: ...

    @property
    def inter_sig_corr(self) -> int: ...

    @property
    def spare(self) -> int: ...

    @property
    def svid(self) -> int: ...


class NAVICEPHEMERIS(Message):
    @property
    def sat_id(self) -> int: ...

    @property
    def wn(self) -> int: ...

    @property
    def af0(self) -> float: ...

    @property
    def af1(self) -> float: ...

    @property
    def af2(self) -> float: ...

    @property
    def ura(self) -> int: ...

    @property
    def toc(self) -> int: ...

    @property
    def tgd(self) -> float: ...

    @property
    def delta_n(self) -> float: ...

    @property
    def iodec(self) -> int: ...

    @property
    def NAVICEPHEMERIS_reserved(self) -> int: ...

    @property
    def l5_health(self) -> int: ...

    @property
    def s_health(self) -> int: ...

    @property
    def cuc(self) -> float: ...

    @property
    def cus(self) -> float: ...

    @property
    def cic(self) -> float: ...

    @property
    def cis(self) -> float: ...

    @property
    def crc(self) -> float: ...

    @property
    def crs(self) -> float: ...

    @property
    def i_dot(self) -> float: ...

    @property
    def spare1(self) -> int: ...

    @property
    def m0(self) -> float: ...

    @property
    def toe(self) -> int: ...

    @property
    def ecc(self) -> float: ...

    @property
    def root_a(self) -> float: ...

    @property
    def omega0(self) -> float: ...

    @property
    def omega(self) -> float: ...

    @property
    def omega_dot(self) -> float: ...

    @property
    def i0(self) -> float: ...

    @property
    def spare2(self) -> int: ...

    @property
    def alert_flag(self) -> int: ...

    @property
    def auto_nav_flag(self) -> int: ...


class NAVICIONO(Message):
    @property
    def prnid(self) -> int: ...

    @property
    def alpha0(self) -> float: ...

    @property
    def alpha1(self) -> float: ...

    @property
    def alpha2(self) -> float: ...

    @property
    def alpha3(self) -> float: ...

    @property
    def beta0(self) -> float: ...

    @property
    def beta1(self) -> float: ...

    @property
    def beta2(self) -> float: ...

    @property
    def beta3(self) -> float: ...

    @property
    def spare(self) -> int: ...


class NAVICSYSCLOCK(Message):
    @property
    def prnid(self) -> int: ...

    @property
    def a0_utc(self) -> float: ...

    @property
    def a1_utc(self) -> float: ...

    @property
    def a2_utc(self) -> float: ...

    @property
    def delta_tls(self) -> int: ...

    @property
    def toutc(self) -> int: ...

    @property
    def w_noutc(self) -> int: ...

    @property
    def wnlsf(self) -> int: ...

    @property
    def dn(self) -> int: ...

    @property
    def delta_tlsf(self) -> int: ...

    @property
    def gnssid(self) -> int: ...

    @property
    def a0(self) -> float: ...

    @property
    def a1(self) -> float: ...

    @property
    def a2(self) -> float: ...

    @property
    def tot(self) -> int: ...

    @property
    def w_not(self) -> int: ...

    @property
    def spare(self) -> int: ...


class NAVICECUTOFF(Message):
    @property
    def elevation_cutoff_angle(self) -> float: ...


class ITDETECTCONFIG(Message):
    @property
    def frequency(self) -> ITFrequency: ...

    @property
    def ITDETECTCONFIG_reserved1(self) -> int: ...

    @property
    def ITDETECTCONFIG_reserved2(self) -> int: ...

    @property
    def ITDETECTCONFIG_reserved3(self) -> int: ...


class RAWSBASFRAME2(Message):
    @property
    def prn(self) -> int: ...

    @property
    def signal_channel_num(self) -> int: ...

    @property
    def sbas_signal(self) -> int: ...

    @property
    def preamble_type(self) -> int: ...

    @property
    def reserve(self) -> int: ...

    @property
    def waas_msg_id(self) -> int: ...

    @property
    def raw_frame_data(self) -> list[int]: ...


class FORCEGALE6CODE(Message):
    @property
    def type(self) -> GALE6CodeType: ...


class GALCNAVRAWPAGE(Message):
    @property
    def chan(self) -> int: ...

    @property
    def sat_id(self) -> int: ...

    @property
    def message_id(self) -> int: ...

    @property
    def page_id(self) -> int: ...

    @property
    def page(self) -> list[int]: ...


class QZSSCNAVRAWMESSAGE(Message):
    @property
    def sig_chan_num(self) -> int: ...

    @property
    def prn(self) -> int: ...

    @property
    def signal_type(self) -> SignalType: ...

    @property
    def message_id(self) -> int: ...

    @property
    def raw_frame_data(self) -> list[int]: ...


class GPSCNAVRAWMESSAGE(Message):
    @property
    def sig_chan_num(self) -> int: ...

    @property
    def prn(self) -> int: ...

    @property
    def signal_type(self) -> SignalType: ...

    @property
    def frame_id(self) -> int: ...

    @property
    def raw_frame_data(self) -> list[int]: ...


class SPRINKLERDATA(Message):
    @property
    def config(self) -> int: ...

    @property
    def start_sample_index(self) -> int: ...

    @property
    def samples(self) -> list[int]: ...


class SPRINKLERCONFIG(Message):
    @property
    def sprinker_channel(self) -> SprinklerChannel: ...

    @property
    def enable(self) -> Enable: ...

    @property
    def signal(self) -> Frequency: ...

    @property
    def sample_source(self) -> SpectralAnalysisSource: ...

    @property
    def num_samples_requested(self) -> int: ...

    @property
    def period_ms(self) -> int: ...

    @property
    def offset_ms(self) -> int: ...


class SPRINKLERDATAH(Message):
    @property
    def signal(self) -> Frequency: ...

    @property
    def freq_band(self) -> RFInputFrequency: ...

    @property
    def config(self) -> int: ...

    @property
    def rf_start_frequency(self) -> int: ...

    @property
    def sample_rate(self) -> int: ...

    @property
    def collection_status(self) -> SampleBufferCollectionStatus: ...

    @property
    def adc_pulse_width(self) -> int: ...

    @property
    def agc_pulse_modulus(self) -> int: ...

    @property
    def num_samples_collected(self) -> int: ...


class ITWARNINGCONFIG(Message):
    @property
    def level(self) -> int: ...

    @property
    def ITWARNINGCONFIG_reserved(self) -> int: ...


class TRACKSIGNAL(Message):
    @property
    def signal(self) -> TrackSignal: ...

    @property
    def enable(self) -> Enable: ...


class SKDETECTCONFIG(Message):
    @property
    def enable(self) -> Enable: ...

    @property
    def SKDETECTCONFIG_reserved0(self) -> int: ...

    @property
    def SKDETECTCONFIG_reserved1(self) -> int: ...


class SKCALIBRATESTATUS_calibration_results_Field(Field):
    @property
    def signal_type(self) -> SpoofDetectSignalType: ...

    @property
    def mode(self) -> SpoofCalibrationCmdMode: ...

    @property
    def front_end_mode(self) -> ITBFrontEndMode: ...

    @property
    def result(self) -> SpoofCalibrationResult: ...

    @property
    def data(self) -> int: ...


class SKCALIBRATESTATUS(Message):
    @property
    def overall_status(self) -> SpoofCalibrationResult: ...

    @property
    def frequency_plan(self) -> FrequencyPlan: ...

    @property
    def calibration_results(self) -> list[SKCALIBRATESTATUS_calibration_results_Field]: ...


class SKCALIBRATE(Message):
    @property
    def mode(self) -> SpoofCalibrationCmdMode: ...

    @property
    def option(self) -> SpoofCalibrationCmdOption: ...

    @property
    def SKCALIBRATE_reserved(self) -> int: ...


class BDSBCNAV1EPHEMERIS(Message):
    @property
    def satellite_id(self) -> int: ...

    @property
    def wn(self) -> int: ...

    @property
    def sat_status(self) -> int: ...

    @property
    def iode(self) -> int: ...

    @property
    def toe(self) -> int: ...

    @property
    def sat_type(self) -> int: ...

    @property
    def delta_a(self) -> float: ...

    @property
    def a_dot(self) -> float: ...

    @property
    def delta_n(self) -> float: ...

    @property
    def n_dot(self) -> float: ...

    @property
    def m0(self) -> float: ...

    @property
    def eccentricity(self) -> float: ...

    @property
    def omega(self) -> float: ...

    @property
    def omega0(self) -> float: ...

    @property
    def i0(self) -> float: ...

    @property
    def omega_dot(self) -> float: ...

    @property
    def i_dot(self) -> float: ...

    @property
    def cis(self) -> float: ...

    @property
    def cic(self) -> float: ...

    @property
    def crs(self) -> float: ...

    @property
    def crc(self) -> float: ...

    @property
    def cus(self) -> float: ...

    @property
    def cuc(self) -> float: ...

    @property
    def iodc(self) -> int: ...

    @property
    def toc(self) -> int: ...

    @property
    def a0(self) -> float: ...

    @property
    def a1(self) -> float: ...

    @property
    def a2(self) -> float: ...

    @property
    def tgdb1_cp(self) -> float: ...

    @property
    def tgdb2_ap(self) -> float: ...

    @property
    def iscb1_cd(self) -> float: ...

    @property
    def BDSBCNAV1EPHEMERIS_reserved(self) -> int: ...


class BDSBCNAV2EPHEMERIS(Message):
    @property
    def satellite_id(self) -> int: ...

    @property
    def wn(self) -> int: ...

    @property
    def sat_status(self) -> int: ...

    @property
    def iode(self) -> int: ...

    @property
    def toe(self) -> int: ...

    @property
    def sat_type(self) -> int: ...

    @property
    def delta_a(self) -> float: ...

    @property
    def a_dot(self) -> float: ...

    @property
    def delta_n(self) -> float: ...

    @property
    def n_dot(self) -> float: ...

    @property
    def m0(self) -> float: ...

    @property
    def eccentricity(self) -> float: ...

    @property
    def omega(self) -> float: ...

    @property
    def omega0(self) -> float: ...

    @property
    def i0(self) -> float: ...

    @property
    def omega_dot(self) -> float: ...

    @property
    def i_dot(self) -> float: ...

    @property
    def cis(self) -> float: ...

    @property
    def cic(self) -> float: ...

    @property
    def crs(self) -> float: ...

    @property
    def crc(self) -> float: ...

    @property
    def cus(self) -> float: ...

    @property
    def cuc(self) -> float: ...

    @property
    def iodc(self) -> int: ...

    @property
    def toc(self) -> int: ...

    @property
    def a0(self) -> float: ...

    @property
    def a1(self) -> float: ...

    @property
    def a2(self) -> float: ...

    @property
    def tgdb1_cp(self) -> float: ...

    @property
    def tgdb2_ap(self) -> float: ...

    @property
    def iscb2ad(self) -> float: ...

    @property
    def BDSBCNAV2EPHEMERIS_reserved(self) -> int: ...


class BDSBCNAV1RAWMESSAGE(Message):
    @property
    def sig_chan_num(self) -> int: ...

    @property
    def prn(self) -> int: ...

    @property
    def page_id(self) -> int: ...

    @property
    def subframe1_data(self) -> list[int]: ...

    @property
    def subframe2_data(self) -> list[int]: ...

    @property
    def subframe3_data(self) -> list[int]: ...


class BDSBCNAV2RAWMESSAGE(Message):
    @property
    def sig_chan_num(self) -> int: ...

    @property
    def prn(self) -> int: ...

    @property
    def message_type(self) -> int: ...

    @property
    def raw_message_data(self) -> list[int]: ...


class BDSBCNAV3RAWMESSAGE(Message):
    @property
    def signal_channel(self) -> int: ...

    @property
    def satellite_id(self) -> int: ...

    @property
    def message_id(self) -> int: ...

    @property
    def raw_message_data(self) -> list[int]: ...

    @property
    def char_as_int(self) -> int: ...

    @property
    def char_as_int_5(self) -> int: ...


class BDSBCNAV3EPHEMERIS(Message):
    @property
    def satellite_id(self) -> int: ...

    @property
    def wn(self) -> int: ...

    @property
    def sat_status(self) -> int: ...

    @property
    def toe(self) -> int: ...

    @property
    def sat_type(self) -> int: ...

    @property
    def delta_a(self) -> float: ...

    @property
    def a_dot(self) -> float: ...

    @property
    def delta_n(self) -> float: ...

    @property
    def n_dot(self) -> float: ...

    @property
    def m0(self) -> float: ...

    @property
    def eccentricity(self) -> float: ...

    @property
    def omega(self) -> float: ...

    @property
    def omega0(self) -> float: ...

    @property
    def i0(self) -> float: ...

    @property
    def omega_dot(self) -> float: ...

    @property
    def i_dot(self) -> float: ...

    @property
    def cis(self) -> float: ...

    @property
    def cic(self) -> float: ...

    @property
    def crs(self) -> float: ...

    @property
    def crc(self) -> float: ...

    @property
    def cus(self) -> float: ...

    @property
    def cuc(self) -> float: ...

    @property
    def toc(self) -> int: ...

    @property
    def a0(self) -> float: ...

    @property
    def a1(self) -> float: ...

    @property
    def a2(self) -> float: ...

    @property
    def tgdb2b_i(self) -> float: ...

    @property
    def BDSBCNAV3EPHEMERIS_reserved(self) -> int: ...


class LOCKOUTSATELLITE(Message):
    @property
    def system(self) -> SystemType: ...

    @property
    def system_id(self) -> int: ...


class UNLOCKOUTSATELLITE(Message):
    @property
    def system(self) -> SystemType: ...

    @property
    def system_id(self) -> int: ...


class INSATT(Message):
    @property
    def week(self) -> int: ...

    @property
    def seconds(self) -> float: ...

    @property
    def roll(self) -> float: ...

    @property
    def pitch(self) -> float: ...

    @property
    def azimuth(self) -> float: ...

    @property
    def ins_solution_status(self) -> INSStatus: ...


class INSPOS(Message):
    @property
    def week(self) -> int: ...

    @property
    def seconds(self) -> float: ...

    @property
    def latitude(self) -> float: ...

    @property
    def longitude(self) -> float: ...

    @property
    def height(self) -> float: ...

    @property
    def ins_solution_status(self) -> INSStatus: ...


class INSSPD(Message):
    @property
    def week(self) -> int: ...

    @property
    def seconds(self) -> float: ...

    @property
    def ground_track(self) -> float: ...

    @property
    def horizontal_speed(self) -> float: ...

    @property
    def up_vel(self) -> float: ...

    @property
    def ins_solution_status(self) -> INSStatus: ...


class INSVEL(Message):
    @property
    def week(self) -> int: ...

    @property
    def seconds(self) -> float: ...

    @property
    def north_vel(self) -> float: ...

    @property
    def east_vel(self) -> float: ...

    @property
    def up_vel(self) -> float: ...

    @property
    def ins_solution_status(self) -> INSStatus: ...


class RAWIMU(Message):
    @property
    def gps_week(self) -> int: ...

    @property
    def gps_seconds(self) -> float: ...

    @property
    def imu_status(self) -> int: ...

    @property
    def accel_z(self) -> int: ...

    @property
    def accel_y(self) -> int: ...

    @property
    def accel_x(self) -> int: ...

    @property
    def gyro_z(self) -> int: ...

    @property
    def gyro_y(self) -> int: ...

    @property
    def gyro_x(self) -> int: ...


class INSATTS(Message):
    @property
    def week(self) -> int: ...

    @property
    def seconds(self) -> float: ...

    @property
    def roll(self) -> float: ...

    @property
    def pitch(self) -> float: ...

    @property
    def azimuth(self) -> float: ...

    @property
    def ins_solution_status(self) -> INSStatus: ...


class INSPOSS(Message):
    @property
    def week(self) -> int: ...

    @property
    def seconds(self) -> float: ...

    @property
    def latitude(self) -> float: ...

    @property
    def longitude(self) -> float: ...

    @property
    def height(self) -> float: ...

    @property
    def ins_solution_status(self) -> INSStatus: ...


class INSSPDS(Message):
    @property
    def week(self) -> int: ...

    @property
    def seconds(self) -> float: ...

    @property
    def ground_track(self) -> float: ...

    @property
    def horizontal_speed(self) -> float: ...

    @property
    def up_vel(self) -> float: ...

    @property
    def ins_solution_status(self) -> INSStatus: ...


class INSVELS(Message):
    @property
    def week(self) -> int: ...

    @property
    def seconds(self) -> float: ...

    @property
    def north_vel(self) -> float: ...

    @property
    def east_vel(self) -> float: ...

    @property
    def up_vel(self) -> float: ...

    @property
    def ins_solution_status(self) -> INSStatus: ...


class RAWIMUS(Message):
    @property
    def gps_week(self) -> int: ...

    @property
    def gps_seconds(self) -> float: ...

    @property
    def imu_status(self) -> int: ...

    @property
    def accel_z(self) -> int: ...

    @property
    def accel_y(self) -> int: ...

    @property
    def accel_x(self) -> int: ...

    @property
    def gyro_z(self) -> int: ...

    @property
    def gyro_y(self) -> int: ...

    @property
    def gyro_x(self) -> int: ...


class INSCOMMAND(Message):
    @property
    def command(self) -> INSCommand: ...


class INSZUPT(Message):
    @property
    def perform_zupt(self) -> bool: ...


class INSPVA(Message):
    @property
    def week(self) -> int: ...

    @property
    def seconds(self) -> float: ...

    @property
    def latitude(self) -> float: ...

    @property
    def longitude(self) -> float: ...

    @property
    def height(self) -> float: ...

    @property
    def north_vel(self) -> float: ...

    @property
    def east_vel(self) -> float: ...

    @property
    def up_vel(self) -> float: ...

    @property
    def roll(self) -> float: ...

    @property
    def pitch(self) -> float: ...

    @property
    def azimuth(self) -> float: ...

    @property
    def ins_solution_status(self) -> INSStatus: ...


class INSPVAS(Message):
    @property
    def week(self) -> int: ...

    @property
    def seconds(self) -> float: ...

    @property
    def latitude(self) -> float: ...

    @property
    def longitude(self) -> float: ...

    @property
    def height(self) -> float: ...

    @property
    def north_vel(self) -> float: ...

    @property
    def east_vel(self) -> float: ...

    @property
    def up_vel(self) -> float: ...

    @property
    def roll(self) -> float: ...

    @property
    def pitch(self) -> float: ...

    @property
    def azimuth(self) -> float: ...

    @property
    def ins_solution_status(self) -> INSStatus: ...


class CORRIMUDATA(Message):
    @property
    def week(self) -> int: ...

    @property
    def seconds(self) -> float: ...

    @property
    def corr_wb_ib(self) -> list[float]: ...

    @property
    def corr_fb(self) -> list[float]: ...


class CORRIMUDATAS(Message):
    @property
    def week(self) -> int: ...

    @property
    def seconds(self) -> float: ...

    @property
    def corr_wb_ib(self) -> list[float]: ...

    @property
    def corr_fb(self) -> list[float]: ...


class SETINITAZIMUTH(Message):
    @property
    def azimuth(self) -> float: ...

    @property
    def azimuth_std_dev(self) -> float: ...


class MARK1PVA(Message):
    @property
    def week(self) -> int: ...

    @property
    def seconds(self) -> float: ...

    @property
    def latitude(self) -> float: ...

    @property
    def longitude(self) -> float: ...

    @property
    def height(self) -> float: ...

    @property
    def north_vel(self) -> float: ...

    @property
    def east_vel(self) -> float: ...

    @property
    def up_vel(self) -> float: ...

    @property
    def roll(self) -> float: ...

    @property
    def pitch(self) -> float: ...

    @property
    def azimuth(self) -> float: ...

    @property
    def ins_solution_status(self) -> INSStatus: ...


class MARK2PVA(Message):
    @property
    def week(self) -> int: ...

    @property
    def seconds(self) -> float: ...

    @property
    def latitude(self) -> float: ...

    @property
    def longitude(self) -> float: ...

    @property
    def height(self) -> float: ...

    @property
    def north_vel(self) -> float: ...

    @property
    def east_vel(self) -> float: ...

    @property
    def up_vel(self) -> float: ...

    @property
    def roll(self) -> float: ...

    @property
    def pitch(self) -> float: ...

    @property
    def azimuth(self) -> float: ...

    @property
    def ins_solution_status(self) -> INSStatus: ...


class MARK3PVA(Message):
    @property
    def week(self) -> int: ...

    @property
    def seconds(self) -> float: ...

    @property
    def latitude(self) -> float: ...

    @property
    def longitude(self) -> float: ...

    @property
    def height(self) -> float: ...

    @property
    def north_vel(self) -> float: ...

    @property
    def east_vel(self) -> float: ...

    @property
    def up_vel(self) -> float: ...

    @property
    def roll(self) -> float: ...

    @property
    def pitch(self) -> float: ...

    @property
    def azimuth(self) -> float: ...

    @property
    def ins_solution_status(self) -> INSStatus: ...


class MARK4PVA(Message):
    @property
    def week(self) -> int: ...

    @property
    def seconds(self) -> float: ...

    @property
    def latitude(self) -> float: ...

    @property
    def longitude(self) -> float: ...

    @property
    def height(self) -> float: ...

    @property
    def north_vel(self) -> float: ...

    @property
    def east_vel(self) -> float: ...

    @property
    def up_vel(self) -> float: ...

    @property
    def roll(self) -> float: ...

    @property
    def pitch(self) -> float: ...

    @property
    def azimuth(self) -> float: ...

    @property
    def ins_solution_status(self) -> INSStatus: ...


class ALIGNMENTMODE(Message):
    @property
    def alignment_mode(self) -> AlignmentMode: ...


class TILTDATA(Message):
    @property
    def status(self) -> int: ...

    @property
    def x_accel(self) -> float: ...

    @property
    def y_accel(self) -> float: ...

    @property
    def avg_x_incl(self) -> float: ...

    @property
    def x_incl(self) -> float: ...

    @property
    def y_incl(self) -> float: ...

    @property
    def avg_y_incl(self) -> float: ...

    @property
    def ulong(self) -> int: ...


class TILTFILTER(Message):
    @property
    def enable(self) -> Enable: ...

    @property
    def antenna_height(self) -> float: ...

    @property
    def TILTFILTER_reserved1(self) -> int: ...

    @property
    def TILTFILTER_reserved2(self) -> int: ...


class TILTZERO(Message):
    @property
    def tilt_zero_action(self) -> TiltZeroAction: ...


class TAGNEXTMARK(Message):
    @property
    def mark(self) -> Mark: ...

    @property
    def tag(self) -> int: ...


class TAGGEDMARK1PVA(Message):
    @property
    def week(self) -> int: ...

    @property
    def seconds(self) -> float: ...

    @property
    def latitude(self) -> float: ...

    @property
    def longitude(self) -> float: ...

    @property
    def height(self) -> float: ...

    @property
    def north_vel(self) -> float: ...

    @property
    def east_vel(self) -> float: ...

    @property
    def up_vel(self) -> float: ...

    @property
    def roll(self) -> float: ...

    @property
    def pitch(self) -> float: ...

    @property
    def azimuth(self) -> float: ...

    @property
    def ins_solution_status(self) -> INSStatus: ...

    @property
    def tag_id(self) -> int: ...


class TAGGEDMARK2PVA(Message):
    @property
    def week(self) -> int: ...

    @property
    def seconds(self) -> float: ...

    @property
    def latitude(self) -> float: ...

    @property
    def longitude(self) -> float: ...

    @property
    def height(self) -> float: ...

    @property
    def north_vel(self) -> float: ...

    @property
    def east_vel(self) -> float: ...

    @property
    def up_vel(self) -> float: ...

    @property
    def roll(self) -> float: ...

    @property
    def pitch(self) -> float: ...

    @property
    def azimuth(self) -> float: ...

    @property
    def ins_solution_status(self) -> INSStatus: ...

    @property
    def tag_id(self) -> int: ...


class SETIMUSPECS(Message):
    @property
    def data_rate(self) -> int: ...

    @property
    def accel_bias(self) -> float: ...

    @property
    def accel_vrw(self) -> float: ...

    @property
    def gyro_bias(self) -> float: ...

    @property
    def gyro_arw(self) -> float: ...

    @property
    def accel_scale_factor_error(self) -> int: ...

    @property
    def gyro_scale_factor_error(self) -> int: ...

    @property
    def data_latency(self) -> float: ...

    @property
    def scale_factor(self) -> ScaleFactor: ...


class IMURATEPVAS(Message):
    @property
    def week(self) -> int: ...

    @property
    def seconds(self) -> float: ...

    @property
    def latitude(self) -> float: ...

    @property
    def longitude(self) -> float: ...

    @property
    def height(self) -> float: ...

    @property
    def north_vel(self) -> float: ...

    @property
    def east_vel(self) -> float: ...

    @property
    def up_vel(self) -> float: ...

    @property
    def roll(self) -> float: ...

    @property
    def pitch(self) -> float: ...

    @property
    def azimuth(self) -> float: ...

    @property
    def ins_solution_status(self) -> INSStatus: ...


class INPUTGIMBALANGLE(Message):
    @property
    def euler(self) -> list[float]: ...

    @property
    def euler_stdev(self) -> list[float]: ...


class VARIABLELEVERARM(Message):
    @property
    def offsets(self) -> list[float]: ...

    @property
    def stdevs(self) -> list[float]: ...


class GIMBALLEDPVA(Message):
    @property
    def week(self) -> int: ...

    @property
    def seconds(self) -> float: ...

    @property
    def latitude(self) -> float: ...

    @property
    def longitude(self) -> float: ...

    @property
    def height(self) -> float: ...

    @property
    def north_vel(self) -> float: ...

    @property
    def east_vel(self) -> float: ...

    @property
    def up_vel(self) -> float: ...

    @property
    def roll(self) -> float: ...

    @property
    def pitch(self) -> float: ...

    @property
    def azimuth(self) -> float: ...

    @property
    def ins_solution_status(self) -> INSStatus: ...


class TAGGEDMARK3PVA(Message):
    @property
    def week(self) -> int: ...

    @property
    def seconds(self) -> float: ...

    @property
    def latitude(self) -> float: ...

    @property
    def longitude(self) -> float: ...

    @property
    def height(self) -> float: ...

    @property
    def north_vel(self) -> float: ...

    @property
    def east_vel(self) -> float: ...

    @property
    def up_vel(self) -> float: ...

    @property
    def roll(self) -> float: ...

    @property
    def pitch(self) -> float: ...

    @property
    def azimuth(self) -> float: ...

    @property
    def ins_solution_status(self) -> INSStatus: ...

    @property
    def tag_id(self) -> int: ...


class TAGGEDMARK4PVA(Message):
    @property
    def week(self) -> int: ...

    @property
    def seconds(self) -> float: ...

    @property
    def latitude(self) -> float: ...

    @property
    def longitude(self) -> float: ...

    @property
    def height(self) -> float: ...

    @property
    def north_vel(self) -> float: ...

    @property
    def east_vel(self) -> float: ...

    @property
    def up_vel(self) -> float: ...

    @property
    def roll(self) -> float: ...

    @property
    def pitch(self) -> float: ...

    @property
    def azimuth(self) -> float: ...

    @property
    def ins_solution_status(self) -> INSStatus: ...

    @property
    def tag_id(self) -> int: ...


class SETUPSENSOR(Message):
    @property
    def sensor_id(self) -> Sensor: ...

    @property
    def span_event_out(self) -> Mark: ...

    @property
    def span_evt_out_polarity(self) -> Polarity: ...

    @property
    def span_evt_out_active_pulse_ms(self) -> int: ...

    @property
    def span_event_in(self) -> Mark: ...

    @property
    def span_evt_in_enable_disable(self) -> EventInEnable: ...

    @property
    def span_evt_in_polarity(self) -> Polarity: ...

    @property
    def span_evt_in_time_bias_ns(self) -> int: ...

    @property
    def span_evt_in_time_guard_ms(self) -> int: ...


class TIMEDEVENTPULSE(Message):
    @property
    def selected_sensors(self) -> int: ...

    @property
    def target_week(self) -> int: ...

    @property
    def target_seconds(self) -> float: ...

    @property
    def tag(self) -> int: ...


class IMURATECORRIMUS(Message):
    @property
    def week(self) -> int: ...

    @property
    def seconds(self) -> float: ...

    @property
    def pitch(self) -> float: ...

    @property
    def roll(self) -> float: ...

    @property
    def azimuth(self) -> float: ...

    @property
    def lateral(self) -> float: ...

    @property
    def longitudinal(self) -> float: ...

    @property
    def vertical(self) -> float: ...


class HEAVE(Message):
    @property
    def week(self) -> int: ...

    @property
    def seconds(self) -> float: ...

    @property
    def heave(self) -> float: ...


class SETHEAVEWINDOW(Message):
    @property
    def heave_window(self) -> int: ...


class SETALIGNMENTVEL(Message):
    @property
    def min_velocity(self) -> float: ...


class CONNECTIMU(Message):
    @property
    def imu_port(self) -> IMUPort: ...

    @property
    def imu_type(self) -> IMUType: ...


class RELINSPVA(Message):
    @property
    def rel_ins_output(self) -> RelINSOutput: ...

    @property
    def delta_pos_n(self) -> float: ...

    @property
    def delta_pos_e(self) -> float: ...

    @property
    def delta_pos_u(self) -> float: ...

    @property
    def delta_vel_n(self) -> float: ...

    @property
    def delta_vel_e(self) -> float: ...

    @property
    def delta_vel_u(self) -> float: ...

    @property
    def delta_roll(self) -> float: ...

    @property
    def delta_pitch(self) -> float: ...

    @property
    def delta_heading(self) -> float: ...

    @property
    def diff_age(self) -> float: ...

    @property
    def rover_id(self) -> str: ...

    @property
    def rover_ins_status(self) -> INSStatus: ...

    @property
    def master_id(self) -> str: ...

    @property
    def master_ins_status(self) -> INSStatus: ...

    @property
    def rtk_baseline_status(self) -> SolType: ...

    @property
    def extended_sol_stat(self) -> int: ...


class INSTHRESHOLDS(Message):
    @property
    def ins_thresholds(self) -> INSThresholds: ...

    @property
    def INSTHRESHOLDS_reserved1_threshold(self) -> float: ...

    @property
    def INSTHRESHOLDS_reserved2_threshold(self) -> float: ...

    @property
    def INSTHRESHOLDS_reserved3_threshold(self) -> float: ...


class TSS1(Message):
    @property
    def ins_solution_status(self) -> INSStatus: ...

    @property
    def x(self) -> float: ...

    @property
    def y(self) -> float: ...

    @property
    def z(self) -> float: ...

    @property
    def heave(self) -> float: ...

    @property
    def roll(self) -> float: ...

    @property
    def pitch(self) -> float: ...

    @property
    def week(self) -> int: ...

    @property
    def seconds(self) -> float: ...


class INSATTX(Message):
    @property
    def ins_solution_status(self) -> INSStatus: ...

    @property
    def position_type(self) -> SolType: ...

    @property
    def roll(self) -> float: ...

    @property
    def pitch(self) -> float: ...

    @property
    def azimuth(self) -> float: ...

    @property
    def roll_std_dev(self) -> float: ...

    @property
    def pitch_std_dev(self) -> float: ...

    @property
    def azimuth_std_dev(self) -> float: ...

    @property
    def extended_sol_stat(self) -> int: ...

    @property
    def time_since_update(self) -> int: ...


class INSVELX(Message):
    @property
    def ins_solution_status(self) -> INSStatus: ...

    @property
    def position_type(self) -> SolType: ...

    @property
    def north_vel(self) -> float: ...

    @property
    def east_vel(self) -> float: ...

    @property
    def up_vel(self) -> float: ...

    @property
    def north_vel_std_dev(self) -> float: ...

    @property
    def east_vel_std_dev(self) -> float: ...

    @property
    def up_vel_std_dev(self) -> float: ...

    @property
    def extended_sol_stat(self) -> int: ...

    @property
    def time_since_update(self) -> int: ...


class INSPOSX(Message):
    @property
    def ins_solution_status(self) -> INSStatus: ...

    @property
    def position_type(self) -> SolType: ...

    @property
    def latitude(self) -> float: ...

    @property
    def longitude(self) -> float: ...

    @property
    def orthometric_height(self) -> float: ...

    @property
    def undulation(self) -> float: ...

    @property
    def latitude_std_dev(self) -> float: ...

    @property
    def longitude_std_dev(self) -> float: ...

    @property
    def height_std_dev(self) -> float: ...

    @property
    def extended_sol_stat(self) -> int: ...

    @property
    def time_since_update(self) -> int: ...


class RAWIMUX(Message):
    @property
    def imu_status_info(self) -> int: ...

    @property
    def imu_type(self) -> int: ...

    @property
    def gps_week(self) -> int: ...

    @property
    def gps_seconds(self) -> float: ...

    @property
    def imu_status(self) -> int: ...

    @property
    def accel_z(self) -> int: ...

    @property
    def accel_y(self) -> int: ...

    @property
    def accel_x(self) -> int: ...

    @property
    def gyro_z(self) -> int: ...

    @property
    def gyro_y(self) -> int: ...

    @property
    def gyro_x(self) -> int: ...


class RAWIMUSX(Message):
    @property
    def imu_status_info(self) -> int: ...

    @property
    def imu_type(self) -> int: ...

    @property
    def gps_week(self) -> int: ...

    @property
    def gps_seconds(self) -> float: ...

    @property
    def imu_status(self) -> int: ...

    @property
    def accel_z(self) -> int: ...

    @property
    def accel_y(self) -> int: ...

    @property
    def accel_x(self) -> int: ...

    @property
    def gyro_z(self) -> int: ...

    @property
    def gyro_y(self) -> int: ...

    @property
    def gyro_x(self) -> int: ...


class EXTERNALPVAS(Message):
    @property
    def position(self) -> list[float]: ...

    @property
    def velocity(self) -> list[float]: ...

    @property
    def attitude(self) -> list[float]: ...

    @property
    def position_stdev(self) -> list[float]: ...

    @property
    def velocity_stdev(self) -> list[float]: ...

    @property
    def attitude_stdev(self) -> list[float]: ...

    @property
    def update_type(self) -> int: ...

    @property
    def options(self) -> int: ...


class INSPVAX(Message):
    @property
    def ins_solution_status(self) -> INSStatus: ...

    @property
    def position_type(self) -> SolType: ...

    @property
    def latitude(self) -> float: ...

    @property
    def longitude(self) -> float: ...

    @property
    def orthometric_height(self) -> float: ...

    @property
    def undulation(self) -> float: ...

    @property
    def north_vel(self) -> float: ...

    @property
    def east_vel(self) -> float: ...

    @property
    def up_vel(self) -> float: ...

    @property
    def roll(self) -> float: ...

    @property
    def pitch(self) -> float: ...

    @property
    def azimuth(self) -> float: ...

    @property
    def latitude_std_dev(self) -> float: ...

    @property
    def longitude_std_dev(self) -> float: ...

    @property
    def height_std_dev(self) -> float: ...

    @property
    def north_vel_std_dev(self) -> float: ...

    @property
    def east_vel_std_dev(self) -> float: ...

    @property
    def up_vel_std_dev(self) -> float: ...

    @property
    def roll_std_dev(self) -> float: ...

    @property
    def pitch_std_dev(self) -> float: ...

    @property
    def azimuth_std_dev(self) -> float: ...

    @property
    def extended_sol_stat(self) -> int: ...

    @property
    def time_since_update(self) -> int: ...


class SYNCHEAVE(Message):
    @property
    def heave(self) -> float: ...

    @property
    def heave_std_dev(self) -> float: ...


class DELAYEDHEAVE(Message):
    @property
    def heave(self) -> float: ...

    @property
    def heave_std_dev(self) -> float: ...


class SYNCRELINSPVA(Message):
    @property
    def rel_ins_output(self) -> RelINSOutput: ...

    @property
    def delta_pos_n(self) -> float: ...

    @property
    def delta_pos_e(self) -> float: ...

    @property
    def delta_pos_u(self) -> float: ...

    @property
    def delta_vel_n(self) -> float: ...

    @property
    def delta_vel_e(self) -> float: ...

    @property
    def delta_vel_u(self) -> float: ...

    @property
    def delta_roll(self) -> float: ...

    @property
    def delta_pitch(self) -> float: ...

    @property
    def delta_heading(self) -> float: ...

    @property
    def diff_age(self) -> float: ...

    @property
    def rover_id(self) -> str: ...

    @property
    def rover_ins_status(self) -> INSStatus: ...

    @property
    def master_id(self) -> str: ...

    @property
    def master_ins_status(self) -> INSStatus: ...

    @property
    def rtk_baseline_status(self) -> SolType: ...

    @property
    def extended_sol_stat(self) -> int: ...


class RELINSAUTOMATION(Message):
    @property
    def enable(self) -> Enable: ...

    @property
    def port(self) -> CommPort: ...

    @property
    def baud_rate(self) -> int: ...

    @property
    def req_rate_in_hz(self) -> int: ...

    @property
    def send_heading_ext(self) -> OnOff: ...

    @property
    def interface_mode(self) -> InterfaceMode: ...


class SETIMUPORTPROTOCOL(Message):
    @property
    def port_protocol(self) -> PortProtocol: ...


class SETRELINSOUTPUTFRAME(Message):
    @property
    def rel_ins_output(self) -> RelINSOutput: ...

    @property
    def from_master(self) -> bool: ...


class IMURATEPVA(Message):
    @property
    def week(self) -> int: ...

    @property
    def seconds(self) -> float: ...

    @property
    def latitude(self) -> float: ...

    @property
    def longitude(self) -> float: ...

    @property
    def height(self) -> float: ...

    @property
    def north_vel(self) -> float: ...

    @property
    def east_vel(self) -> float: ...

    @property
    def up_vel(self) -> float: ...

    @property
    def roll(self) -> float: ...

    @property
    def pitch(self) -> float: ...

    @property
    def azimuth(self) -> float: ...

    @property
    def ins_solution_status(self) -> INSStatus: ...


class RELINSCONFIG(Message):
    @property
    def enable(self) -> Enable: ...

    @property
    def rel_ins_rx(self) -> RelINSRx: ...

    @property
    def port(self) -> CommPort: ...

    @property
    def baud_rate(self) -> int: ...

    @property
    def req_rate_in_hz(self) -> int: ...


class SETMAXALIGNMENTTIME(Message):
    @property
    def enable(self) -> Enable: ...

    @property
    def max_align_seconds(self) -> int: ...


class SETINSUPDATE(Message):
    @property
    def ins_update(self) -> INSUpdate: ...

    @property
    def trigger(self) -> Enable: ...


class INSUPDATESTATUS(Message):
    @property
    def pos_type(self) -> SolType: ...

    @property
    def num_psr(self) -> int: ...

    @property
    def num_phase(self) -> int: ...

    @property
    def num_dop(self) -> int: ...

    @property
    def wheel_status(self) -> WheelStatus: ...

    @property
    def heading_update_status(self) -> HeadingUpdateStatus: ...

    @property
    def ext_solution_status(self) -> int: ...

    @property
    def ins_update_options(self) -> int: ...

    @property
    def INSUPDATESTATUS_reserved1(self) -> int: ...

    @property
    def INSUPDATESTATUS_reserved2(self) -> int: ...


class INSCALIBRATE(Message):
    @property
    def offset(self) -> INSOffset: ...

    @property
    def trigger(self) -> INSCalibrateTrigger: ...

    @property
    def stdev_threshold(self) -> float: ...


class INSPVASDCMP(Message):
    @property
    def week(self) -> int: ...

    @property
    def week_milliseconds(self) -> int: ...

    @property
    def latitude_std_dev(self) -> int: ...

    @property
    def longitude_std_dev(self) -> int: ...

    @property
    def height_std_dev(self) -> int: ...

    @property
    def velocity_north_std_dev(self) -> int: ...

    @property
    def velocity_east_std_dev(self) -> int: ...

    @property
    def velocity_up_std_dev(self) -> int: ...

    @property
    def roll_std_dev(self) -> int: ...

    @property
    def pitch_std_dev(self) -> int: ...

    @property
    def azimuth_std_dev(self) -> int: ...

    @property
    def time_since_pos_update(self) -> int: ...

    @property
    def gnss_position_update_type(self) -> int: ...

    @property
    def extended_sol_stat(self) -> int: ...

    @property
    def align_age(self) -> int: ...

    @property
    def milliseconds(self) -> int: ...


class INSSEED(Message):
    @property
    def ins_seed(self) -> INSSeed: ...

    @property
    def injection_option(self) -> INSSeedInjection: ...

    @property
    def INSSEED_reserved1(self) -> int: ...

    @property
    def INSSEED_reserved2(self) -> int: ...


class SETINSTRANSLATION(Message):
    @property
    def offset(self) -> INSOffset: ...

    @property
    def elements(self) -> list[float]: ...

    @property
    def elements_2(self) -> list[float]: ...

    @property
    def input_frame(self) -> INSOffsetFrame: ...


class SETINSROTATION(Message):
    @property
    def offset(self) -> INSOffset: ...

    @property
    def elements(self) -> list[float]: ...

    @property
    def elements_2(self) -> list[float]: ...

    @property
    def SETINSROTATION_reserved(self) -> int: ...


class SETINSPROFILE(Message):
    @property
    def ins_profile(self) -> INSProfile: ...


class INSCONFIG_ins_translations_Field(Field):
    @property
    def ins_offset(self) -> INSOffset: ...

    @property
    def input_frame(self) -> INSOffsetFrame: ...

    @property
    def offset(self) -> list[float]: ...

    @property
    def offset_stdev(self) -> list[float]: ...

    @property
    def source_status(self) -> SourceStatus: ...


class INSCONFIG_ins_rotations_Field(Field):
    @property
    def ins_offset_26(self) -> INSOffset: ...

    @property
    def input_frame_27(self) -> INSOffsetFrame: ...

    @property
    def offset_28(self) -> list[float]: ...

    @property
    def offset_stdev_29(self) -> list[float]: ...

    @property
    def source_status_30(self) -> SourceStatus: ...


class INSCONFIG(Message):
    @property
    def imu_type(self) -> IMUType: ...

    @property
    def mapping(self) -> int: ...

    @property
    def scaled_alignment_vel(self) -> int: ...

    @property
    def heave_window(self) -> int: ...

    @property
    def ins_profile(self) -> INSProfile: ...

    @property
    def enabled_updates(self) -> int: ...

    @property
    def alignment_mode(self) -> AlignmentMode: ...

    @property
    def rel_ins_output(self) -> RelINSOutput: ...

    @property
    def rel_from_master(self) -> bool: ...

    @property
    def ins_rx_status(self) -> int: ...

    @property
    def ins_seed(self) -> int: ...

    @property
    def ins_seed_injection_option(self) -> int: ...

    @property
    def ins_grade_mode(self) -> int: ...

    @property
    def INSCONFIG_reserved2(self) -> int: ...

    @property
    def ins_logistics(self) -> int: ...

    @property
    def INSCONFIG_reserved4(self) -> int: ...

    @property
    def INSCONFIG_reserved5(self) -> int: ...

    @property
    def INSCONFIG_reserved6(self) -> int: ...

    @property
    def INSCONFIG_reserved7(self) -> int: ...

    @property
    def ins_translations(self) -> list[INSCONFIG_ins_translations_Field]: ...

    @property
    def ins_rotations(self) -> list[INSCONFIG_ins_rotations_Field]: ...


class INSCALSTATUS(Message):
    @property
    def ins_offset(self) -> INSOffset: ...

    @property
    def calibration(self) -> list[float]: ...

    @property
    def calibration_stdev(self) -> list[float]: ...

    @property
    def source_status(self) -> SourceStatus: ...

    @property
    def calibration_count(self) -> int: ...


class SETIMUEVENT(Message):
    @property
    def imu_event_direction(self) -> InOut: ...

    @property
    def imu_event_line(self) -> IMUEvent: ...


class INSSTDEV(Message):
    @property
    def latitude_std_dev(self) -> float: ...

    @property
    def longitude_std_dev(self) -> float: ...

    @property
    def height_std_dev(self) -> float: ...

    @property
    def north_vel_std_dev(self) -> float: ...

    @property
    def east_vel_std_dev(self) -> float: ...

    @property
    def up_vel_std_dev(self) -> float: ...

    @property
    def roll_std_dev(self) -> float: ...

    @property
    def pitch_std_dev(self) -> float: ...

    @property
    def azimuth_std_dev(self) -> float: ...

    @property
    def extended_sol_stat(self) -> int: ...

    @property
    def time_since_update(self) -> int: ...

    @property
    def ushort(self) -> int: ...

    @property
    def enabled_updates(self) -> int: ...

    @property
    def ulong(self) -> int: ...


class INSSTDEVS(Message):
    @property
    def latitude_std_dev(self) -> float: ...

    @property
    def longitude_std_dev(self) -> float: ...

    @property
    def height_std_dev(self) -> float: ...

    @property
    def north_vel_std_dev(self) -> float: ...

    @property
    def east_vel_std_dev(self) -> float: ...

    @property
    def up_vel_std_dev(self) -> float: ...

    @property
    def roll_std_dev(self) -> float: ...

    @property
    def pitch_std_dev(self) -> float: ...

    @property
    def azimuth_std_dev(self) -> float: ...

    @property
    def extended_sol_stat(self) -> int: ...

    @property
    def time_since_update(self) -> int: ...

    @property
    def ushort(self) -> int: ...

    @property
    def enabled_updates(self) -> int: ...

    @property
    def ulong(self) -> int: ...


class INSATTQS(Message):
    @property
    def week(self) -> int: ...

    @property
    def seconds(self) -> float: ...

    @property
    def quaternion(self) -> list[float]: ...

    @property
    def ins_solution_status(self) -> INSStatus: ...


class INSSEEDSTATUS(Message):
    @property
    def ins_seed_status(self) -> INSSeedStatus: ...

    @property
    def ins_seed_validity(self) -> INSSeedValidity: ...

    @property
    def att(self) -> list[float]: ...

    @property
    def xyz(self) -> list[float]: ...

    @property
    def undulation(self) -> float: ...

    @property
    def INSSEEDSTATUS_reserved1(self) -> int: ...

    @property
    def INSSEEDSTATUS_reserved2(self) -> int: ...

    @property
    def INSSEEDSTATUS_reserved3(self) -> int: ...

    @property
    def INSSEEDSTATUS_reserved4(self) -> int: ...


class INSALIGNCONFIG(Message):
    @property
    def master_port(self) -> CommPort: ...

    @property
    def rover_port(self) -> CommPort: ...

    @property
    def baud_rate(self) -> int: ...

    @property
    def req_rate_in_hz(self) -> int: ...

    @property
    def INSALIGNCONFIG_reserved(self) -> int: ...


class SETALIGNMENTORIENTATION(Message):
    @property
    def init_verification_state(self) -> Enable: ...

    @property
    def angle_threshold(self) -> float: ...


class CORRIMUS(Message):
    @property
    def accum_count(self) -> int: ...

    @property
    def corr_wb_ib(self) -> list[float]: ...

    @property
    def corr_fb(self) -> list[float]: ...

    @property
    def latency_ms(self) -> float: ...

    @property
    def ulong(self) -> int: ...


class RAWDMI(Message):
    @property
    def values(self) -> list[int]: ...

    @property
    def mask(self) -> int: ...


class DMICONFIG(Message):
    @property
    def dmi(self) -> DMI: ...

    @property
    def enable(self) -> Enable: ...

    @property
    def dmi_source(self) -> DMISource: ...

    @property
    def high_rate_event(self) -> DMIEvent: ...


class TILTSTATUS(Message):
    @property
    def compensation_status(self) -> int: ...

    @property
    def pitch(self) -> float: ...

    @property
    def roll(self) -> float: ...

    @property
    def x(self) -> float: ...

    @property
    def y(self) -> float: ...

    @property
    def z(self) -> float: ...

    @property
    def azimuth(self) -> float: ...

    @property
    def ulong(self) -> int: ...


class INSVELUSER(Message):
    @property
    def ins_solution_status(self) -> INSStatus: ...

    @property
    def north_vel(self) -> float: ...

    @property
    def east_vel(self) -> float: ...

    @property
    def up_vel(self) -> float: ...

    @property
    def north_vel_std_dev(self) -> float: ...

    @property
    def east_vel_std_dev(self) -> float: ...

    @property
    def up_vel_std_dev(self) -> float: ...

    @property
    def slip_angle(self) -> float: ...

    @property
    def ulong(self) -> int: ...

    @property
    def ulong_9(self) -> int: ...

    @property
    def ext_vel_status(self) -> int: ...


class INSDATUMINFO(Message):
    @property
    def name(self) -> str: ...

    @property
    def epsg_code(self) -> int: ...

    @property
    def epoch(self) -> float: ...

    @property
    def transformation_status(self) -> DatumTransformationStatus: ...

    @property
    def INSDATUMINFO_reserved(self) -> float: ...

    @property
    def INSDATUMINFO_reserved_5(self) -> int: ...


class CLOCKMODEL(Message):
    @property
    def status(self) -> ClockModelStatus: ...

    @property
    def reject_count(self) -> int: ...

    @property
    def milliseconds(self) -> int: ...

    @property
    def milliseconds_3(self) -> int: ...

    @property
    def par(self) -> list[float]: ...

    @property
    def data(self) -> list[float]: ...

    @property
    def inst_range_bias(self) -> float: ...

    @property
    def inst_drift(self) -> float: ...

    @property
    def constellation_change(self) -> bool: ...


class BESTPOS(Message):
    @property
    def solution_status(self) -> SolStatus: ...

    @property
    def position_type(self) -> SolType: ...

    @property
    def latitude(self) -> float: ...

    @property
    def longitude(self) -> float: ...

    @property
    def orthometric_height(self) -> float: ...

    @property
    def undulation(self) -> float: ...

    @property
    def datum_id(self) -> Datum: ...

    @property
    def latitude_std_dev(self) -> float: ...

    @property
    def longitude_std_dev(self) -> float: ...

    @property
    def height_std_dev(self) -> float: ...

    @property
    def base_id(self) -> str: ...

    @property
    def diff_age(self) -> float: ...

    @property
    def solution_age(self) -> float: ...

    @property
    def num_svs(self) -> int: ...

    @property
    def num_soln_svs(self) -> int: ...

    @property
    def num_soln_L1_svs(self) -> int: ...

    @property
    def num_soln_multi_svs(self) -> int: ...

    @property
    def extended_solution_status2(self) -> int: ...

    @property
    def ext_sol_stat(self) -> int: ...

    @property
    def gal_and_bds_mask(self) -> int: ...

    @property
    def gps_and_glo_mask(self) -> int: ...


class FIX(Message):
    @property
    def fix_cmd(self) -> FixCmd: ...

    @property
    def param1(self) -> float: ...

    @property
    def param2(self) -> float: ...

    @property
    def param3(self) -> float: ...


class PSRPOS(Message):
    @property
    def solution_status(self) -> SolStatus: ...

    @property
    def position_type(self) -> SolType: ...

    @property
    def latitude(self) -> float: ...

    @property
    def longitude(self) -> float: ...

    @property
    def orthometric_height(self) -> float: ...

    @property
    def undulation(self) -> float: ...

    @property
    def datum_id(self) -> Datum: ...

    @property
    def latitude_std_dev(self) -> float: ...

    @property
    def longitude_std_dev(self) -> float: ...

    @property
    def height_std_dev(self) -> float: ...

    @property
    def base_id(self) -> str: ...

    @property
    def diff_age(self) -> float: ...

    @property
    def solution_age(self) -> float: ...

    @property
    def num_svs(self) -> int: ...

    @property
    def num_soln_svs(self) -> int: ...

    @property
    def char_as_int(self) -> int: ...

    @property
    def char_as_int_16(self) -> int: ...

    @property
    def extended_solution_status2(self) -> int: ...

    @property
    def ext_sol_stat(self) -> int: ...

    @property
    def gal_and_bds_mask(self) -> int: ...

    @property
    def gps_and_glo_mask(self) -> int: ...


class USERDATUM(Message):
    @property
    def semi_major_axis(self) -> float: ...

    @property
    def inverse_flattening(self) -> float: ...

    @property
    def x(self) -> float: ...

    @property
    def y(self) -> float: ...

    @property
    def z(self) -> float: ...

    @property
    def x_5(self) -> float: ...

    @property
    def y_6(self) -> float: ...

    @property
    def z_7(self) -> float: ...

    @property
    def scale(self) -> float: ...


class RTKELEVMASK(Message):
    @property
    def elev_mask_type(self) -> RTKElevMaskType: ...

    @property
    def angle(self) -> float: ...


class RTKSVENTRIES(Message):
    @property
    def max_sv(self) -> int: ...


class MATCHEDPOS(Message):
    @property
    def solution_status(self) -> SolStatus: ...

    @property
    def position_type(self) -> SolType: ...

    @property
    def latitude(self) -> float: ...

    @property
    def longitude(self) -> float: ...

    @property
    def orthometric_height(self) -> float: ...

    @property
    def undulation(self) -> float: ...

    @property
    def datum_id(self) -> Datum: ...

    @property
    def latitude_std_dev(self) -> float: ...

    @property
    def longitude_std_dev(self) -> float: ...

    @property
    def height_std_dev(self) -> float: ...

    @property
    def base_id(self) -> str: ...

    @property
    def diff_age(self) -> float: ...

    @property
    def solution_age(self) -> float: ...

    @property
    def num_svs(self) -> int: ...

    @property
    def num_soln_svs(self) -> int: ...

    @property
    def num_soln_L1_svs(self) -> int: ...

    @property
    def num_soln_multi_svs(self) -> int: ...

    @property
    def extended_solution_status2(self) -> int: ...

    @property
    def ext_sol_stat(self) -> int: ...

    @property
    def gal_and_bds_mask(self) -> int: ...

    @property
    def gps_and_glo_mask(self) -> int: ...


class RTKCOMMAND(Message):
    @property
    def command(self) -> RTKCommand: ...


class BESTVEL(Message):
    @property
    def status(self) -> SolStatus: ...

    @property
    def type(self) -> SolType: ...

    @property
    def latency(self) -> float: ...

    @property
    def diff_age(self) -> float: ...

    @property
    def horizontal_speed(self) -> float: ...

    @property
    def ground_track(self) -> float: ...

    @property
    def z(self) -> float: ...

    @property
    def rsvd_field_for_velocity_logs(self) -> int: ...


class PSRVEL(Message):
    @property
    def velocity_status(self) -> SolStatus: ...

    @property
    def velocity_type(self) -> SolType: ...

    @property
    def latency(self) -> float: ...

    @property
    def diff_age(self) -> float: ...

    @property
    def horizontal_speed(self) -> float: ...

    @property
    def ground_track(self) -> float: ...

    @property
    def z(self) -> float: ...

    @property
    def rsvd_field_for_velocity_logs(self) -> int: ...


class SETRTCM16(Message):
    @property
    def text(self) -> str: ...


class RTKPOS(Message):
    @property
    def solution_status(self) -> SolStatus: ...

    @property
    def position_type(self) -> SolType: ...

    @property
    def latitude(self) -> float: ...

    @property
    def longitude(self) -> float: ...

    @property
    def orthometric_height(self) -> float: ...

    @property
    def undulation(self) -> float: ...

    @property
    def datum_id(self) -> Datum: ...

    @property
    def latitude_std_dev(self) -> float: ...

    @property
    def longitude_std_dev(self) -> float: ...

    @property
    def height_std_dev(self) -> float: ...

    @property
    def base_id(self) -> str: ...

    @property
    def diff_age(self) -> float: ...

    @property
    def solution_age(self) -> float: ...

    @property
    def num_svs(self) -> int: ...

    @property
    def num_soln_svs(self) -> int: ...

    @property
    def num_soln_L1_svs(self) -> int: ...

    @property
    def num_soln_multi_svs(self) -> int: ...

    @property
    def extended_solution_status2(self) -> int: ...

    @property
    def ext_sol_stat(self) -> int: ...

    @property
    def gal_and_bds_mask(self) -> int: ...

    @property
    def gps_and_glo_mask(self) -> int: ...


class DGPSTXID(Message):
    @property
    def dgps_type(self) -> DGPSType: ...

    @property
    def dgps_id(self) -> str: ...


class DATUM(Message):
    @property
    def datum_id(self) -> Datum: ...


class NAVIGATE(Message):
    @property
    def solution_status(self) -> SolStatus: ...

    @property
    def position_type(self) -> SolType: ...

    @property
    def velocity_status(self) -> SolStatus: ...

    @property
    def nav_status(self) -> NavStatus: ...

    @property
    def distance(self) -> float: ...

    @property
    def bearing(self) -> float: ...

    @property
    def along_track(self) -> float: ...

    @property
    def x_track(self) -> float: ...

    @property
    def eta_weeks(self) -> int: ...

    @property
    def eta_seconds(self) -> float: ...


class SETNAV(Message):
    @property
    def from_latitude(self) -> float: ...

    @property
    def from_longitude(self) -> float: ...

    @property
    def to_latitude(self) -> float: ...

    @property
    def to_longitude(self) -> float: ...

    @property
    def track_offset(self) -> float: ...

    @property
    def from_point(self) -> str: ...

    @property
    def to_point(self) -> str: ...


class AVEPOS(Message):
    @property
    def latitude(self) -> float: ...

    @property
    def longitude(self) -> float: ...

    @property
    def orthometric_height(self) -> float: ...

    @property
    def latitude_std_dev(self) -> float: ...

    @property
    def longitude_std_dev(self) -> float: ...

    @property
    def height_std_dev(self) -> float: ...

    @property
    def ave_status(self) -> PosAveStatus: ...

    @property
    def ave_time(self) -> int: ...

    @property
    def num_sample(self) -> int: ...


class POSAVE(Message):
    @property
    def command(self) -> PosAveCommand: ...

    @property
    def max_time(self) -> float: ...

    @property
    def max_horiz(self) -> float: ...

    @property
    def max_height(self) -> float: ...


class PSRDOP(Message):
    @property
    def gdop(self) -> float: ...

    @property
    def pdop(self) -> float: ...

    @property
    def hdop(self) -> float: ...

    @property
    def htdop(self) -> float: ...

    @property
    def tdop(self) -> float: ...

    @property
    def gps_elev_mask(self) -> float: ...

    @property
    def sats(self) -> list[int]: ...


class REFSTATION(Message):
    @property
    def ref_status(self) -> int: ...

    @property
    def ecef_x(self) -> float: ...

    @property
    def ecef_y(self) -> float: ...

    @property
    def ecef_z(self) -> float: ...

    @property
    def health(self) -> int: ...

    @property
    def ref_type(self) -> RefStation: ...

    @property
    def ref_id(self) -> str: ...


class MAGVAR(Message):
    @property
    def mag_var_type(self) -> MagVarType: ...

    @property
    def correction(self) -> float: ...

    @property
    def correction_std_dev(self) -> float: ...


class MARKPOS(Message):
    @property
    def solution_status(self) -> SolStatus: ...

    @property
    def position_type(self) -> SolType: ...

    @property
    def latitude(self) -> float: ...

    @property
    def longitude(self) -> float: ...

    @property
    def orthometric_height(self) -> float: ...

    @property
    def undulation(self) -> float: ...

    @property
    def datum_id(self) -> Datum: ...

    @property
    def latitude_std_dev(self) -> float: ...

    @property
    def longitude_std_dev(self) -> float: ...

    @property
    def height_std_dev(self) -> float: ...

    @property
    def base_id(self) -> str: ...

    @property
    def diff_age(self) -> float: ...

    @property
    def solution_age(self) -> float: ...

    @property
    def num_svs(self) -> int: ...

    @property
    def num_soln_svs(self) -> int: ...

    @property
    def num_soln_L1_svs(self) -> int: ...

    @property
    def num_soln_multi_svs(self) -> int: ...

    @property
    def char_as_int(self) -> int: ...

    @property
    def ext_sol_stat(self) -> int: ...

    @property
    def gal_and_bds_mask(self) -> int: ...

    @property
    def gps_and_glo_mask(self) -> int: ...


class RTKDYNAMICS(Message):
    @property
    def dynamics(self) -> RTKDynamics: ...


class UNDULATION(Message):
    @property
    def undulation_type(self) -> UndulationType: ...

    @property
    def undulation(self) -> float: ...


class RTKVEL(Message):
    @property
    def velocity_status(self) -> SolStatus: ...

    @property
    def velocity_type(self) -> SolType: ...

    @property
    def latency(self) -> float: ...

    @property
    def diff_age(self) -> float: ...

    @property
    def horizontal_speed(self) -> float: ...

    @property
    def ground_track(self) -> float: ...

    @property
    def z(self) -> float: ...

    @property
    def rsvd_field_for_velocity_logs(self) -> int: ...


class BESTXYZ(Message):
    @property
    def solution_status(self) -> SolStatus: ...

    @property
    def position_type(self) -> SolType: ...

    @property
    def x(self) -> float: ...

    @property
    def y(self) -> float: ...

    @property
    def z(self) -> float: ...

    @property
    def x_std_dev(self) -> float: ...

    @property
    def y_std_dev(self) -> float: ...

    @property
    def z_std_dev(self) -> float: ...

    @property
    def status(self) -> SolStatus: ...

    @property
    def type(self) -> SolType: ...

    @property
    def x_10(self) -> float: ...

    @property
    def y_11(self) -> float: ...

    @property
    def z_12(self) -> float: ...

    @property
    def x_std_dev_13(self) -> float: ...

    @property
    def y_std_dev_14(self) -> float: ...

    @property
    def z_std_dev_15(self) -> float: ...

    @property
    def base_id(self) -> str: ...

    @property
    def latency(self) -> float: ...

    @property
    def diff_age(self) -> float: ...

    @property
    def solution_age(self) -> float: ...

    @property
    def num_svs(self) -> int: ...

    @property
    def num_soln_svs(self) -> int: ...

    @property
    def num_soln_L1_svs(self) -> int: ...

    @property
    def num_soln_multi_svs(self) -> int: ...

    @property
    def char_as_int(self) -> int: ...

    @property
    def ext_sol_stat(self) -> int: ...

    @property
    def gal_and_bds_mask(self) -> int: ...

    @property
    def gps_and_glo_mask(self) -> int: ...


class MATCHEDXYZ(Message):
    @property
    def solution_status(self) -> SolStatus: ...

    @property
    def position_type(self) -> SolType: ...

    @property
    def x(self) -> float: ...

    @property
    def y(self) -> float: ...

    @property
    def z(self) -> float: ...

    @property
    def x_std_dev(self) -> float: ...

    @property
    def y_std_dev(self) -> float: ...

    @property
    def z_std_dev(self) -> float: ...

    @property
    def base_id(self) -> str: ...

    @property
    def num_svs(self) -> int: ...

    @property
    def num_soln_svs(self) -> int: ...

    @property
    def num_soln_L1_svs(self) -> int: ...

    @property
    def num_soln_multi_svs(self) -> int: ...

    @property
    def char_as_int(self) -> int: ...

    @property
    def ext_sol_stat(self) -> int: ...

    @property
    def gal_and_bds_mask(self) -> int: ...

    @property
    def gps_and_glo_mask(self) -> int: ...


class PSRXYZ(Message):
    @property
    def solution_status(self) -> SolStatus: ...

    @property
    def position_type(self) -> SolType: ...

    @property
    def x(self) -> float: ...

    @property
    def y(self) -> float: ...

    @property
    def z(self) -> float: ...

    @property
    def x_std_dev(self) -> float: ...

    @property
    def y_std_dev(self) -> float: ...

    @property
    def z_std_dev(self) -> float: ...

    @property
    def velocity_status(self) -> SolStatus: ...

    @property
    def velocity_type(self) -> SolType: ...

    @property
    def x_10(self) -> float: ...

    @property
    def y_11(self) -> float: ...

    @property
    def z_12(self) -> float: ...

    @property
    def x_std_dev_13(self) -> float: ...

    @property
    def y_std_dev_14(self) -> float: ...

    @property
    def z_std_dev_15(self) -> float: ...

    @property
    def base_id(self) -> str: ...

    @property
    def latency(self) -> float: ...

    @property
    def diff_age(self) -> float: ...

    @property
    def solution_age(self) -> float: ...

    @property
    def num_svs(self) -> int: ...

    @property
    def num_soln_svs(self) -> int: ...

    @property
    def char_as_int(self) -> int: ...

    @property
    def char_as_int_23(self) -> int: ...

    @property
    def char_as_int_24(self) -> int: ...

    @property
    def ext_sol_stat(self) -> int: ...

    @property
    def gal_and_bds_mask(self) -> int: ...

    @property
    def gps_and_glo_mask(self) -> int: ...


class RTKXYZ(Message):
    @property
    def solution_status(self) -> SolStatus: ...

    @property
    def position_type(self) -> SolType: ...

    @property
    def x(self) -> float: ...

    @property
    def y(self) -> float: ...

    @property
    def z(self) -> float: ...

    @property
    def x_std_dev(self) -> float: ...

    @property
    def y_std_dev(self) -> float: ...

    @property
    def z_std_dev(self) -> float: ...

    @property
    def velocity_status(self) -> SolStatus: ...

    @property
    def velocity_type(self) -> SolType: ...

    @property
    def x_10(self) -> float: ...

    @property
    def y_11(self) -> float: ...

    @property
    def z_12(self) -> float: ...

    @property
    def x_std_dev_13(self) -> float: ...

    @property
    def y_std_dev_14(self) -> float: ...

    @property
    def z_std_dev_15(self) -> float: ...

    @property
    def base_id(self) -> str: ...

    @property
    def latency(self) -> float: ...

    @property
    def diff_age(self) -> float: ...

    @property
    def solution_age(self) -> float: ...

    @property
    def num_svs(self) -> int: ...

    @property
    def num_soln_svs(self) -> int: ...

    @property
    def num_soln_L1_svs(self) -> int: ...

    @property
    def num_soln_multi_svs(self) -> int: ...

    @property
    def char_as_int(self) -> int: ...

    @property
    def ext_sol_stat(self) -> int: ...

    @property
    def gal_and_bds_mask(self) -> int: ...

    @property
    def gps_and_glo_mask(self) -> int: ...


class SETAPPROXPOS(Message):
    @property
    def lat(self) -> float: ...

    @property
    def lon(self) -> float: ...

    @property
    def hgt(self) -> float: ...


class PDPFILTER(Message):
    @property
    def command(self) -> PDPFilterCommand: ...


class PDPPOS(Message):
    @property
    def solution_status(self) -> SolStatus: ...

    @property
    def position_type(self) -> SolType: ...

    @property
    def latitude(self) -> float: ...

    @property
    def longitude(self) -> float: ...

    @property
    def orthometric_height(self) -> float: ...

    @property
    def undulation(self) -> float: ...

    @property
    def datum_id(self) -> Datum: ...

    @property
    def latitude_std_dev(self) -> float: ...

    @property
    def longitude_std_dev(self) -> float: ...

    @property
    def height_std_dev(self) -> float: ...

    @property
    def base_id(self) -> str: ...

    @property
    def diff_age(self) -> float: ...

    @property
    def solution_age(self) -> float: ...

    @property
    def num_svs(self) -> int: ...

    @property
    def num_soln_svs(self) -> int: ...

    @property
    def char_as_int(self) -> int: ...

    @property
    def char_as_int_16(self) -> int: ...

    @property
    def extended_solution_status2(self) -> int: ...

    @property
    def ext_sol_stat(self) -> int: ...

    @property
    def gal_and_bds_mask(self) -> int: ...

    @property
    def gps_and_glo_mask(self) -> int: ...


class PDPVEL(Message):
    @property
    def velocity_status(self) -> SolStatus: ...

    @property
    def velocity_type(self) -> SolType: ...

    @property
    def latency(self) -> float: ...

    @property
    def diff_age(self) -> float: ...

    @property
    def horizontal_speed(self) -> float: ...

    @property
    def ground_track(self) -> float: ...

    @property
    def z(self) -> float: ...

    @property
    def rsvd_field_for_velocity_logs(self) -> int: ...


class PDPXYZ(Message):
    @property
    def solution_status(self) -> SolStatus: ...

    @property
    def position_type(self) -> SolType: ...

    @property
    def x(self) -> float: ...

    @property
    def y(self) -> float: ...

    @property
    def z(self) -> float: ...

    @property
    def x_std_dev(self) -> float: ...

    @property
    def y_std_dev(self) -> float: ...

    @property
    def z_std_dev(self) -> float: ...

    @property
    def velocity_status(self) -> SolStatus: ...

    @property
    def velocity_type(self) -> SolType: ...

    @property
    def x_10(self) -> float: ...

    @property
    def y_11(self) -> float: ...

    @property
    def z_12(self) -> float: ...

    @property
    def x_std_dev_13(self) -> float: ...

    @property
    def y_std_dev_14(self) -> float: ...

    @property
    def z_std_dev_15(self) -> float: ...

    @property
    def base_id(self) -> str: ...

    @property
    def latency(self) -> float: ...

    @property
    def diff_age(self) -> float: ...

    @property
    def solution_age(self) -> float: ...

    @property
    def num_svs(self) -> int: ...

    @property
    def num_soln_svs(self) -> int: ...

    @property
    def num_soln_L1_svs(self) -> int: ...

    @property
    def num_soln_multi_svs(self) -> int: ...

    @property
    def char_as_int(self) -> int: ...

    @property
    def ext_sol_stat(self) -> int: ...

    @property
    def gal_and_bds_mask(self) -> int: ...

    @property
    def gps_and_glo_mask(self) -> int: ...


class PSRDIFFSOURCE(Message):
    @property
    def corr_type(self) -> DGPSType: ...

    @property
    def station_id(self) -> str: ...


class RTKSOURCE(Message):
    @property
    def corr_type(self) -> DGPSType: ...

    @property
    def station_id(self) -> str: ...


class POSTIMEOUT(Message):
    @property
    def time_out(self) -> int: ...


class MARK2POS(Message):
    @property
    def solution_status(self) -> SolStatus: ...

    @property
    def position_type(self) -> SolType: ...

    @property
    def latitude(self) -> float: ...

    @property
    def longitude(self) -> float: ...

    @property
    def orthometric_height(self) -> float: ...

    @property
    def undulation(self) -> float: ...

    @property
    def datum_id(self) -> Datum: ...

    @property
    def latitude_std_dev(self) -> float: ...

    @property
    def longitude_std_dev(self) -> float: ...

    @property
    def height_std_dev(self) -> float: ...

    @property
    def base_id(self) -> str: ...

    @property
    def diff_age(self) -> float: ...

    @property
    def solution_age(self) -> float: ...

    @property
    def num_svs(self) -> int: ...

    @property
    def num_soln_svs(self) -> int: ...

    @property
    def num_soln_L1_svs(self) -> int: ...

    @property
    def num_soln_multi_svs(self) -> int: ...

    @property
    def char_as_int(self) -> int: ...

    @property
    def ext_sol_stat(self) -> int: ...

    @property
    def gal_and_bds_mask(self) -> int: ...

    @property
    def gps_and_glo_mask(self) -> int: ...


class SBASCONTROL(Message):
    @property
    def enable(self) -> Enable: ...

    @property
    def system(self) -> SBASSystem: ...

    @property
    def prn(self) -> int: ...

    @property
    def test_mode(self) -> SBASTestMode: ...


class BSLNXYZ(Message):
    @property
    def solution_status(self) -> SolStatus: ...

    @property
    def position_type(self) -> SolType: ...

    @property
    def x(self) -> float: ...

    @property
    def y(self) -> float: ...

    @property
    def z(self) -> float: ...

    @property
    def x_std_dev(self) -> float: ...

    @property
    def y_std_dev(self) -> float: ...

    @property
    def z_std_dev(self) -> float: ...

    @property
    def base_id(self) -> str: ...

    @property
    def num_svs(self) -> int: ...

    @property
    def num_soln_svs(self) -> int: ...

    @property
    def num_soln_L1_svs(self) -> int: ...

    @property
    def num_soln_multi_svs(self) -> int: ...

    @property
    def char_as_int(self) -> int: ...

    @property
    def ext_sol_stat(self) -> int: ...

    @property
    def gal_and_bds_mask(self) -> int: ...

    @property
    def gps_and_glo_mask(self) -> int: ...


class SETDIFFCODEBIASES(Message):
    @property
    def code_pair(self) -> CodePair: ...

    @property
    def biases(self) -> list[float]: ...


class GGAQUALITY_mappings_Field(Field):
    @property
    def sol_type(self) -> SolType: ...

    @property
    def gga_quality(self) -> int: ...


class GGAQUALITY(Message):
    @property
    def mappings(self) -> list[GGAQUALITY_mappings_Field]: ...


class SETIONOTYPE(Message):
    @property
    def model(self) -> IonoCorrType: ...


class BESTUTM(Message):
    @property
    def solution_status(self) -> SolStatus: ...

    @property
    def position_type(self) -> SolType: ...

    @property
    def zone_number(self) -> int: ...

    @property
    def zone_letter(self) -> int: ...

    @property
    def northing(self) -> float: ...

    @property
    def easting(self) -> float: ...

    @property
    def height(self) -> float: ...

    @property
    def undulation(self) -> float: ...

    @property
    def datum_id(self) -> Datum: ...

    @property
    def latitude_std_dev(self) -> float: ...

    @property
    def longitude_std_dev(self) -> float: ...

    @property
    def height_std_dev(self) -> float: ...

    @property
    def base_id(self) -> str: ...

    @property
    def diff_age(self) -> float: ...

    @property
    def solution_age(self) -> float: ...

    @property
    def num_svs(self) -> int: ...

    @property
    def num_soln_svs(self) -> int: ...

    @property
    def num_soln_L1_svs(self) -> int: ...

    @property
    def num_soln_multi_svs(self) -> int: ...

    @property
    def char_as_int(self) -> int: ...

    @property
    def ext_sol_stat(self) -> int: ...

    @property
    def gal_and_bds_mask(self) -> int: ...

    @property
    def gps_and_glo_mask(self) -> int: ...


class UTMZONE(Message):
    @property
    def utm_zone_command(self) -> UTMZoneCommand: ...

    @property
    def param(self) -> int: ...


class MOVINGBASESTATION(Message):
    @property
    def moving_base_station_enum(self) -> Enable: ...


class USEREXPDATUM(Message):
    @property
    def semi_major_axis(self) -> float: ...

    @property
    def inverse_flattening(self) -> float: ...

    @property
    def x(self) -> float: ...

    @property
    def y(self) -> float: ...

    @property
    def z(self) -> float: ...

    @property
    def x_5(self) -> float: ...

    @property
    def y_6(self) -> float: ...

    @property
    def z_7(self) -> float: ...

    @property
    def scale(self) -> float: ...

    @property
    def x_9(self) -> float: ...

    @property
    def y_10(self) -> float: ...

    @property
    def z_11(self) -> float: ...

    @property
    def x_12(self) -> float: ...

    @property
    def y_13(self) -> float: ...

    @property
    def z_14(self) -> float: ...

    @property
    def scale_rate(self) -> float: ...

    @property
    def reference_date(self) -> float: ...


class SETBESTPOSCRITERIA(Message):
    @property
    def selection_type(self) -> SetBestPosCriteria: ...

    @property
    def num_epochs(self) -> int: ...


class RTKQUALITYLEVEL(Message):
    @property
    def rtk_quality_level(self) -> RTKQuality: ...


class RTKANTENNA(Message):
    @property
    def position_reference_enum(self) -> PositionReference: ...

    @property
    def pcv_model_enum(self) -> PCVModeling: ...

    @property
    def RTKANTENNA_reserved1(self) -> bool: ...

    @property
    def RTKANTENNA_reserved2(self) -> bool: ...


class LOCKOUTSYSTEM(Message):
    @property
    def system(self) -> SystemType: ...


class SETRTCM36(Message):
    @property
    def text(self) -> str: ...


class PSRTIME_system_offsets_Field(Field):
    @property
    def system(self) -> TimingSystem: ...

    @property
    def bias(self) -> float: ...

    @property
    def bias_std_dev(self) -> float: ...


class PSRTIME(Message):
    @property
    def system_offsets(self) -> list[PSRTIME_system_offsets_Field]: ...


class UNLOCKOUTSYSTEM(Message):
    @property
    def system(self) -> SystemType: ...


class RTKTIMEOUT(Message):
    @property
    def rtk_time_out(self) -> int: ...


class DIFFCODEBIASCONTROL(Message):
    @property
    def enable_enum(self) -> Enable: ...


class RTKNETWORK(Message):
    @property
    def rtk_network(self) -> RTKNetwork: ...

    @property
    def network_number(self) -> int: ...


class RTKDOP(Message):
    @property
    def gdop(self) -> float: ...

    @property
    def pdop(self) -> float: ...

    @property
    def hdop(self) -> float: ...

    @property
    def htdop(self) -> float: ...

    @property
    def tdop(self) -> float: ...

    @property
    def gps_elev_mask(self) -> float: ...

    @property
    def sats(self) -> list[int]: ...


class PDPMODE(Message):
    @property
    def mode(self) -> PDPFilterMode: ...

    @property
    def dynamics(self) -> PDPFilterDynamics: ...


class HEADING(Message):
    @property
    def solution_status(self) -> SolStatus: ...

    @property
    def position_type(self) -> SolType: ...

    @property
    def b_length(self) -> float: ...

    @property
    def heading(self) -> float: ...

    @property
    def pitch(self) -> float: ...

    @property
    def float_1(self) -> float: ...

    @property
    def heading_std_dev(self) -> float: ...

    @property
    def pitch_std_dev(self) -> float: ...

    @property
    def base_id(self) -> str: ...

    @property
    def num_svs(self) -> int: ...

    @property
    def num_soln_svs(self) -> int: ...

    @property
    def num_soln_L1_svs(self) -> int: ...

    @property
    def num_soln_multi_svs(self) -> int: ...

    @property
    def extended_solution_status2(self) -> int: ...

    @property
    def ext_sol_stat(self) -> int: ...

    @property
    def gal_and_bds_mask(self) -> int: ...

    @property
    def gps_and_glo_mask(self) -> int: ...


class SBASTIMEOUT(Message):
    @property
    def time_out_enum(self) -> TimeOut: ...

    @property
    def time_out(self) -> float: ...

    @property
    def SBASTIMEOUT_reserved(self) -> float: ...


class MASTERPOS(Message):
    @property
    def solution_status(self) -> SolStatus: ...

    @property
    def position_type(self) -> SolType: ...

    @property
    def latitude(self) -> float: ...

    @property
    def longitude(self) -> float: ...

    @property
    def orthometric_height(self) -> float: ...

    @property
    def undulation(self) -> float: ...

    @property
    def datum_id(self) -> Datum: ...

    @property
    def latitude_std_dev(self) -> float: ...

    @property
    def longitude_std_dev(self) -> float: ...

    @property
    def height_std_dev(self) -> float: ...

    @property
    def base_id(self) -> str: ...

    @property
    def float_1(self) -> float: ...

    @property
    def float_1_12(self) -> float: ...

    @property
    def num_svs(self) -> int: ...

    @property
    def num_soln_svs(self) -> int: ...

    @property
    def num_soln_L1_svs(self) -> int: ...

    @property
    def num_soln_multi_svs(self) -> int: ...

    @property
    def extended_solution_status2(self) -> int: ...

    @property
    def char_as_int(self) -> int: ...

    @property
    def char_as_int_19(self) -> int: ...

    @property
    def char_as_int_20(self) -> int: ...


class ROVERPOS(Message):
    @property
    def solution_status(self) -> SolStatus: ...

    @property
    def position_type(self) -> SolType: ...

    @property
    def latitude(self) -> float: ...

    @property
    def longitude(self) -> float: ...

    @property
    def orthometric_height(self) -> float: ...

    @property
    def undulation(self) -> float: ...

    @property
    def datum_id(self) -> Datum: ...

    @property
    def latitude_std_dev(self) -> float: ...

    @property
    def longitude_std_dev(self) -> float: ...

    @property
    def height_std_dev(self) -> float: ...

    @property
    def base_id(self) -> str: ...

    @property
    def float_1(self) -> float: ...

    @property
    def float_1_12(self) -> float: ...

    @property
    def num_svs(self) -> int: ...

    @property
    def num_soln_svs(self) -> int: ...

    @property
    def num_soln_L1_svs(self) -> int: ...

    @property
    def num_soln_multi_svs(self) -> int: ...

    @property
    def extended_solution_status2(self) -> int: ...

    @property
    def char_as_int(self) -> int: ...

    @property
    def char_as_int_19(self) -> int: ...

    @property
    def char_as_int_20(self) -> int: ...


class HDTOUTTHRESHOLD(Message):
    @property
    def heading_std_threshold(self) -> float: ...


class HEADINGOFFSET(Message):
    @property
    def heading_offset(self) -> float: ...

    @property
    def pitch_offset(self) -> float: ...


class HEADINGEXT(Message):
    @property
    def solution_status(self) -> int: ...

    @property
    def solution_type(self) -> int: ...

    @property
    def heading_offset(self) -> float: ...

    @property
    def pitch_offset(self) -> float: ...

    @property
    def x(self) -> float: ...

    @property
    def y(self) -> float: ...

    @property
    def z(self) -> float: ...

    @property
    def x_var(self) -> float: ...

    @property
    def y_var(self) -> float: ...

    @property
    def z_var(self) -> float: ...

    @property
    def xy_var(self) -> float: ...

    @property
    def yz_var(self) -> float: ...

    @property
    def zx_var(self) -> float: ...

    @property
    def master_id(self) -> str: ...

    @property
    def rover_id(self) -> str: ...

    @property
    def undulation(self) -> float: ...

    @property
    def num_sats_tracked(self) -> int: ...

    @property
    def num_sats_in_sol(self) -> int: ...

    @property
    def num_high_sats(self) -> int: ...

    @property
    def num_high_l2_sats(self) -> int: ...

    @property
    def ext_sol_stat(self) -> int: ...

    @property
    def gp_sand_glo_freqs_in_sol(self) -> int: ...


class SETROVERID(Message):
    @property
    def id(self) -> str: ...


class OUTPUTDATUM(Message):
    @property
    def name(self) -> str: ...

    @property
    def epoch_option(self) -> EpochOption: ...

    @property
    def epoch(self) -> float: ...


class PSRSATS_satellite_entries_Field(Field):
    @property
    def system_type(self) -> SystemType: ...

    @property
    def id(self) -> SatelliteId: ...

    @property
    def status(self) -> ObservationStatus: ...

    @property
    def status_mask(self) -> int: ...


class PSRSATS(Message):
    @property
    def satellite_entries(self) -> list[PSRSATS_satellite_entries_Field]: ...


class PSRDOP2_tdo_ps_Field(Field):
    @property
    def system(self) -> TimingSystem: ...

    @property
    def dop(self) -> float: ...


class PSRDOP2(Message):
    @property
    def gdop(self) -> float: ...

    @property
    def pdop(self) -> float: ...

    @property
    def hdop(self) -> float: ...

    @property
    def vdop(self) -> float: ...

    @property
    def tdo_ps(self) -> list[PSRDOP2_tdo_ps_Field]: ...


class RTKDOP2_tdo_ps_Field(Field):
    @property
    def system(self) -> TimingSystem: ...

    @property
    def dop(self) -> float: ...


class RTKDOP2(Message):
    @property
    def gdop(self) -> float: ...

    @property
    def pdop(self) -> float: ...

    @property
    def hdop(self) -> float: ...

    @property
    def vdop(self) -> float: ...

    @property
    def tdo_ps(self) -> list[RTKDOP2_tdo_ps_Field]: ...


class RTKSATS_satellite_entries_Field(Field):
    @property
    def system_type(self) -> SystemType: ...

    @property
    def id(self) -> SatelliteId: ...

    @property
    def status(self) -> ObservationStatus: ...

    @property
    def status_mask(self) -> int: ...


class RTKSATS(Message):
    @property
    def satellite_entries(self) -> list[RTKSATS_satellite_entries_Field]: ...


class MATCHEDSATS_satellite_entries_Field(Field):
    @property
    def system_type(self) -> SystemType: ...

    @property
    def id(self) -> SatelliteId: ...

    @property
    def status(self) -> ObservationStatus: ...

    @property
    def status_mask(self) -> int: ...


class MATCHEDSATS(Message):
    @property
    def satellite_entries(self) -> list[MATCHEDSATS_satellite_entries_Field]: ...


class BESTSATS_satellite_entries_Field(Field):
    @property
    def system_type(self) -> SystemType: ...

    @property
    def id(self) -> SatelliteId: ...

    @property
    def status(self) -> ObservationStatus: ...

    @property
    def status_mask(self) -> int: ...


class BESTSATS(Message):
    @property
    def satellite_entries(self) -> list[BESTSATS_satellite_entries_Field]: ...


class IONOCONDITION(Message):
    @property
    def iono_condition(self) -> IonoCondition: ...


class SETRTCMRXVERSION(Message):
    @property
    def version(self) -> RTCMVersion: ...


class PDPSATS_satellite_entries_Field(Field):
    @property
    def system_type(self) -> SystemType: ...

    @property
    def id(self) -> SatelliteId: ...

    @property
    def status(self) -> ObservationStatus: ...

    @property
    def status_mask(self) -> int: ...


class PDPSATS(Message):
    @property
    def satellite_entries(self) -> list[PDPSATS_satellite_entries_Field]: ...


class GENERATERTKCORRECTIONS(Message):
    @property
    def correction_type_enum(self) -> RTKCorrectionSet: ...

    @property
    def port(self) -> CommPort: ...


class RAIMMODE(Message):
    @property
    def mode(self) -> RAIMMode: ...

    @property
    def hal(self) -> float: ...

    @property
    def val(self) -> float: ...

    @property
    def pfa(self) -> float: ...


class RAIMSTATUS_rejected_s_vs_Field(Field):
    @property
    def system_type(self) -> SystemType: ...

    @property
    def id(self) -> SatelliteId: ...


class RAIMSTATUS(Message):
    @property
    def mode(self) -> RAIMMode: ...

    @property
    def integrity_status(self) -> RAIMIntegrityStatus: ...

    @property
    def hpl_status(self) -> RAIMProtectionLevelStatus: ...

    @property
    def hpl(self) -> float: ...

    @property
    def vpl_status(self) -> RAIMProtectionLevelStatus: ...

    @property
    def vpl(self) -> float: ...

    @property
    def rejected_s_vs(self) -> list[RAIMSTATUS_rejected_s_vs_Field]: ...


class GENERATEDIFFCORRECTIONS(Message):
    @property
    def interface_mode_enum(self) -> InterfaceMode: ...

    @property
    def port(self) -> CommPort: ...


class ALIGNBSLNXYZ(Message):
    @property
    def solution_status(self) -> SolStatus: ...

    @property
    def position_type(self) -> SolType: ...

    @property
    def x(self) -> float: ...

    @property
    def y(self) -> float: ...

    @property
    def z(self) -> float: ...

    @property
    def x_std_dev(self) -> float: ...

    @property
    def y_std_dev(self) -> float: ...

    @property
    def z_std_dev(self) -> float: ...

    @property
    def rover_id(self) -> str: ...

    @property
    def base_id(self) -> str: ...

    @property
    def num_svs(self) -> int: ...

    @property
    def num_soln_svs(self) -> int: ...

    @property
    def num_soln_L1_svs(self) -> int: ...

    @property
    def num_soln_multi_svs(self) -> int: ...

    @property
    def extended_solution_status2(self) -> int: ...

    @property
    def ext_sol_stat(self) -> int: ...

    @property
    def gal_and_bds_mask(self) -> int: ...

    @property
    def gps_and_glo_mask(self) -> int: ...


class ALIGNBSLNENU(Message):
    @property
    def solution_status(self) -> SolStatus: ...

    @property
    def solution_type(self) -> SolType: ...

    @property
    def longitude(self) -> float: ...

    @property
    def latitude(self) -> float: ...

    @property
    def height(self) -> float: ...

    @property
    def longitude_std_dev(self) -> float: ...

    @property
    def latitude_std_dev(self) -> float: ...

    @property
    def height_std_dev(self) -> float: ...

    @property
    def rover_id(self) -> str: ...

    @property
    def master_id(self) -> str: ...

    @property
    def num_svs(self) -> int: ...

    @property
    def num_soln_svs(self) -> int: ...

    @property
    def num_soln_L1_svs(self) -> int: ...

    @property
    def num_soln_multi_svs(self) -> int: ...

    @property
    def measurement_source(self) -> int: ...

    @property
    def ext_sol_stat(self) -> int: ...

    @property
    def gal_and_bds_mask(self) -> int: ...

    @property
    def gps_and_glo_mask(self) -> int: ...


class HEADINGSATS_satellite_entries_Field(Field):
    @property
    def system_type(self) -> SystemType: ...

    @property
    def id(self) -> SatelliteId: ...

    @property
    def status(self) -> ObservationStatus: ...

    @property
    def status_mask(self) -> int: ...


class HEADINGSATS(Message):
    @property
    def satellite_entries(self) -> list[HEADINGSATS_satellite_entries_Field]: ...


class SETRTCMTXVERSION(Message):
    @property
    def version(self) -> RTCMVersion: ...


class ALIGNAUTOMATION(Message):
    @property
    def enable(self) -> Enable: ...

    @property
    def port(self) -> CommPort: ...

    @property
    def baud_rate(self) -> int: ...

    @property
    def req_rate_in_hz(self) -> int: ...

    @property
    def send_heading_ext(self) -> OnOff: ...

    @property
    def interface_mode(self) -> InterfaceMode: ...


class REFSTATIONINFO(Message):
    @property
    def latitude(self) -> float: ...

    @property
    def longitude(self) -> float: ...

    @property
    def height(self) -> float: ...

    @property
    def datum(self) -> Datum: ...

    @property
    def arp_height(self) -> float: ...

    @property
    def health(self) -> int: ...

    @property
    def ref_type(self) -> RefStation: ...

    @property
    def station_id(self) -> str: ...

    @property
    def antenna_model(self) -> str: ...

    @property
    def antenna_serial(self) -> str: ...


class ALIGNDOP(Message):
    @property
    def gdop(self) -> float: ...

    @property
    def pdop(self) -> float: ...

    @property
    def hdop(self) -> float: ...

    @property
    def htdop(self) -> float: ...

    @property
    def tdop(self) -> float: ...

    @property
    def gps_elev_mask(self) -> float: ...

    @property
    def sats(self) -> list[int]: ...


class HEADING2(Message):
    @property
    def solution_status(self) -> SolStatus: ...

    @property
    def position_type(self) -> SolType: ...

    @property
    def b_length(self) -> float: ...

    @property
    def heading(self) -> float: ...

    @property
    def pitch(self) -> float: ...

    @property
    def float_1(self) -> float: ...

    @property
    def heading_std_dev(self) -> float: ...

    @property
    def pitch_std_dev(self) -> float: ...

    @property
    def rover_id(self) -> str: ...

    @property
    def base_id(self) -> str: ...

    @property
    def num_svs(self) -> int: ...

    @property
    def num_soln_svs(self) -> int: ...

    @property
    def num_soln_L1_svs(self) -> int: ...

    @property
    def num_soln_multi_svs(self) -> int: ...

    @property
    def extended_solution_status2(self) -> int: ...

    @property
    def ext_sol_stat(self) -> int: ...

    @property
    def gal_and_bds_mask(self) -> int: ...

    @property
    def gps_and_glo_mask(self) -> int: ...


class GENERATEALIGNCORRECTIONS(Message):
    @property
    def port(self) -> CommPort: ...

    @property
    def baud_rate(self) -> int: ...

    @property
    def obs_rate_in_hz(self) -> int: ...

    @property
    def ref_rate_in_hz(self) -> int: ...

    @property
    def correction_interface(self) -> InterfaceMode: ...


class SETBASERECEIVERTYPE(Message):
    @property
    def receiver_type(self) -> BaseReceiverType: ...


class BASEANTENNAPCO(Message):
    @property
    def frequency(self) -> Frequency: ...

    @property
    def offset(self) -> list[float]: ...

    @property
    def corr_type (self) -> DGPSType: ...

    @property
    def station_id(self) -> str: ...


class BASEANTENNAPCV(Message):
    @property
    def frequency(self) -> Frequency: ...

    @property
    def pcv(self) -> list[float]: ...

    @property
    def corr_type (self) -> DGPSType: ...

    @property
    def station_id(self) -> str: ...


class THISANTENNAPCO(Message):
    @property
    def frequency(self) -> Frequency: ...

    @property
    def offset(self) -> list[float]: ...


class THISANTENNAPCV(Message):
    @property
    def frequency(self) -> Frequency: ...

    @property
    def pcv(self) -> list[float]: ...


class BASEANTENNATYPE(Message):
    @property
    def antenna_type(self) -> AntennaModel: ...

    @property
    def antenna_raydom(self) -> AntennaRaydomType: ...

    @property
    def corr_type(self) -> DGPSType: ...

    @property
    def station_id(self) -> str: ...


class HEADINGEXT(Message):
    @property
    def solution_status(self) -> int: ...

    @property
    def solution_type(self) -> int: ...

    @property
    def heading_offset(self) -> float: ...

    @property
    def pitch_offset(self) -> float: ...

    @property
    def x(self) -> float: ...

    @property
    def y(self) -> float: ...

    @property
    def z(self) -> float: ...

    @property
    def x_var(self) -> float: ...

    @property
    def y_var(self) -> float: ...

    @property
    def z_var(self) -> float: ...

    @property
    def xy_var(self) -> float: ...

    @property
    def yz_var(self) -> float: ...

    @property
    def zx_var(self) -> float: ...

    @property
    def master_id(self) -> str: ...

    @property
    def rover_id(self) -> str: ...

    @property
    def undulation(self) -> float: ...

    @property
    def num_sats_tracked(self) -> int: ...

    @property
    def num_sats_in_sol(self) -> int: ...

    @property
    def num_high_sats(self) -> int: ...

    @property
    def num_high_l2_sats(self) -> int: ...

    @property
    def ext_sol_stat(self) -> int: ...

    @property
    def gp_sand_glo_freqs_in_sol(self) -> int: ...


class THISANTENNATYPE(Message):
    @property
    def antenna_type(self) -> AntennaModel: ...

    @property
    def antenna_raydom(self) -> AntennaRaydomType: ...


class SBASALMANAC(Message):
    @property
    def satellite_id(self) -> int: ...

    @property
    def system_variant(self) -> SystemVariant: ...

    @property
    def t0(self) -> int: ...

    @property
    def data_id(self) -> int: ...

    @property
    def health(self) -> int: ...

    @property
    def x(self) -> int: ...

    @property
    def y(self) -> int: ...

    @property
    def z(self) -> int: ...

    @property
    def x_vel(self) -> int: ...

    @property
    def y_vel(self) -> int: ...

    @property
    def z_vel(self) -> int: ...


class BESTGNSSPOS(Message):
    @property
    def solution_status(self) -> SolStatus: ...

    @property
    def position_type(self) -> SolType: ...

    @property
    def latitude(self) -> float: ...

    @property
    def longitude(self) -> float: ...

    @property
    def orthometric_height(self) -> float: ...

    @property
    def undulation(self) -> float: ...

    @property
    def datum_id(self) -> Datum: ...

    @property
    def latitude_std_dev(self) -> float: ...

    @property
    def longitude_std_dev(self) -> float: ...

    @property
    def height_std_dev(self) -> float: ...

    @property
    def base_id(self) -> str: ...

    @property
    def diff_age(self) -> float: ...

    @property
    def solution_age(self) -> float: ...

    @property
    def num_svs(self) -> int: ...

    @property
    def num_soln_svs(self) -> int: ...

    @property
    def num_soln_L1_svs(self) -> int: ...

    @property
    def num_soln_multi_svs(self) -> int: ...

    @property
    def extended_solution_status2(self) -> int: ...

    @property
    def ext_sol_stat(self) -> int: ...

    @property
    def gal_and_bds_mask(self) -> int: ...

    @property
    def gps_and_glo_mask(self) -> int: ...


class BESTGNSSVEL(Message):
    @property
    def velocity_status(self) -> SolStatus: ...

    @property
    def velocity_type(self) -> SolType: ...

    @property
    def latency(self) -> float: ...

    @property
    def diff_age(self) -> float: ...

    @property
    def horizontal_speed(self) -> float: ...

    @property
    def ground_track(self) -> float: ...

    @property
    def z(self) -> float: ...

    @property
    def float_1(self) -> float: ...


class SETTROPOMODEL(Message):
    @property
    def model(self) -> TropoModel: ...


class RTKSOURCETIMEOUT(Message):
    @property
    def setting(self) -> CorrectionsTimeOut: ...

    @property
    def time_out(self) -> int: ...


class RTKMATCHEDTIMEOUT(Message):
    @property
    def timeout(self) -> int: ...


class PSRDIFFSOURCETIMEOUT(Message):
    @property
    def setting(self) -> CorrectionsTimeOut: ...

    @property
    def time_out(self) -> int: ...


class PSRDIFFTIMEOUT(Message):
    @property
    def time_out(self) -> int: ...


class STEADYLINE(Message):
    @property
    def command(self) -> SteadyLineCommand: ...

    @property
    def offset_deweight(self) -> int: ...


class PPPPOS(Message):
    @property
    def solution_status(self) -> SolStatus: ...

    @property
    def position_type(self) -> SolType: ...

    @property
    def latitude(self) -> float: ...

    @property
    def longitude(self) -> float: ...

    @property
    def orthometric_height(self) -> float: ...

    @property
    def undulation(self) -> float: ...

    @property
    def datum_id(self) -> Datum: ...

    @property
    def latitude_std_dev(self) -> float: ...

    @property
    def longitude_std_dev(self) -> float: ...

    @property
    def height_std_dev(self) -> float: ...

    @property
    def base_id(self) -> str: ...

    @property
    def diff_age(self) -> float: ...

    @property
    def solution_age(self) -> float: ...

    @property
    def num_svs(self) -> int: ...

    @property
    def num_soln_svs(self) -> int: ...

    @property
    def num_soln_L1_svs(self) -> int: ...

    @property
    def num_soln_multi_svs(self) -> int: ...

    @property
    def extended_solution_status2(self) -> int: ...

    @property
    def ext_sol_stat(self) -> int: ...

    @property
    def gal_and_bds_mask(self) -> int: ...

    @property
    def gps_and_glo_mask(self) -> int: ...


class PPPSATS_satellite_entries_Field(Field):
    @property
    def system_type(self) -> SystemType: ...

    @property
    def id(self) -> SatelliteId: ...

    @property
    def status(self) -> ObservationStatus: ...

    @property
    def status_mask(self) -> int: ...


class PPPSATS(Message):
    @property
    def satellite_entries(self) -> list[PPPSATS_satellite_entries_Field]: ...


class PPPRESET(Message):
    @property
    def type(self) -> PPPResetType: ...


class PPPXYZ(Message):
    @property
    def solution_status(self) -> SolStatus: ...

    @property
    def position_type(self) -> SolType: ...

    @property
    def x(self) -> float: ...

    @property
    def y(self) -> float: ...

    @property
    def z(self) -> float: ...

    @property
    def x_std_dev(self) -> float: ...

    @property
    def y_std_dev(self) -> float: ...

    @property
    def z_std_dev(self) -> float: ...

    @property
    def velocity_status(self) -> SolStatus: ...

    @property
    def velocity_type(self) -> SolType: ...

    @property
    def x_10(self) -> float: ...

    @property
    def y_11(self) -> float: ...

    @property
    def z_12(self) -> float: ...

    @property
    def x_std_dev_13(self) -> float: ...

    @property
    def y_std_dev_14(self) -> float: ...

    @property
    def z_std_dev_15(self) -> float: ...

    @property
    def base_id(self) -> str: ...

    @property
    def latency(self) -> float: ...

    @property
    def diff_age(self) -> float: ...

    @property
    def solution_age(self) -> float: ...

    @property
    def num_svs(self) -> int: ...

    @property
    def num_soln_svs(self) -> int: ...

    @property
    def num_soln_L1_svs(self) -> int: ...

    @property
    def num_soln_multi_svs(self) -> int: ...

    @property
    def char_as_int(self) -> int: ...

    @property
    def ext_sol_stat(self) -> int: ...

    @property
    def gal_and_bds_mask(self) -> int: ...

    @property
    def gps_and_glo_mask(self) -> int: ...


class PPPSEED(Message):
    @property
    def mode(self) -> PPPSeedMode: ...

    @property
    def latitude_in_degrees(self) -> float: ...

    @property
    def longitude_in_degrees(self) -> float: ...

    @property
    def height(self) -> float: ...

    @property
    def northing_std_dev(self) -> float: ...

    @property
    def easting_std_dev(self) -> float: ...

    @property
    def height_std_dev(self) -> float: ...

    @property
    def undulation(self) -> float: ...


class PPPDOP2_tdo_ps_Field(Field):
    @property
    def system(self) -> TimingSystem: ...

    @property
    def dop(self) -> float: ...


class PPPDOP2(Message):
    @property
    def gdop(self) -> float: ...

    @property
    def pdop(self) -> float: ...

    @property
    def hdop(self) -> float: ...

    @property
    def vdop(self) -> float: ...

    @property
    def tdo_ps(self) -> list[PPPDOP2_tdo_ps_Field]: ...


class PPPDYNAMICS(Message):
    @property
    def dynamics(self) -> PPPDynamics: ...


class PPPTIMEOUT(Message):
    @property
    def time_out(self) -> int: ...


class PPPCONVERGEDCRITERIA(Message):
    @property
    def criteria(self) -> PPPConvergedCriteria: ...

    @property
    def threshold(self) -> float: ...


class UALCONTROL(Message):
    @property
    def accuracy_level_action(self) -> UserAccuracyLevelControl: ...

    @property
    def accuracy_level1_upper_bound(self) -> float: ...

    @property
    def accuracy_level2_upper_bound(self) -> float: ...


class HEADINGEXT2(Message):
    @property
    def rover_id(self) -> str: ...

    @property
    def master_id(self) -> str: ...

    @property
    def data(self) -> list[int]: ...


class BESTVELTYPE(Message):
    @property
    def type(self) -> BestVelType: ...


class HEADINGRATE(Message):
    @property
    def solution_status(self) -> SolStatus: ...

    @property
    def solution_type(self) -> SolType: ...

    @property
    def latency(self) -> float: ...

    @property
    def b_length(self) -> float: ...

    @property
    def heading(self) -> float: ...

    @property
    def pitch(self) -> float: ...

    @property
    def b_length_std_dev(self) -> float: ...

    @property
    def heading_std_dev(self) -> float: ...

    @property
    def pitch_std_dev(self) -> float: ...

    @property
    def float_1(self) -> float: ...

    @property
    def rover_id(self) -> str: ...

    @property
    def base_id(self) -> str: ...

    @property
    def extended_solution_status2(self) -> int: ...

    @property
    def char_as_int(self) -> int: ...

    @property
    def char_as_int_14(self) -> int: ...

    @property
    def char_as_int_15(self) -> int: ...


class PPPSOURCE(Message):
    @property
    def type(self) -> PPPSource: ...


class LBANDBEAMTABLE_items_Field(Field):
    @property
    def name(self) -> str: ...

    @property
    def region_id(self) -> str: ...

    @property
    def frequency_in_hz(self) -> int: ...

    @property
    def baud_rate(self) -> int: ...

    @property
    def longitude(self) -> float: ...

    @property
    def beam_access(self) -> int: ...


class LBANDBEAMTABLE(Message):
    @property
    def items(self) -> list[LBANDBEAMTABLE_items_Field]: ...


class TERRASTARINFO(Message):
    @property
    def pac(self) -> str: ...

    @property
    def operating_mode(self) -> VeriposOperatingMode: ...

    @property
    def subscription_details(self) -> int: ...

    @property
    def contract_end_day_of_year(self) -> int: ...

    @property
    def contract_end_year(self) -> int: ...

    @property
    def timed_enable_period(self) -> int: ...

    @property
    def region_restriction(self) -> VeriposRegionRestriction: ...

    @property
    def local_area_center_point_latitude(self) -> float: ...

    @property
    def local_area_center_point_longitude(self) -> float: ...

    @property
    def local_area_radius(self) -> int: ...


class VERIPOSINFO(Message):
    @property
    def serial_number(self) -> int: ...

    @property
    def operating_mode(self) -> VeriposOperatingMode: ...

    @property
    def subscription_details(self) -> int: ...

    @property
    def service_code(self) -> str: ...


class TERRASTARSTATUS(Message):
    @property
    def access_status(self) -> Enable: ...

    @property
    def decoder_sync_state(self) -> VeriposDecoderSyncState: ...

    @property
    def timed_enable_remaining_time(self) -> int: ...

    @property
    def local_area_status(self) -> VeriposLocalAreaStatus: ...

    @property
    def geogating_status(self) -> VeriposGeogatingStatus: ...


class VERIPOSSTATUS(Message):
    @property
    def access_status(self) -> Enable: ...

    @property
    def decoder_sync_state(self) -> VeriposDecoderSyncState: ...


class MARK3POS(Message):
    @property
    def solution_status(self) -> SolStatus: ...

    @property
    def position_type(self) -> SolType: ...

    @property
    def latitude(self) -> float: ...

    @property
    def longitude(self) -> float: ...

    @property
    def orthometric_height(self) -> float: ...

    @property
    def undulation(self) -> float: ...

    @property
    def datum_id(self) -> Datum: ...

    @property
    def latitude_std_dev(self) -> float: ...

    @property
    def longitude_std_dev(self) -> float: ...

    @property
    def height_std_dev(self) -> float: ...

    @property
    def base_id(self) -> str: ...

    @property
    def diff_age(self) -> float: ...

    @property
    def solution_age(self) -> float: ...

    @property
    def num_svs(self) -> int: ...

    @property
    def num_soln_svs(self) -> int: ...

    @property
    def num_soln_L1_svs(self) -> int: ...

    @property
    def num_soln_multi_svs(self) -> int: ...

    @property
    def char_as_int(self) -> int: ...

    @property
    def ext_sol_stat(self) -> int: ...

    @property
    def gal_and_bds_mask(self) -> int: ...

    @property
    def gps_and_glo_mask(self) -> int: ...


class MARK4POS(Message):
    @property
    def solution_status(self) -> SolStatus: ...

    @property
    def position_type(self) -> SolType: ...

    @property
    def latitude(self) -> float: ...

    @property
    def longitude(self) -> float: ...

    @property
    def orthometric_height(self) -> float: ...

    @property
    def undulation(self) -> float: ...

    @property
    def datum_id(self) -> Datum: ...

    @property
    def latitude_std_dev(self) -> float: ...

    @property
    def longitude_std_dev(self) -> float: ...

    @property
    def height_std_dev(self) -> float: ...

    @property
    def base_id(self) -> str: ...

    @property
    def diff_age(self) -> float: ...

    @property
    def solution_age(self) -> float: ...

    @property
    def num_svs(self) -> int: ...

    @property
    def num_soln_svs(self) -> int: ...

    @property
    def num_soln_L1_svs(self) -> int: ...

    @property
    def num_soln_multi_svs(self) -> int: ...

    @property
    def char_as_int(self) -> int: ...

    @property
    def ext_sol_stat(self) -> int: ...

    @property
    def gal_and_bds_mask(self) -> int: ...

    @property
    def gps_and_glo_mask(self) -> int: ...


class GLIDEINITIALIZATIONPERIOD(Message):
    @property
    def wait_duration(self) -> float: ...


class DUALANTENNAALIGN(Message):
    @property
    def enable(self) -> Enable: ...

    @property
    def obs_rate_hz(self) -> int: ...

    @property
    def pos_rate_hz(self) -> int: ...


class AUTOSURVEY(Message):
    @property
    def switch(self) -> Enable: ...

    @property
    def max_time(self) -> int: ...

    @property
    def accuracy(self) -> float: ...

    @property
    def horiz_tol(self) -> float: ...

    @property
    def save_positions_in_nvm(self) -> OnOff: ...

    @property
    def id(self) -> str: ...


class RTKPORTMODE(Message):
    @property
    def port(self) -> CommPort: ...

    @property
    def port_mode(self) -> RTKPortMode: ...


class PPPBASICCONVERGEDCRITERIA(Message):
    @property
    def criteria(self) -> PPPConvergedCriteria: ...

    @property
    def threshold(self) -> float: ...


class SAVEDSURVEYPOSITIONS_positions_Field(Field):
    @property
    def id(self) -> str: ...

    @property
    def latitude(self) -> float: ...

    @property
    def longitude(self) -> float: ...

    @property
    def height(self) -> float: ...


class SAVEDSURVEYPOSITIONS(Message):
    @property
    def positions(self) -> list[SAVEDSURVEYPOSITIONS_positions_Field]: ...


class SURVEYPOSITION(Message):
    @property
    def option(self) -> SurveyPosition: ...

    @property
    def id(self) -> str: ...

    @property
    def latitude(self) -> float: ...

    @property
    def longitude(self) -> float: ...

    @property
    def height(self) -> float: ...

    @property
    def tolerance(self) -> float: ...


class RTKASSIST(Message):
    @property
    def enable(self) -> Enable: ...


class PDPDOP2_tdo_ps_Field(Field):
    @property
    def system(self) -> TimingSystem: ...

    @property
    def dop(self) -> float: ...


class PDPDOP2(Message):
    @property
    def gdop(self) -> float: ...

    @property
    def pdop(self) -> float: ...

    @property
    def hdop(self) -> float: ...

    @property
    def vdop(self) -> float: ...

    @property
    def tdo_ps(self) -> list[PDPDOP2_tdo_ps_Field]: ...


class PPPDOP(Message):
    @property
    def gdop(self) -> float: ...

    @property
    def pdop(self) -> float: ...

    @property
    def hdop(self) -> float: ...

    @property
    def htdop(self) -> float: ...

    @property
    def tdop(self) -> float: ...

    @property
    def gps_elev_mask(self) -> float: ...

    @property
    def sats(self) -> list[int]: ...


class PDPDOP(Message):
    @property
    def gdop(self) -> float: ...

    @property
    def pdop(self) -> float: ...

    @property
    def hdop(self) -> float: ...

    @property
    def htdop(self) -> float: ...

    @property
    def tdop(self) -> float: ...

    @property
    def gps_elev_mask(self) -> float: ...

    @property
    def sats(self) -> list[int]: ...


class STEADYLINEDIFFERENTIALTIMEOUT(Message):
    @property
    def time_out(self) -> float: ...


class RTKASSISTTIMEOUT(Message):
    @property
    def limit_type(self) -> RTKAssistTimeOutLimit: ...

    @property
    def time_out(self) -> int: ...


class REFERENCESTATIONTIMEOUT(Message):
    @property
    def setting(self) -> CorrectionsTimeOut: ...

    @property
    def time_out(self) -> int: ...


class DUALANTENNAHEADING(Message):
    @property
    def solution_status(self) -> SolStatus: ...

    @property
    def position_type(self) -> SolType: ...

    @property
    def b_length(self) -> float: ...

    @property
    def heading(self) -> float: ...

    @property
    def pitch(self) -> float: ...

    @property
    def float_1(self) -> float: ...

    @property
    def heading_std_dev(self) -> float: ...

    @property
    def pitch_std_dev(self) -> float: ...

    @property
    def base_id(self) -> str: ...

    @property
    def num_svs(self) -> int: ...

    @property
    def num_soln_svs(self) -> int: ...

    @property
    def num_soln_L1_svs(self) -> int: ...

    @property
    def num_soln_multi_svs(self) -> int: ...

    @property
    def extended_solution_status2(self) -> int: ...

    @property
    def ext_sol_stat(self) -> int: ...

    @property
    def gal_and_bds_mask(self) -> int: ...

    @property
    def gps_and_glo_mask(self) -> int: ...


class GPHDTDUALANTENNA(Message):
    @property
    def solution_status(self) -> SolStatus: ...

    @property
    def position_type(self) -> SolType: ...

    @property
    def output_hdt(self) -> bool: ...

    @property
    def heading(self) -> float: ...

    @property
    def system_set(self) -> int: ...


class RTKASSISTSTATUS(Message):
    @property
    def state(self) -> RTKAssistState: ...

    @property
    def status(self) -> RTKAssistStatus: ...

    @property
    def remaining_time(self) -> float: ...

    @property
    def corrections_age(self) -> float: ...


class RTKINTEGERCRITERIA(Message):
    @property
    def criteria(self) -> RTKIntegerCriteria: ...

    @property
    def threshold(self) -> float: ...


class PPPDYNAMICSEED(Message):
    @property
    def week(self) -> int: ...

    @property
    def seconds (self) -> Any: ...

    @property
    def latitude_in_degrees(self) -> float: ...

    @property
    def longitude_in_degrees(self) -> float: ...

    @property
    def ellipsoidal_height(self) -> float: ...

    @property
    def northing_std_dev(self) -> float: ...

    @property
    def easting_std_dev(self) -> float: ...

    @property
    def height_std_dev(self) -> float: ...

    @property
    def northing_easting_covariance(self) -> float: ...

    @property
    def northing_height_covariance(self) -> float: ...

    @property
    def easting_height_covariance(self) -> float: ...


class RTKRESET(Message):
    @property
    def type(self) -> RTKResetType: ...


class OCEANIXINFO(Message):
    @property
    def pac(self) -> str: ...

    @property
    def operating_mode(self) -> VeriposOperatingMode: ...

    @property
    def subscription_details(self) -> int: ...

    @property
    def contract_end_day_of_year(self) -> int: ...

    @property
    def contract_end_year(self) -> int: ...

    @property
    def timed_enable_period(self) -> int: ...

    @property
    def region_restriction(self) -> VeriposRegionRestriction: ...


class OCEANIXSTATUS(Message):
    @property
    def access_status(self) -> Enable: ...

    @property
    def decoder_sync_state(self) -> VeriposDecoderSyncState: ...

    @property
    def region_restriction_status(self) -> VeriposRegionRestrictionStatus: ...


class BESTVELX(Message):
    @property
    def status(self) -> SolStatus: ...

    @property
    def vel_type(self) -> VelType: ...

    @property
    def x(self) -> float: ...

    @property
    def y(self) -> float: ...

    @property
    def z(self) -> float: ...

    @property
    def x_std_dev(self) -> float: ...

    @property
    def y_std_dev(self) -> float: ...

    @property
    def z_std_dev(self) -> float: ...

    @property
    def rsvd_field(self) -> int: ...

    @property
    def latency_ms(self) -> int: ...


class PPPSEEDAPPLICATIONSTATUS(Message):
    @property
    def status(self) -> PPPSeedApplicationStatus: ...

    @property
    def latitude(self) -> float: ...

    @property
    def longitude(self) -> float: ...

    @property
    def height(self) -> float: ...

    @property
    def latitude_std_dev(self) -> float: ...

    @property
    def longitude_std_dev(self) -> float: ...

    @property
    def height_std_dev(self) -> float: ...


class TECTONICSCOMPENSATIONSOURCE(Message):
    @property
    def velocity_source(self) -> TectonicsCompensationVelocitySource: ...

    @property
    def name(self) -> str: ...


class HEADINGEXT2(Message):
    @property
    def rover_id(self) -> str: ...

    @property
    def master_id(self) -> str: ...

    @property
    def data(self) -> list[int]: ...


class TECTONICSCOMPENSATION(Message):
    @property
    def status(self) -> TectonicsCompensationStatus: ...

    @property
    def name(self) -> str: ...

    @property
    def x(self) -> float: ...

    @property
    def y(self) -> float: ...

    @property
    def z(self) -> float: ...


class PPPDATUMINFO(Message):
    @property
    def name(self) -> str: ...

    @property
    def epsg_code(self) -> int: ...

    @property
    def epoch(self) -> float: ...

    @property
    def transformation_status(self) -> DatumTransformationStatus: ...


class PSRDATUMINFO(Message):
    @property
    def name(self) -> str: ...

    @property
    def epsg_code(self) -> int: ...

    @property
    def epoch(self) -> float: ...

    @property
    def transformation_status(self) -> DatumTransformationStatus: ...


class BESTGNSSDATUMINFO(Message):
    @property
    def name(self) -> str: ...

    @property
    def epsg_code(self) -> int: ...

    @property
    def epoch(self) -> float: ...

    @property
    def transformation_status(self) -> DatumTransformationStatus: ...


class PDPDATUMINFO(Message):
    @property
    def name(self) -> str: ...

    @property
    def epsg_code(self) -> int: ...

    @property
    def epoch(self) -> float: ...

    @property
    def transformation_status(self) -> DatumTransformationStatus: ...


class RTKDATUMINFO(Message):
    @property
    def name(self) -> str: ...

    @property
    def epsg_code(self) -> int: ...

    @property
    def epoch(self) -> float: ...

    @property
    def transformation_status(self) -> DatumTransformationStatus: ...


class BESTDATUMINFO(Message):
    @property
    def name(self) -> str: ...

    @property
    def epsg_code(self) -> int: ...

    @property
    def epoch(self) -> float: ...

    @property
    def transformation_status(self) -> DatumTransformationStatus: ...


class TILTCOMPENSATIONCONTROL(Message):
    @property
    def enable(self) -> Enable: ...


class WIFIAPPASSKEY(Message):
    @property
    def passkey(self) -> str: ...


class WIFIAPCHANNEL(Message):
    @property
    def channel(self) -> int: ...


class WIFIAPSETTINGS(Message):
    @property
    def ssid(self) -> str: ...

    @property
    def passkey(self) -> str: ...

    @property
    def band(self) -> WifiBand: ...

    @property
    def security_type(self) -> WifiSecurityType: ...

    @property
    def encryption(self) -> WifiEncryptionType: ...

    @property
    def region(self) -> Region: ...

    @property
    def channel(self) -> int: ...

    @property
    def bssid(self) -> str: ...


class WIFIAPIPCONFIG(Message):
    @property
    def ip_address(self) -> str: ...

    @property
    def netmask(self) -> str: ...


class MEDIAFORMAT(Message):
    @property
    def mass_storage_device(self) -> MassStorageDevice: ...


class WIFIMODE(Message):
    @property
    def mode(self) -> WifiMode: ...


class SATELCONTROL(Message):
    @property
    def action(self) -> SatelControlAction: ...

    @property
    def value(self) -> str: ...


class SATELDETECT(Message):
    @property
    def comm_port(self) -> CommPort: ...


class SATELSTATUS(Message):
    @property
    def satel_status(self) -> SatelStatus: ...

    @property
    def satel_error(self) -> SatelError: ...

    @property
    def failed_command(self) -> str: ...


class WIFIAPSSID(Message):
    @property
    def ssid(self) -> str: ...


class WIFISTATUS_clients_Field(Field):
    @property
    def mac_address(self) -> str: ...


class WIFISTATUS(Message):
    @property
    def status(self) -> WifiStatus: ...

    @property
    def ssid(self) -> str: ...

    @property
    def rssi(self) -> int: ...

    @property
    def channel(self) -> int: ...

    @property
    def bssid(self) -> str: ...

    @property
    def security(self) -> WifiSecurityType: ...

    @property
    def clients(self) -> list[WIFISTATUS_clients_Field]: ...


class WIFINETLIST_net_ap_info_Field(Field):
    @property
    def ssid(self) -> str: ...

    @property
    def rssi(self) -> int: ...

    @property
    def channel(self) -> int: ...

    @property
    def bssid(self) -> str: ...

    @property
    def security(self) -> WifiSecurityType: ...


class WIFINETLIST(Message):
    @property
    def net_ap_info(self) -> list[WIFINETLIST_net_ap_info_Field]: ...


class WIFINETCONFIG(Message):
    @property
    def network_id(self) -> int: ...

    @property
    def switch(self) -> Enable: ...

    @property
    def ssid(self) -> str: ...

    @property
    def passkey(self) -> str: ...

    @property
    def address_mode(self) -> IPConfigMode: ...

    @property
    def ip_address(self) -> str: ...

    @property
    def net_mask(self) -> str: ...

    @property
    def gateway(self) -> str: ...

    @property
    def dns_server(self) -> str: ...


class WIFIALIGNAUTOMATION(Message):
    @property
    def switch(self) -> Enable: ...

    @property
    def network_id(self) -> int: ...

    @property
    def icom(self) -> CommPort: ...

    @property
    def req_rate_hz(self) -> int: ...

    @property
    def send_heading_ext(self) -> OnOff: ...

    @property
    def interface_mode(self) -> InterfaceMode: ...


class SATEL4CONFIG(Message):
    @property
    def satel4_radio_behaviour(self) -> Satel4RadioBehaviour: ...

    @property
    def tx_power_m_w(self) -> Any: ...

    @property
    def freq_hz(self) -> Any: ...

    @property
    def compatibility_mode(self) -> Any: ...

    @property
    def satel4_base_type(self) -> Satel4BaseType: ...


class SATEL4INFO(Message):
    @property
    def satel_protocol(self) -> Satel4Protocol: ...

    @property
    def tx_freq_hz(self) -> Any: ...

    @property
    def rx_freq_hz(self) -> Any: ...

    @property
    def channel_spacing_hz(self) -> Any: ...

    @property
    def tx_power_m_w(self) -> Any: ...

    @property
    def fec_enabled(self) -> bool: ...


class SATEL9CONFIG(Message):
    @property
    def satel9_modem_mode(self) -> Satel9ModemMode: ...

    @property
    def freq_key(self) -> Any: ...

    @property
    def network_id(self) -> Any: ...

    @property
    def min_packet_size(self) -> Any: ...

    @property
    def max_packet_size(self) -> Any: ...

    @property
    def retry_timeout(self) -> Any: ...

    @property
    def subnet(self) -> Any: ...

    @property
    def repeaters(self) -> bool: ...

    @property
    def master_packet_repeat(self) -> Any: ...

    @property
    def tx_power_m_w(self) -> Any: ...


class SATEL9CONFIGL(Message):
    @property
    def satel9_modem_mode(self) -> Satel9ModemMode: ...

    @property
    def leica_channel(self) -> Any: ...

    @property
    def retry_timeout(self) -> Any: ...

    @property
    def subnet(self) -> Any: ...

    @property
    def repeaters(self) -> bool: ...

    @property
    def master_packet_repeat(self) -> Any: ...

    @property
    def tx_power_m_w(self) -> Any: ...


class SATEL9CONFIGN(Message):
    @property
    def satel9_modem_mode(self) -> Satel9ModemMode: ...

    @property
    def novariant_channel(self) -> Any: ...

    @property
    def retry_timeout(self) -> Any: ...

    @property
    def subnet(self) -> Any: ...

    @property
    def repeaters(self) -> bool: ...

    @property
    def master_packet_repeat(self) -> Any: ...

    @property
    def tx_power_m_w(self) -> Any: ...


class SATEL9INFO(Message):
    @property
    def satel9_modem_mode(self) -> Satel9ModemMode: ...

    @property
    def leica_channel(self) -> int: ...

    @property
    def novariant_channel(self) -> int: ...

    @property
    def freq_key(self) -> Any: ...

    @property
    def network_id(self) -> Any: ...

    @property
    def min_packet_size(self) -> Any: ...

    @property
    def max_packet_size(self) -> Any: ...

    @property
    def retry_timeout(self) -> Any: ...

    @property
    def subnet(self) -> Any: ...

    @property
    def repeaters(self) -> bool: ...

    @property
    def master_packet_repeat(self) -> Any: ...

    @property
    def tx_power_m_w(self) -> Any: ...

    @property
    def hop_table_version(self) -> Any: ...

    @property
    def freq_zone(self) -> str: ...


class SATELSTARTUPDETECT(Message):
    @property
    def enable(self) -> Enable: ...

    @property
    def comm_port(self) -> CommPort: ...


class BLUETOOTHCONTROL(Message):
    @property
    def bluetooth_enable(self) -> BluetoothControl: ...


class PASSXCOM1(Message):
    @property
    def buffer(self) -> list[int]: ...


class PASSXCOM2(Message):
    @property
    def buffer(self) -> list[int]: ...


class PASSXCOM3(Message):
    @property
    def buffer(self) -> list[int]: ...


class PASSETH1(Message):
    @property
    def buffer(self) -> list[int]: ...


class SBAS12(Message):
    @property
    def prn(self) -> int: ...

    @property
    def a1(self) -> float: ...

    @property
    def a0(self) -> float: ...

    @property
    def t0t(self) -> int: ...

    @property
    def wn(self) -> int: ...

    @property
    def dt_ls(self) -> int: ...

    @property
    def wnlsf(self) -> int: ...

    @property
    def dn(self) -> int: ...

    @property
    def dt_lsf(self) -> int: ...

    @property
    def utcid(self) -> int: ...

    @property
    def gpstow(self) -> int: ...

    @property
    def gpswn(self) -> int: ...

    @property
    def glonass_indicator(self) -> bool: ...

    @property
    def SBAS12_reserved_bits(self) -> list[int]: ...


class SBAS27_regions_Field(Field):
    @property
    def lat1(self) -> int: ...

    @property
    def long1(self) -> int: ...

    @property
    def lat2(self) -> int: ...

    @property
    def long2(self) -> int: ...

    @property
    def shape(self) -> int: ...


class SBAS27(Message):
    @property
    def prn(self) -> int: ...

    @property
    def iods(self) -> int: ...

    @property
    def num_service_msgs(self) -> int: ...

    @property
    def service_msg_num(self) -> int: ...

    @property
    def priority_code(self) -> int: ...

    @property
    def udre_inside(self) -> int: ...

    @property
    def udre_outside(self) -> int: ...

    @property
    def regions(self) -> list[SBAS27_regions_Field]: ...

    @property
    def SBAS27_reserved(self) -> int: ...


class SBAS6(Message):
    @property
    def prn(self) -> int: ...

    @property
    def iodf2(self) -> int: ...

    @property
    def iodf3(self) -> int: ...

    @property
    def iodf4(self) -> int: ...

    @property
    def iodf5(self) -> int: ...

    @property
    def udrei(self) -> list[int]: ...


class INSPVACMP(Message):
    @property
    def week_milliseconds(self) -> int: ...

    @property
    def ins_solution_status(self) -> int: ...

    @property
    def gnss_position_type(self) -> int: ...

    @property
    def latitude(self) -> int: ...

    @property
    def longitude(self) -> int: ...

    @property
    def height(self) -> int: ...

    @property
    def north_vel(self) -> int: ...

    @property
    def east_vel(self) -> int: ...

    @property
    def up_vel(self) -> int: ...

    @property
    def roll(self) -> int: ...

    @property
    def pitch(self) -> int: ...

    @property
    def azimuth(self) -> int: ...

    @property
    def azimuth_rate(self) -> int: ...

    @property
    def milliseconds(self) -> int: ...


class INSCOV(Message):
    @property
    def week(self) -> int: ...

    @property
    def seconds(self) -> float: ...

    @property
    def elements(self) -> list[float]: ...

    @property
    def elements_3(self) -> list[float]: ...

    @property
    def elements_4(self) -> list[float]: ...


class INSCOVS(Message):
    @property
    def week(self) -> int: ...

    @property
    def seconds(self) -> float: ...

    @property
    def elements(self) -> list[float]: ...

    @property
    def elements_3(self) -> list[float]: ...

    @property
    def elements_4(self) -> list[float]: ...


class SETMARK3OFFSET(Message):
    @property
    def input(self) -> list[float]: ...

    @property
    def input_1(self) -> list[float]: ...


class SETMARK4OFFSET(Message):
    @property
    def input(self) -> list[float]: ...

    @property
    def input_1(self) -> list[float]: ...


class SETIMUTOANTOFFSET(Message):
    @property
    def input(self) -> list[float]: ...

    @property
    def input_stdev(self) -> list[float]: ...


class SETIMUORIENTATION(Message):
    @property
    def orientation(self) -> int: ...


class RVBCALIBRATE(Message):
    @property
    def cmd(self) -> Any: ...


class VEHICLEBODYROTATION(Message):
    @property
    def input(self) -> list[float]: ...

    @property
    def input_stdev(self) -> list[float]: ...


class INSWHEELUPDATE(Message):
    @property
    def trigger(self) -> Enable: ...


class BESTLEVERARM(Message):
    @property
    def input(self) -> list[float]: ...

    @property
    def input_stdev(self) -> list[float]: ...

    @property
    def mapping(self) -> int: ...


class LEVERARMCALIBRATE(Message):
    @property
    def trigger(self) -> OnOff: ...

    @property
    def max_time(self) -> float: ...

    @property
    def max_offset_std(self) -> float: ...


class SETINSOFFSET(Message):
    @property
    def input(self) -> list[float]: ...


class INSUPDATE(Message):
    @property
    def pos_type(self) -> SolType: ...

    @property
    def num_psr(self) -> int: ...

    @property
    def num_phase(self) -> int: ...

    @property
    def num_dop(self) -> int: ...

    @property
    def zupt_epoch(self) -> bool: ...

    @property
    def wheel_status(self) -> WheelStatus: ...

    @property
    def heading_update_status(self) -> HeadingUpdateStatus: ...


class SETINITATTITUDE(Message):
    @property
    def pitch(self) -> float: ...

    @property
    def roll(self) -> float: ...

    @property
    def azimuth(self) -> float: ...

    @property
    def pitch_std_dev(self) -> float: ...

    @property
    def roll_std_dev(self) -> float: ...

    @property
    def azimuth_std_dev(self) -> float: ...


class APPLYVEHICLEBODYROTATION(Message):
    @property
    def trigger(self) -> Enable: ...


class EXTHDGOFFSET(Message):
    @property
    def heading_offset(self) -> float: ...

    @property
    def heading_offset_std_dev(self) -> float: ...

    @property
    def pitch_offset(self) -> float: ...

    @property
    def pitch_offset_std_dev(self) -> float: ...


class SETIMUTOANTOFFSET2(Message):
    @property
    def input(self) -> list[float]: ...

    @property
    def input_stdev(self) -> list[float]: ...


class BESTLEVERARM2(Message):
    @property
    def input(self) -> list[float]: ...

    @property
    def input_stdev(self) -> list[float]: ...

    @property
    def mapping(self) -> int: ...


class IMUTOANTOFFSETS_lever_arm_Field(Field):
    @property
    def offset(self) -> INSOffset: ...

    @property
    def elements(self) -> list[float]: ...

    @property
    def elements_4(self) -> list[float]: ...

    @property
    def status(self) -> SourceStatus: ...


class IMUTOANTOFFSETS(Message):
    @property
    def mapping(self) -> int: ...

    @property
    def lever_arm(self) -> list[IMUTOANTOFFSETS_lever_arm_Field]: ...


class INSZUPTCONTROL(Message):
    @property
    def trigger(self) -> Enable: ...


class SETGIMBALORIENTATION(Message):
    @property
    def orientation(self) -> int: ...


class GIMBALSPANROTATION(Message):
    @property
    def input(self) -> list[float]: ...

    @property
    def input_stdev(self) -> list[float]: ...


class SETIMUTOGIMBALOFFSET(Message):
    @property
    def input(self) -> list[float]: ...

    @property
    def input_stdev(self) -> list[float]: ...


class SETMARK1OFFSET(Message):
    @property
    def input(self) -> list[float]: ...

    @property
    def input_1(self) -> list[float]: ...


class SETMARK2OFFSET(Message):
    @property
    def input(self) -> list[float]: ...

    @property
    def input_1(self) -> list[float]: ...


class SETWHEELSOURCE(Message):
    @property
    def wheel_sensor_input(self) -> Any: ...

    @property
    def polarity(self) -> Polarity: ...

    @property
    def SETWHEELSOURCE_reserved(self) -> int: ...


class RAWLBANDFRAME(Message):
    @property
    def service_id(self) -> int: ...

    @property
    def RAWLBANDFRAME_reserved(self) -> int: ...

    @property
    def data(self) -> list[int]: ...


class RAWLBANDPACKET(Message):
    @property
    def data(self) -> list[int]: ...


class PDPVELOCITYOUT(Message):
    @property
    def pdp_velocity_out_cmd(self) -> Any: ...


class DGPSEPHEMDELAY(Message):
    @property
    def ephem_delay(self) -> int: ...


class GPGGARTK(Message):
    @property
    def latitude(self) -> float: ...

    @property
    def longitude(self) -> float: ...

    @property
    def undulation(self) -> float: ...

    @property
    def height(self) -> float: ...

    @property
    def solution_status(self) -> SolStatus: ...

    @property
    def position_type(self) -> SolType: ...

    @property
    def num_soln_svs(self) -> int: ...

    @property
    def hdop(self) -> float: ...

    @property
    def diff_age(self) -> float: ...

    @property
    def base_id(self) -> str: ...

    @property
    def gga_quality(self) -> int: ...


class LBANDINFO(Message):
    @property
    def assigned_frequency(self) -> int: ...

    @property
    def baud_rate(self) -> int: ...

    @property
    def service_id(self) -> int: ...

    @property
    def ushort(self) -> int: ...

    @property
    def osn(self) -> int: ...

    @property
    def subscription_type(self) -> Any: ...

    @property
    def expiration_week(self) -> int: ...

    @property
    def expiration_seconds(self) -> int: ...

    @property
    def subscription_type_8(self) -> Any: ...

    @property
    def expiration_week_9(self) -> int: ...

    @property
    def expiration_seconds_10(self) -> int: ...

    @property
    def subscription_mode(self) -> int: ...


class BASEANTENNAMODEL(Message):
    @property
    def antenna_name(self) -> str: ...

    @property
    def serial_number(self) -> str: ...

    @property
    def setup_id(self) -> int: ...

    @property
    def antenna_type(self) -> AntennaModel: ...

    @property
    def l1_offset(self) -> list[float]: ...

    @property
    def l1_pcv(self) -> list[float]: ...

    @property
    def l2_offset(self) -> list[float]: ...

    @property
    def l2_pcv(self) -> list[float]: ...


class SBAS32(Message):
    @property
    def prn(self) -> int: ...

    @property
    def iodp(self) -> int: ...

    @property
    def prc(self) -> list[int]: ...

    @property
    def udrei(self) -> list[int]: ...


class SBAS33(Message):
    @property
    def prn(self) -> int: ...

    @property
    def iodp(self) -> int: ...

    @property
    def prc(self) -> list[int]: ...

    @property
    def udrei(self) -> list[int]: ...


class SBAS34(Message):
    @property
    def prn(self) -> int: ...

    @property
    def iodp(self) -> int: ...

    @property
    def prc(self) -> list[int]: ...

    @property
    def udrei(self) -> list[int]: ...


class SBAS35(Message):
    @property
    def prn(self) -> int: ...

    @property
    def iodp(self) -> int: ...

    @property
    def prc(self) -> list[int]: ...

    @property
    def udrei(self) -> list[int]: ...


class SBAS45(Message):
    @property
    def prn(self) -> int: ...

    @property
    def prn_mask_number(self) -> int: ...

    @property
    def iode(self) -> int: ...

    @property
    def dx(self) -> int: ...

    @property
    def dy(self) -> int: ...

    @property
    def dz(self) -> int: ...

    @property
    def ddx(self) -> int: ...

    @property
    def ddy(self) -> int: ...

    @property
    def ddz(self) -> int: ...

    @property
    def daf0(self) -> int: ...

    @property
    def tod(self) -> int: ...

    @property
    def prn_mask_number_11(self) -> int: ...

    @property
    def iode_12(self) -> int: ...

    @property
    def dx_13(self) -> int: ...

    @property
    def dy_14(self) -> int: ...

    @property
    def dz_15(self) -> int: ...

    @property
    def ddx_16(self) -> int: ...

    @property
    def ddy_17(self) -> int: ...

    @property
    def ddz_18(self) -> int: ...

    @property
    def daf0_19(self) -> int: ...

    @property
    def tod_20(self) -> int: ...

    @property
    def iodp(self) -> int: ...


class SETCANNAME(Message):
    @property
    def manufacturer_code(self) -> int: ...

    @property
    def industry_group(self) -> int: ...

    @property
    def device_class(self) -> int: ...

    @property
    def device_class_instance(self) -> int: ...

    @property
    def function(self) -> int: ...

    @property
    def function_instance(self) -> int: ...

    @property
    def ecu_instance(self) -> int: ...

    @property
    def preferred_address(self) -> int: ...

    @property
    def can_port(self) -> CanPort: ...


class SETMARK3OFFSET(Message):
    @property
    def input(self) -> list[float]: ...

    @property
    def input_1(self) -> list[float]: ...


class SETMARK4OFFSET(Message):
    @property
    def input(self) -> list[float]: ...

    @property
    def input_1(self) -> list[float]: ...


class SETMARK1OFFSET(Message):
    @property
    def input(self) -> list[float]: ...

    @property
    def input_1(self) -> list[float]: ...


class SETMARK2OFFSET(Message):
    @property
    def input(self) -> list[float]: ...

    @property
    def input_1(self) -> list[float]: ...


class SETWHEELSOURCE(Message):
    @property
    def wheel_sensor_input(self) -> Any: ...

    @property
    def polarity(self) -> Polarity: ...

    @property
    def SETWHEELSOURCE_reserved(self) -> int: ...


class LBANDINFO(Message):
    @property
    def assigned_frequency(self) -> int: ...

    @property
    def baud_rate(self) -> int: ...

    @property
    def service_id(self) -> int: ...

    @property
    def ushort(self) -> int: ...

    @property
    def osn(self) -> int: ...

    @property
    def subscription_type(self) -> Any: ...

    @property
    def expiration_week(self) -> int: ...

    @property
    def expiration_seconds(self) -> int: ...

    @property
    def subscription_type_8(self) -> Any: ...

    @property
    def expiration_week_9(self) -> int: ...

    @property
    def expiration_seconds_10(self) -> int: ...

    @property
    def subscription_mode(self) -> int: ...

